/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
import { FocusableOption, FocusKeyManager, FocusMonitor } from '@angular/cdk/a11y';
import { BooleanInput } from '@angular/cdk/coercion';
import { SelectionModel } from '@angular/cdk/collections';
import { AfterContentInit, ChangeDetectorRef, ElementRef, EventEmitter, OnChanges, OnDestroy, OnInit, QueryList, SimpleChanges } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { CanDisableRipple } from '@vdlx/vdl-angular/mat/core';
import * as i0 from "@angular/core";
declare const _MatNavMenuListBase: import("@vdlx/vdl-angular/mat/core")._Constructor<CanDisableRipple> & import("@vdlx/vdl-angular/mat/core")._AbstractConstructor<CanDisableRipple> & {
    new (): {};
};
declare const _MatNavMenuOptionBase: import("@vdlx/vdl-angular/mat/core")._Constructor<CanDisableRipple> & import("@vdlx/vdl-angular/mat/core")._AbstractConstructor<CanDisableRipple> & {
    new (): {};
};
/** @docs-private */
export declare const MAT_NAV_MENU_LIST_VALUE_ACCESSOR: any;
/** Change event that is being fired whenever the selected state of an option changes. */
export declare class MatNavMenuListChange {
    /** Reference to the nav menu list that emitted the event. */
    source: MatNavMenuList;
    /** Reference to the options that have been changed. */
    options: MatNavMenuOption[];
    constructor(
    /** Reference to the nav menu list that emitted the event. */
    source: MatNavMenuList, 
    /** Reference to the options that have been changed. */
    options: MatNavMenuOption[]);
}
/**
 * Component for nav-menu-options of nav-menu-list. Each nav-menu-options can put current item
 * into the selectionModel of nav-menu-list if the current item is selected.
 */
export declare class MatNavMenuOption extends _MatNavMenuOptionBase implements OnDestroy, OnInit, FocusableOption, CanDisableRipple {
    private _element;
    private _changeDetector;
    /** @docs-private */
    navMenuList: MatNavMenuList;
    private _selected;
    private _disabled;
    private _hasFocus;
    /**
     * Emits when the selected state of the option has changed.
     * Use to facilitate two-data binding to the `selected` property.
     * @docs-private
     */
    readonly selectedChange: EventEmitter<boolean>;
    /** DOM element containing the item's text. */
    _text: ElementRef;
    /**
     * This is set to true after the first OnChanges cycle so we don't clear the value of `selected`
     * in the first cycle.
     */
    private _inputsInitialized;
    /** Value of the option */
    get value(): any;
    set value(newValue: any);
    private _value;
    /** Whether the option is disabled. */
    get disabled(): boolean;
    set disabled(value: BooleanInput);
    /** Whether the option is selected. */
    get selected(): boolean;
    set selected(value: BooleanInput);
    constructor(_element: ElementRef<HTMLElement>, _changeDetector: ChangeDetectorRef, 
    /** @docs-private */
    navMenuList: MatNavMenuList);
    ngOnInit(): void;
    ngOnDestroy(): void;
    /** Toggles the selection state of the option. */
    toggle(): void;
    /** Allows for programmatic focusing of the option. */
    focus(): void;
    /** Whether the option has focus. */
    hasFocus(): boolean;
    /**
     * Returns the list item's text label. Implemented as a part of the FocusKeyManager.
     * @docs-private
     */
    getLabel(): any;
    /** Whether this list item should show a ripple effect when clicked. */
    _isRippleDisabled(): boolean;
    /** Handles click event for nav menu list options */
    _handleClick(): void;
    /** Handles focus event for nav menu list options */
    _handleFocus(): void;
    /** Handles blur event for nav menu list options */
    _handleBlur(): void;
    /** Retrieves the DOM element of the component host. */
    _getHostElement(): HTMLElement;
    /** Sets the selected state of the option. Returns whether the value has changed. */
    _setSelected(selected: boolean): boolean;
    /**
     * Notifies Angular that the option needs to be checked in the next change detection run. Mainly
     * used to trigger an update of the list option if the disabled state of the nav menu list
     * changed.
     */
    _markForCheck(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<MatNavMenuOption, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MatNavMenuOption, "mat-nav-menu-option", ["matNavMenuOption"], { "disableRipple": "disableRipple"; "value": "value"; "disabled": "disabled"; "selected": "selected"; }, { "selectedChange": "selectedChange"; }, never, ["*"]>;
}
/**
 * Material Design list component where each item is a selectable option. Behaves as a listbox.
 */
export declare class MatNavMenuList extends _MatNavMenuListBase implements CanDisableRipple, AfterContentInit, ControlValueAccessor, OnDestroy, OnChanges {
    private _element;
    private _changeDetector;
    private _focusMonitor;
    private _contentInitialized;
    /** The FocusKeyManager which handles focus. */
    _keyManager: FocusKeyManager<MatNavMenuOption>;
    /** The label for the Menu List Header. */
    headerLabel: string;
    /** The option components contained within this selection-list. */
    options: QueryList<MatNavMenuOption>;
    /** Emits a change event whenever the selected state of an option changes. */
    readonly selectionChange: EventEmitter<MatNavMenuListChange>;
    /** Emits a change event whenever the focus state of an option changes. */
    readonly focusChange: EventEmitter<MatNavMenuOption>;
    /**
     * Tabindex of the nav menu list.
     * @breaking-change 11.0.0 Remove `tabIndex` input. Check Selection List to see what they do in the future
     */
    tabIndex: number;
    /**
     * Function used for comparing an option against the selected value when determining which
     * options should appear as selected. The first argument is the value of an options. The second
     * one is a value from the selected value. A boolean must be returned.
     */
    compareWith: (o1: any, o2: any) => boolean;
    /** Whether the nav menu list is disabled. */
    get disabled(): boolean;
    set disabled(value: BooleanInput);
    private _disabled;
    /** The currently selected options. */
    selectedOptions: SelectionModel<MatNavMenuOption>;
    /** The tabindex of the nav menu list. */
    _tabIndex: number;
    /** View to model callback that should be called whenever the selected options change. */
    private _onChange;
    /** Keeps track of the currently-selected value. */
    _value: string[] | null;
    /** Emits when the list has been destroyed. */
    private readonly _destroyed;
    /** View to model callback that should be called if the list or its options lost focus. */
    _onTouched: () => void;
    /** Whether the list has been destroyed. */
    private _isDestroyed;
    constructor(_element: ElementRef<HTMLElement>, tabIndex: string, _changeDetector: ChangeDetectorRef, _focusMonitor: FocusMonitor);
    ngAfterContentInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    /** Focuses the nav menu list. */
    focus(options?: FocusOptions): void;
    /** Sets the focused option of the nav-menu-list. */
    _setFocusedOption(option: MatNavMenuOption): void;
    /**
     * Removes an option from the nav menu list and updates the active item.
     * @returns Currently-active item.
     */
    _removeOptionFromList(option: MatNavMenuOption): MatNavMenuOption | null;
    /** Passes relevant key presses to our key manager. */
    _keydown(event: KeyboardEvent): void;
    /** Reports a value change to the ControlValueAccessor */
    _reportValueChange(): void;
    /** Emits a change event if the selected state of an option changed. */
    _emitChangeEvent(options: MatNavMenuOption[]): void;
    /** Implemented as part of ControlValueAccessor. */
    writeValue(values: string[]): void;
    /** Implemented as a part of ControlValueAccessor. */
    setDisabledState(isDisabled: boolean): void;
    /** Implemented as part of ControlValueAccessor. */
    registerOnChange(fn: (value: any) => void): void;
    /** Implemented as part of ControlValueAccessor. */
    registerOnTouched(fn: () => void): void;
    /** Sets the selected options based on the specified values. */
    private _setOptionsFromValues;
    /** Returns the values of the selected options. */
    private _getSelectedOptionValues;
    /** Toggles the state of the currently focused option if enabled. */
    private _toggleFocusedOption;
    /**
     * Utility to ensure all indexes are valid.
     * @param index The index to be checked.
     * @returns True if the index is valid for our list of options.
     */
    private _isValidIndex;
    /** Returns the index of the specified list option. */
    private _getOptionIndex;
    /** Marks all the options to be checked in the next change detection run. */
    private _markOptionsForCheck;
    /**
     * Removes the tabindex from the nav menu list and resets it back afterwards, allowing the user
     * to tab out of it. This prevents the list from capturing focus and redirecting it back within
     * the list, creating a focus trap if it user tries to tab away.
     */
    private _allowFocusEscape;
    /** Updates the tabindex based upon if the nav-menu list is empty. */
    private _updateTabIndex;
    static ɵfac: i0.ɵɵFactoryDeclaration<MatNavMenuList, [null, { attribute: "tabindex"; }, null, null]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MatNavMenuList, "mat-nav-menu-list", ["matNavMenuList"], { "disableRipple": "disableRipple"; "headerLabel": "headerLabel"; "tabIndex": "tabIndex"; "compareWith": "compareWith"; "disabled": "disabled"; }, { "selectionChange": "selectionChange"; "focusChange": "focusChange"; }, ["options"], ["*"]>;
}
/**
 * Nav Menu List - Nav Menu
 */
export declare class MatNavMenu {
    static ɵfac: i0.ɵɵFactoryDeclaration<MatNavMenu, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<MatNavMenu, "mat-nav-menu-list[mat-nav-menu]", never, {}, {}, never>;
}
/**
 * Nav Menu List - Nav Submenu
 */
export declare class MatNavSubmenu {
    static ɵfac: i0.ɵɵFactoryDeclaration<MatNavSubmenu, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<MatNavSubmenu, "mat-nav-menu-list[mat-nav-submenu]", never, {}, {}, never>;
}
export {};
