/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
import { FocusMonitor } from '@angular/cdk/a11y';
import { AfterViewInit, ChangeDetectorRef, ElementRef, EventEmitter } from '@angular/core';
import { MatListItem } from '@vdlx/vdl-angular/mat/list';
import * as i0 from "@angular/core";
/** Notification Status types */
export declare type MatProfilePanelNotificationStatus = 'error' | 'informational' | 'successful' | 'warning';
/** Profile Panel Notification type */
export interface MatProfilePanelNotificationType {
    message: string;
    status: MatProfilePanelNotificationStatus;
    unread?: boolean;
    description?: string;
    readOnly?: boolean;
}
/** Profile Panel Notification Clicked Event type */
export interface ProfilePanelNotificationClickedEvent {
    event: Event;
    notification: MatProfilePanelNotificationType;
}
/** Notification list item for use in the profile panel notifications expansion panel */
export declare class MatProfilePanelNotification extends MatListItem implements AfterViewInit {
    private _elementRef;
    private _focusMonitor;
    /** Profile Panel Notification */
    notification: MatProfilePanelNotificationType;
    /** Notification Clicked event emitter */
    notificationClicked: EventEmitter<ProfilePanelNotificationClickedEvent>;
    /** Title Clicked event emitter */
    titleClicked: EventEmitter<ProfilePanelNotificationClickedEvent>;
    constructor(_elementRef: ElementRef<HTMLElement>, _changeDetectorRef: ChangeDetectorRef, _focusMonitor: FocusMonitor);
    ngAfterViewInit(): void;
    /** returns icon name for the notification type */
    getStatusIcon(): string | null;
    /** Emits Notification Clicked event when list item clicked */
    notificationClickHandler(event: Event, notification: MatProfilePanelNotificationType): void;
    /** Emits Title Clicked event when Title on list item is clicked */
    titleClickHandler(event: Event, notification: MatProfilePanelNotificationType): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<MatProfilePanelNotification, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MatProfilePanelNotification, "mat-profile-panel-notification", never, { "notification": "notification"; }, { "notificationClicked": "notificationClicked"; "titleClicked": "titleClicked"; }, never, ["*"]>;
}
