/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
import { AfterViewInit, ChangeDetectorRef, ElementRef, OnDestroy, QueryList } from '@angular/core';
import { MatExpansionPanel } from '@vdlx/vdl-angular/mat/expansion';
import { MatDrawer } from '@vdlx/vdl-angular/mat/sidenav';
import { Subscription } from 'rxjs';
import { MatProfilePanelFooter, MatProfilePanelFooterContent } from './profile-panel-footer';
import { MatProfilePanelIntl } from './profile-panel-intl';
import * as i0 from "@angular/core";
export declare class MatProfileNotificationsFooter {
    static ɵfac: i0.ɵɵFactoryDeclaration<MatProfileNotificationsFooter, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<MatProfileNotificationsFooter, "[mat-profile-notifications-footer]", never, {}, {}, never>;
}
/** Help Item for help expansion */
export declare class MatProfileHelpItem {
    static ɵfac: i0.ɵɵFactoryDeclaration<MatProfileHelpItem, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<MatProfileHelpItem, "[mat-profile-help-item]", never, {}, {}, never>;
}
/** Header for help expansion */
export declare class MatProfileHelpHeader {
    static ɵfac: i0.ɵɵFactoryDeclaration<MatProfileHelpHeader, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<MatProfileHelpHeader, "[mat-profile-help-header]", never, {}, {}, never>;
}
/** Footer for help expansion */
export declare class MatProfileHelpFooter {
    static ɵfac: i0.ɵɵFactoryDeclaration<MatProfileHelpFooter, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<MatProfileHelpFooter, "[mat-profile-help-footer]", never, {}, {}, never>;
}
/** Item for Settings expansion */
export declare class MatProfileSettingItem {
    static ɵfac: i0.ɵɵFactoryDeclaration<MatProfileSettingItem, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<MatProfileSettingItem, "[mat-profile-setting-item]", never, {}, {}, never>;
}
/** Content within the profile panel. This includes the Accordion with Notifications, Help and Settings Expansion Panels */
export declare class MatProfilePanelContent implements OnDestroy {
    _intl: MatProfilePanelIntl;
    private _changeDetectorRef;
    private _intlChanges;
    /** Enables Notifications section in Profile Panel. Default is true. */
    enableNotifications: boolean;
    /** Enables Help section in Profile Panel. Default is true. */
    enableHelp: boolean;
    /** Enables Settings section in Profile Panel. Default is true. */
    enableSettings: boolean;
    /** Count to display in badge on notifications header. If 0, then the badge will not be shown. */
    notificationsCount: number;
    panelSubscriptions: Subscription[];
    /** List of Expansion Panel components in profile panel */
    expansionPanels: QueryList<MatExpansionPanel>;
    /** List of Expansion Panel elements in profile panel */
    expansionElements: QueryList<ElementRef>;
    /** Notifications footer component */
    notificationsFooter: MatProfileNotificationsFooter;
    /** Help content header */
    helpHeader: MatProfileHelpHeader;
    /** Help footer component */
    helpFooter: MatProfileHelpFooter;
    constructor(_intl: MatProfilePanelIntl, _changeDetectorRef: ChangeDetectorRef);
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<MatProfilePanelContent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MatProfilePanelContent, "mat-profile-panel-content", never, { "enableNotifications": "enableNotifications"; "enableHelp": "enableHelp"; "enableSettings": "enableSettings"; "notificationsCount": "notificationsCount"; }, {}, ["notificationsFooter", "helpHeader", "helpFooter"], ["mat-profile-panel-notification", "a[mat-profile-notifications-footer]", "mat-form-field[mat-profile-help-header]", "a[mat-profile-help-item]", "a[mat-profile-help-footer]", "mat-divider[mat-profile-setting-item], mat-slide-toggle[mat-profile-setting-item], a[mat-profile-setting-item]"]>;
}
/** For displaying a badge on the profile panel expansion header title */
export declare class MatProfilePanelExpansionBadge {
    /** Number to display in the badge */
    count: number;
    static ɵfac: i0.ɵɵFactoryDeclaration<MatProfilePanelExpansionBadge, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MatProfilePanelExpansionBadge, "mat-profile-panel-expansion-badge", never, { "count": "count"; }, {}, never, never>;
}
/** Profile Panel */
export declare class MatProfilePanel extends MatDrawer implements AfterViewInit, OnDestroy {
    /** Sets fixed as true by default */
    fixedInViewport: boolean;
    /** Sets only position for profile Panel to end */
    get position(): 'start' | 'end';
    /** Profile Panel footer component */
    profileFooter: MatProfilePanelFooter;
    /** Profile Panel footer additional content */
    profileFooterContent: MatProfilePanelFooterContent;
    static ɵfac: i0.ɵɵFactoryDeclaration<MatProfilePanel, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MatProfilePanel, "mat-profile-panel", ["matProfilePanel"], {}, {}, ["profileFooter", "profileFooterContent"], ["mat-profile-panel-content", "*", "mat-profile-panel-footer"]>;
}
/** Footer used in the Expansion Panels within profile panel */
export declare class MatProfileExpansionPanelFooter {
    static ɵfac: i0.ɵɵFactoryDeclaration<MatProfileExpansionPanelFooter, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MatProfileExpansionPanelFooter, "mat-profile-expansion-panel-footer", never, {}, {}, never, ["*"]>;
}
