import * as i0 from "@angular/core";
/**
 * Possible states for a pseudo radio.
 * @docs-private
 */
export declare type MatPseudoRadioState = 'unchecked' | 'checked';
/**
 * Component that shows a simplified radio without including any kind of "real" radio.
 * Meant to be used when the radio is purely decorative and a large number of them will be
 * included, such as for the options in a single select list. Uses no SVGs or complex animations.
 * Note that theming is meant to be handled by the parent element, e.g.
 * `mat-primary .mat-pseudo-radio`.
 *
 * Note that this component will be completely invisible to screen-reader users. This is *not*
 * interchangeable with `<mat-radio>` and should *not* be used if the user would directly
 * interact with the radio. The pseudo-radio should only be used as an implementation detail
 * of more complex components that appropriately handle selected / checked state.
 * @docs-private
 */
export declare class MatPseudoRadio {
    _animationMode?: string | undefined;
    /** Display state of the pseudo radio. */
    state: MatPseudoRadioState;
    /** Whether the pseudo radio is disabled. */
    disabled: boolean;
    /** Whether the pseudo radio is shown. Default is true */
    showRadio: boolean;
    constructor(_animationMode?: string | undefined);
    static ɵfac: i0.ɵɵFactoryDeclaration<MatPseudoRadio, [{ optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MatPseudoRadio, "mat-pseudo-radio", never, { "state": "state"; "disabled": "disabled"; "showRadio": "showRadio"; }, {}, never, never>;
}
