import * as i1$1 from '@angular/cdk/overlay';
import { Overlay, ConnectionPositionPair, OverlayConfig, OverlayModule } from '@angular/cdk/overlay';
import * as i3 from '@angular/cdk/portal';
import { BasePortalOutlet, CdkPortalOutlet, ComponentPortal, TemplatePortal, PortalModule } from '@angular/cdk/portal';
import * as i2 from '@angular/common';
import { DOCUMENT, CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { EventEmitter, Directive, Optional, Inject, ViewChild, Component, ViewEncapsulation, ChangeDetectionStrategy, InjectionToken, Injector, TemplateRef, InjectFlags, Injectable, SkipSelf, Input, ElementRef, Output, NgModule } from '@angular/core';
import * as i3$1 from '@vdlx/vdl-angular/mat/button';
import { MatButtonModule } from '@vdlx/vdl-angular/mat/button';
import { MatCommonModule } from '@vdlx/vdl-angular/mat/core';
import * as i1$2 from '@vdlx/vdl-angular/mat/icon';
import { MatIconRegistry, MatIconModule } from '@vdlx/vdl-angular/mat/icon';
import { Directionality } from '@angular/cdk/bidi';
import { ANIMATION_MODULE_TYPE } from '@angular/platform-browser/animations';
import { Subject, defer, fromEvent, of } from 'rxjs';
import { filter, take, startWith, takeUntil } from 'rxjs/operators';
import { _getFocusedElementPierceShadowDom } from '@angular/cdk/platform';
import { trigger, state, style, transition, group, animate, query, animateChild } from '@angular/animations';
import * as i1 from '@angular/cdk/a11y';
import { ESCAPE, hasModifierKey } from '@angular/cdk/keycodes';

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
/**
 * Configuration for opening a modal dialog with the MatDialog service.
 */
class MatDialogConfig {
    constructor() {
        // VDL change: specific configs prefixed with/for popover
        this.popover = false;
        /**
         * Position of a popover. Accepts: `'above'`, `'below'`, `'before'`, `'after'`
         * Default: `'after'`
         */
        this.popoverPosition = 'after';
        /** The ARIA role of the dialog element. */
        this.role = 'dialog';
        /** Custom class for the overlay pane. */
        this.panelClass = '';
        /** Whether the dialog has a backdrop. */
        this.hasBackdrop = true;
        /** Custom class for the backdrop. */
        this.backdropClass = '';
        /** Whether the user can use escape or clicking on the backdrop to close the modal. */
        this.disableClose = false;
        /** Width of the dialog. */
        this.width = '';
        /** Height of the dialog. */
        this.height = '';
        /** Max-width of the dialog. If a number is provided, assumes pixel units. Defaults to 80vw. */
        this.maxWidth = '80vw';
        /** Data being injected into the child component. */
        this.data = null;
        /** ID of the element that describes the dialog. */
        this.ariaDescribedBy = null;
        /** ID of the element that labels the dialog. */
        this.ariaLabelledBy = null;
        /** Aria label to assign to the dialog element. */
        this.ariaLabel = null;
        /**
         * Where the dialog should focus on open.
         * @breaking-change 14.0.0 Remove boolean option from autoFocus. Use string or
         * AutoFocusTarget instead.
         */
        this.autoFocus = 'first-tabbable';
        /**
         * Whether the dialog should restore focus to the
         * previously-focused element, after it's closed.
         */
        this.restoreFocus = true;
        /** Whether to wait for the opening animation to finish before trapping focus. */
        this.delayFocusTrap = true;
        /**
         * Whether the dialog should close when the user goes backwards/forwards in history.
         * Note that this usually doesn't include clicking on links (unless the user is using
         * the `HashLocationStrategy`).
         */
        this.closeOnNavigation = true;
        // TODO(jelbourn): add configuration for lifecycle hooks, ARIA labelling.
    }
}

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
/**
 * Animations used by MatDialog.
 * @docs-private
 */
const matDialogAnimations = {
    /** Animation that is applied on the dialog container by default. */
    dialogContainer: trigger('dialogContainer', [
        // Note: The `enter` animation transitions to `transform: none`, because for some reason
        // specifying the transform explicitly, causes IE both to blur the dialog content and
        // decimate the animation performance. Leaving it as `none` solves both issues.
        state('void, exit', style({ opacity: 0, transform: 'scale(0.7)' })),
        state('enter', style({ transform: 'none' })),
        transition('* => enter', group([
            animate('150ms cubic-bezier(0, 0, 0.2, 1)', style({ transform: 'none', opacity: 1 })),
            query('@*', animateChild(), { optional: true })
        ])),
        transition('* => void, * => exit', group([
            animate('75ms cubic-bezier(0.4, 0.0, 0.2, 1)', style({ opacity: 0 })),
            query('@*', animateChild(), { optional: true })
        ]))
    ])
};

/**
 * Throws an exception for the case when a ComponentPortal is
 * attached to a DomPortalOutlet without an origin.
 * @docs-private
 */
function throwMatDialogContentAlreadyAttachedError() {
    throw Error('Attempting to attach dialog content after content is already attached');
}
/**
 * Base class for the `MatDialogContainer`. The base class does not implement
 * animations as these are left to implementers of the dialog container.
 */
class _MatDialogContainerBase extends BasePortalOutlet {
    constructor(_elementRef, _focusTrapFactory, _changeDetectorRef, _document, 
    /** The dialog configuration. */
    _config, _interactivityChecker, _ngZone, _focusMonitor) {
        super();
        this._elementRef = _elementRef;
        this._focusTrapFactory = _focusTrapFactory;
        this._changeDetectorRef = _changeDetectorRef;
        this._config = _config;
        this._interactivityChecker = _interactivityChecker;
        this._ngZone = _ngZone;
        this._focusMonitor = _focusMonitor;
        /** Emits when an animation state changes. */
        this._animationStateChanged = new EventEmitter();
        /** Element that was focused before the dialog was opened. Save this to restore upon close. */
        this._elementFocusedBeforeDialogWasOpened = null;
        /**
         * Type of interaction that led to the dialog being closed. This is used to determine
         * whether the focus style will be applied when returning focus to its original location
         * after the dialog is closed.
         */
        this._closeInteractionType = null;
        /**
         * Attaches a DOM portal to the dialog container.
         * @param portal Portal to be attached.
         * @deprecated To be turned into a method.
         * @breaking-change 10.0.0
         */
        this.attachDomPortal = (portal) => {
            if (this._portalOutlet.hasAttached() /* && (typeof ngDevMode === 'undefined' || ngDevMode)*/) {
                throwMatDialogContentAlreadyAttachedError();
            }
            return this._portalOutlet.attachDomPortal(portal);
        };
        this._ariaLabelledBy = _config.ariaLabelledBy || null;
        this._document = _document;
    }
    /** Initializes the dialog container with the attached content. */
    _initializeWithAttachedContent() {
        this._focusTrap = this._focusTrapFactory.create(this._elementRef.nativeElement);
        // Save the previously focused element. This element will be re-focused
        // when the dialog closes.
        if (this._document) {
            this._elementFocusedBeforeDialogWasOpened =
                _getFocusedElementPierceShadowDom();
        }
    }
    /**
     * Attach a ComponentPortal as content to this dialog container.
     * @param portal Portal to be attached as the dialog content.
     */
    attachComponentPortal(portal) {
        if (this._portalOutlet.hasAttached() /* && (typeof ngDevMode === 'undefined' || ngDevMode) */) {
            throwMatDialogContentAlreadyAttachedError();
        }
        return this._portalOutlet.attachComponentPortal(portal);
    }
    /**
     * Attach a TemplatePortal as content to this dialog container.
     * @param portal Portal to be attached as the dialog content.
     */
    attachTemplatePortal(portal) {
        if (this._portalOutlet.hasAttached() /* && (typeof ngDevMode === 'undefined' || ngDevMode)*/) {
            throwMatDialogContentAlreadyAttachedError();
        }
        return this._portalOutlet.attachTemplatePortal(portal);
    }
    /** Moves focus back into the dialog if it was moved out. */
    _recaptureFocus() {
        if (!this._containsFocus()) {
            this._trapFocus();
        }
    }
    /**
     * Focuses the provided element. If the element is not focusable, it will add a tabIndex
     * attribute to forcefully focus it. The attribute is removed after focus is moved.
     * @param element The element to focus.
     */
    _forceFocus(element, options) {
        if (!this._interactivityChecker.isFocusable(element)) {
            element.tabIndex = -1;
            // The tabindex attribute should be removed to avoid navigating to that element again
            this._ngZone.runOutsideAngular(() => {
                const callback = () => {
                    element.removeEventListener('blur', callback);
                    element.removeEventListener('mousedown', callback);
                    element.removeAttribute('tabindex');
                };
                element.addEventListener('blur', callback);
                element.addEventListener('mousedown', callback);
            });
        }
        element.focus(options);
    }
    /**
     * Focuses the first element that matches the given selector within the focus trap.
     * @param selector The CSS selector for the element to set focus to.
     */
    _focusByCssSelector(selector, options) {
        let elementToFocus = this._elementRef.nativeElement.querySelector(selector);
        if (elementToFocus) {
            this._forceFocus(elementToFocus, options);
        }
    }
    /**
     * Moves the focus inside the focus trap. When autoFocus is not set to 'dialog', if focus
     * cannot be moved then focus will go to the dialog container.
     */
    _trapFocus() {
        const element = this._elementRef.nativeElement;
        // If were to attempt to focus immediately, then the content of the dialog would not yet be
        // ready in instances where change detection has to run first. To deal with this, we simply
        // wait for the microtask queue to be empty when setting focus when autoFocus isn't set to
        // dialog. If the element inside the dialog can't be focused, then the container is focused
        // so the user can't tab into other elements behind it.
        switch (this._config.autoFocus) {
            case false:
            case 'dialog':
                // Ensure that focus is on the dialog container. It's possible that a different
                // component tried to move focus while the open animation was running. See:
                // https://github.com/angular/components/issues/16215. Note that we only want to do this
                // if the focus isn't inside the dialog already, because it's possible that the consumer
                // turned off `autoFocus` in order to move focus themselves.
                if (!this._containsFocus()) {
                    element.focus();
                }
                break;
            case true:
            case 'first-tabbable':
                this._focusTrap
                    .focusInitialElementWhenReady()
                    .then((focusedSuccessfully) => {
                    // If we weren't able to find a focusable element in the dialog, then focus the dialog
                    // container instead.
                    if (!focusedSuccessfully) {
                        this._focusDialogContainer();
                    }
                });
                break;
            case 'first-heading':
                this._focusByCssSelector('h1, h2, h3, h4, h5, h6, [role="heading"]');
                break;
            default:
                this._focusByCssSelector(this._config.autoFocus);
                break;
        }
    }
    /** Restores focus to the element that was focused before the dialog opened. */
    _restoreFocus() {
        const previousElement = this._elementFocusedBeforeDialogWasOpened;
        // We need the extra check, because IE can set the `activeElement` to null in some cases.
        if (this._config.restoreFocus &&
            previousElement &&
            typeof previousElement.focus === 'function') {
            const activeElement = _getFocusedElementPierceShadowDom();
            const element = this._elementRef.nativeElement;
            // Make sure that focus is still inside the dialog or is on the body (usually because a
            // non-focusable element like the backdrop was clicked) before moving it. It's possible that
            // the consumer moved it themselves before the animation was done, in which case we shouldn't
            // do anything.
            if (!activeElement ||
                activeElement === this._document.body ||
                activeElement === element ||
                element.contains(activeElement)) {
                if (this._focusMonitor) {
                    this._focusMonitor.focusVia(previousElement, this._closeInteractionType);
                    this._closeInteractionType = null;
                }
                else {
                    previousElement.focus();
                }
            }
        }
        if (this._focusTrap) {
            this._focusTrap.destroy();
        }
    }
    /** Focuses the dialog container. */
    _focusDialogContainer() {
        // Note that there is no focus method when rendering on the server.
        if (this._elementRef.nativeElement.focus) {
            this._elementRef.nativeElement.focus();
        }
    }
    /** Returns whether focus is inside the dialog. */
    _containsFocus() {
        const element = this._elementRef.nativeElement;
        const activeElement = _getFocusedElementPierceShadowDom();
        return element === activeElement || element.contains(activeElement);
    }
}
_MatDialogContainerBase.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: _MatDialogContainerBase, deps: [{ token: i0.ElementRef }, { token: i1.FocusTrapFactory }, { token: i0.ChangeDetectorRef }, { token: DOCUMENT, optional: true }, { token: MatDialogConfig }, { token: i1.InteractivityChecker }, { token: i0.NgZone }, { token: i1.FocusMonitor }], target: i0.ɵɵFactoryTarget.Directive });
_MatDialogContainerBase.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.3.11", type: _MatDialogContainerBase, viewQueries: [{ propertyName: "_portalOutlet", first: true, predicate: CdkPortalOutlet, descendants: true, static: true }], usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: _MatDialogContainerBase, decorators: [{
            type: Directive
        }], ctorParameters: function () {
        return [{ type: i0.ElementRef }, { type: i1.FocusTrapFactory }, { type: i0.ChangeDetectorRef }, { type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [DOCUMENT]
                    }] }, { type: MatDialogConfig }, { type: i1.InteractivityChecker }, { type: i0.NgZone }, { type: i1.FocusMonitor }];
    }, propDecorators: { _portalOutlet: [{
                type: ViewChild,
                args: [CdkPortalOutlet, { static: true }]
            }] } });
/**
 * Internal component that wraps user-provided dialog content.
 * Animation is based on https://material.io/guidelines/motion/choreography.html.
 * @docs-private
 */
class MatDialogContainer extends _MatDialogContainerBase {
    constructor() {
        super(...arguments);
        /** State of the dialog animation. */
        this._state = 'enter';
    }
    /** Callback, invoked whenever an animation on the host completes. */
    _onAnimationDone({ toState, totalTime }) {
        if (toState === 'enter') {
            if (this._config.delayFocusTrap) {
                this._trapFocus();
            }
            this._animationStateChanged.next({ state: 'opened', totalTime });
        }
        else if (toState === 'exit') {
            this._restoreFocus();
            this._animationStateChanged.next({ state: 'closed', totalTime });
        }
    }
    /** Callback, invoked when an animation on the host starts. */
    _onAnimationStart({ toState, totalTime }) {
        if (toState === 'enter') {
            this._animationStateChanged.next({ state: 'opening', totalTime });
        }
        else if (toState === 'exit' || toState === 'void') {
            this._animationStateChanged.next({ state: 'closing', totalTime });
        }
    }
    /** Starts the dialog exit animation. */
    _startExitAnimation() {
        this._state = 'exit';
        // Mark the container for check so it can react if the
        // view container is using OnPush change detection.
        this._changeDetectorRef.markForCheck();
    }
    _initializeWithAttachedContent() {
        super._initializeWithAttachedContent();
        if (!this._config.delayFocusTrap) {
            this._trapFocus();
        }
    }
}
MatDialogContainer.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatDialogContainer, deps: null, target: i0.ɵɵFactoryTarget.Component });
MatDialogContainer.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.11", type: MatDialogContainer, selector: "mat-dialog-container", host: { attributes: { "tabindex": "-1", "aria-modal": "true" }, listeners: { "@dialogContainer.start": "_onAnimationStart($event)", "@dialogContainer.done": "_onAnimationDone($event)" }, properties: { "id": "_id", "attr.role": "_config.role", "attr.aria-labelledby": "_config.ariaLabel ? null : _ariaLabelledBy", "attr.aria-label": "_config.ariaLabel", "attr.aria-describedby": "_config.ariaDescribedBy || null", "@dialogContainer": "_state" }, classAttribute: "mat-dialog-container" }, usesInheritance: true, ngImport: i0, template: "<ng-template cdkPortalOutlet></ng-template>", styles: [".mat-popover-container:before,.mat-popover-container:after{opacity:0;position:absolute;display:block;width:0;height:0;top:unset;left:unset;border-color:transparent;border-style:solid;transition-timing-function:ease-in;transition-duration:1ms}.mat-popover-container:before{transition-property:opacity,border-color}.mat-popover-container:after{transition-property:color,opacity;color:#0000}.mat-popover-container:before{content:\"\";border-width:11px}.mat-popover-container:after{content:\"\";border-width:10px}.mat-popover-container.mat-popover-before{right:0;margin-right:14px}.mat-popover-container.mat-popover-before:before,.mat-popover-container.mat-popover-before:after{border-right-width:0}.mat-popover-container.mat-popover-before:before{right:-11px}.mat-popover-container.mat-popover-before:after{right:-15px;margin-top:23px;box-sizing:border-box;border:8px solid transparent;transform-origin:0 0;transform:rotate(225deg);box-shadow:-2px 2px 2px}.mat-popover-container.mat-popover-after{margin-left:14px}.mat-popover-container.mat-popover-after:before,.mat-popover-container.mat-popover-after:after{border-left-width:0}.mat-popover-container.mat-popover-after:before{left:-10px}.mat-popover-container.mat-popover-after:after{left:0;box-sizing:border-box;border:1px solid transparent;transform-origin:0 0;transform:rotate(45deg);box-shadow:0 1px;width:15px;height:14px;content:\"\"}.mat-popover-container.mat-popover-above{margin-bottom:14px}.mat-popover-container.mat-popover-above:before,.mat-popover-container.mat-popover-above:after{border-bottom-width:0}.mat-popover-container.mat-popover-above:before{bottom:-10px;margin-left:-11px}.mat-popover-container.mat-popover-above:after{bottom:-14px;margin-left:-10px;box-sizing:border-box;border:1px solid transparent;transform-origin:0 0;transform:rotate(-45deg);box-shadow:-2px 2px 2px;width:15px;height:14px}.mat-popover-container.mat-popover-below{margin-top:14px}.mat-popover-container.mat-popover-below:before,.mat-popover-container.mat-popover-below:after{border-top-width:0}.mat-popover-container.mat-popover-below:before{top:-10px;margin-left:-11px}.mat-popover-container.mat-popover-below:after{top:0;margin-left:10.5px;box-sizing:border-box;border:1px solid transparent;transform-origin:0 0;transform:rotate(135deg);box-shadow:-.5px .5px;width:15px;height:14px;content:\"\"}.mat-dialog-container{display:block;padding:24px;border-radius:4px;box-sizing:border-box;overflow:auto;outline:0;width:100%;height:100%;min-height:inherit;max-height:inherit}.cdk-high-contrast-active .mat-dialog-container{outline:solid 1px}.mat-dialog-container .mat-dialog-header{margin:-24px -24px 0;align-items:center;display:flex;font-size:1rem;height:60px;overflow:hidden;white-space:nowrap;padding-left:15px}.mat-dialog-container .mat-dialog-header .mat-dialog-title{outline:0;flex:1 1 auto;margin:0}.mat-dialog-container .mat-dialog-header-actions{padding:0 15px}.mat-dialog-container .mat-dialog-header-actions mat-icon{font-size:24px;line-height:24px;height:24px;width:24px}.mat-dialog-container .mat-dialog-header+.mat-dialog-content{padding:24px 15px}.mat-dialog-content{display:block;margin:0 -24px;padding:0 24px;max-height:65vh;overflow:auto;-webkit-overflow-scrolling:touch}.mat-dialog-title{margin:0 0 20px;display:block}.mat-dialog-actions{padding:8px 0;display:flex;flex-wrap:wrap;min-height:52px;align-items:center;box-sizing:content-box;margin-bottom:-24px}.mat-dialog-actions[align=end]{justify-content:flex-end}.mat-dialog-actions[align=center]{justify-content:center}.mat-dialog-actions .mat-button-base+.mat-button-base,.mat-dialog-actions .mat-mdc-button-base+.mat-mdc-button-base{margin-left:8px}[dir=rtl] .mat-dialog-actions .mat-button-base+.mat-button-base,[dir=rtl] .mat-dialog-actions .mat-mdc-button-base+.mat-mdc-button-base{margin-left:0;margin-right:8px}.mat-dialog-actions .mat-button-bar{width:-webkit-fill-available;width:-moz-available;width:stretch;padding-top:8px;padding-right:8px;margin-left:-24px;margin-right:-24px}[dir=rtl] .mat-dialog-container .mat-dialog-header{padding-left:unset;padding-right:15px}\n"], directives: [{ type: i3.CdkPortalOutlet, selector: "[cdkPortalOutlet]", inputs: ["cdkPortalOutlet"], outputs: ["attached"], exportAs: ["cdkPortalOutlet"] }], animations: [matDialogAnimations.dialogContainer], changeDetection: i0.ChangeDetectionStrategy.Default, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatDialogContainer, decorators: [{
            type: Component,
            args: [{ selector: 'mat-dialog-container', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.Default, animations: [matDialogAnimations.dialogContainer], host: {
                        class: 'mat-dialog-container',
                        tabindex: '-1',
                        'aria-modal': 'true',
                        '[id]': '_id',
                        '[attr.role]': '_config.role',
                        '[attr.aria-labelledby]': '_config.ariaLabel ? null : _ariaLabelledBy',
                        '[attr.aria-label]': '_config.ariaLabel',
                        '[attr.aria-describedby]': '_config.ariaDescribedBy || null',
                        '[@dialogContainer]': '_state',
                        '(@dialogContainer.start)': '_onAnimationStart($event)',
                        '(@dialogContainer.done)': '_onAnimationDone($event)'
                    }, template: "<ng-template cdkPortalOutlet></ng-template>", styles: [".mat-popover-container:before,.mat-popover-container:after{opacity:0;position:absolute;display:block;width:0;height:0;top:unset;left:unset;border-color:transparent;border-style:solid;transition-timing-function:ease-in;transition-duration:1ms}.mat-popover-container:before{transition-property:opacity,border-color}.mat-popover-container:after{transition-property:color,opacity;color:#0000}.mat-popover-container:before{content:\"\";border-width:11px}.mat-popover-container:after{content:\"\";border-width:10px}.mat-popover-container.mat-popover-before{right:0;margin-right:14px}.mat-popover-container.mat-popover-before:before,.mat-popover-container.mat-popover-before:after{border-right-width:0}.mat-popover-container.mat-popover-before:before{right:-11px}.mat-popover-container.mat-popover-before:after{right:-15px;margin-top:23px;box-sizing:border-box;border:8px solid transparent;transform-origin:0 0;transform:rotate(225deg);box-shadow:-2px 2px 2px}.mat-popover-container.mat-popover-after{margin-left:14px}.mat-popover-container.mat-popover-after:before,.mat-popover-container.mat-popover-after:after{border-left-width:0}.mat-popover-container.mat-popover-after:before{left:-10px}.mat-popover-container.mat-popover-after:after{left:0;box-sizing:border-box;border:1px solid transparent;transform-origin:0 0;transform:rotate(45deg);box-shadow:0 1px;width:15px;height:14px;content:\"\"}.mat-popover-container.mat-popover-above{margin-bottom:14px}.mat-popover-container.mat-popover-above:before,.mat-popover-container.mat-popover-above:after{border-bottom-width:0}.mat-popover-container.mat-popover-above:before{bottom:-10px;margin-left:-11px}.mat-popover-container.mat-popover-above:after{bottom:-14px;margin-left:-10px;box-sizing:border-box;border:1px solid transparent;transform-origin:0 0;transform:rotate(-45deg);box-shadow:-2px 2px 2px;width:15px;height:14px}.mat-popover-container.mat-popover-below{margin-top:14px}.mat-popover-container.mat-popover-below:before,.mat-popover-container.mat-popover-below:after{border-top-width:0}.mat-popover-container.mat-popover-below:before{top:-10px;margin-left:-11px}.mat-popover-container.mat-popover-below:after{top:0;margin-left:10.5px;box-sizing:border-box;border:1px solid transparent;transform-origin:0 0;transform:rotate(135deg);box-shadow:-.5px .5px;width:15px;height:14px;content:\"\"}.mat-dialog-container{display:block;padding:24px;border-radius:4px;box-sizing:border-box;overflow:auto;outline:0;width:100%;height:100%;min-height:inherit;max-height:inherit}.cdk-high-contrast-active .mat-dialog-container{outline:solid 1px}.mat-dialog-container .mat-dialog-header{margin:-24px -24px 0;align-items:center;display:flex;font-size:1rem;height:60px;overflow:hidden;white-space:nowrap;padding-left:15px}.mat-dialog-container .mat-dialog-header .mat-dialog-title{outline:0;flex:1 1 auto;margin:0}.mat-dialog-container .mat-dialog-header-actions{padding:0 15px}.mat-dialog-container .mat-dialog-header-actions mat-icon{font-size:24px;line-height:24px;height:24px;width:24px}.mat-dialog-container .mat-dialog-header+.mat-dialog-content{padding:24px 15px}.mat-dialog-content{display:block;margin:0 -24px;padding:0 24px;max-height:65vh;overflow:auto;-webkit-overflow-scrolling:touch}.mat-dialog-title{margin:0 0 20px;display:block}.mat-dialog-actions{padding:8px 0;display:flex;flex-wrap:wrap;min-height:52px;align-items:center;box-sizing:content-box;margin-bottom:-24px}.mat-dialog-actions[align=end]{justify-content:flex-end}.mat-dialog-actions[align=center]{justify-content:center}.mat-dialog-actions .mat-button-base+.mat-button-base,.mat-dialog-actions .mat-mdc-button-base+.mat-mdc-button-base{margin-left:8px}[dir=rtl] .mat-dialog-actions .mat-button-base+.mat-button-base,[dir=rtl] .mat-dialog-actions .mat-mdc-button-base+.mat-mdc-button-base{margin-left:0;margin-right:8px}.mat-dialog-actions .mat-button-bar{width:-webkit-fill-available;width:-moz-available;width:stretch;padding-top:8px;padding-right:8px;margin-left:-24px;margin-right:-24px}[dir=rtl] .mat-dialog-container .mat-dialog-header{padding-left:unset;padding-right:15px}\n"] }]
        }] });

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
// TODO(jelbourn): resizing
// Counter for unique dialog ids.
let uniqueId = 0;
/**
 * Reference to a dialog opened via the MatDialog service.
 */
class MatDialogRef {
    constructor(_overlayRef, _containerInstance, 
    /** Id of the dialog. */
    id = `mat-dialog-${uniqueId++}`) {
        this._overlayRef = _overlayRef;
        this._containerInstance = _containerInstance;
        this.id = id;
        /** Whether the user is allowed to close the dialog. */
        this.disableClose = this._containerInstance._config.disableClose;
        this.config = this._containerInstance._config;
        /** Subject for notifying the user that the dialog has finished opening. */
        this._afterOpened = new Subject();
        /** Subject for notifying the user that the dialog has finished closing. */
        this._afterClosed = new Subject();
        /** Subject for notifying the user that the dialog has started closing. */
        this._beforeClosed = new Subject();
        /** Current state of the dialog. */
        this._state = 0 /* OPEN */;
        // Pass the id along to the container.
        _containerInstance._id = id;
        // Emit when opening animation completes
        _containerInstance._animationStateChanged
            .pipe(filter((event) => event.state === 'opened'), take(1))
            .subscribe(() => {
            this._afterOpened.next();
            this._afterOpened.complete();
        });
        // Dispose overlay when closing animation is complete
        _containerInstance._animationStateChanged
            .pipe(filter((event) => event.state === 'closed'), take(1))
            .subscribe(() => {
            clearTimeout(this._closeFallbackTimeout);
            this._finishDialogClose();
        });
        _overlayRef.detachments().subscribe(() => {
            this._beforeClosed.next(this._result);
            this._beforeClosed.complete();
            this._afterClosed.next(this._result);
            this._afterClosed.complete();
            this.componentInstance = null;
            this._overlayRef.dispose();
        });
        _overlayRef
            .keydownEvents()
            .pipe(filter((event) => {
            return (event.keyCode === ESCAPE &&
                !this.disableClose &&
                !hasModifierKey(event));
        }))
            .subscribe((event) => {
            event.preventDefault();
            _closeDialogVia(this, 'keyboard');
        });
        _overlayRef.backdropClick().subscribe(() => {
            // VDL change: parallels dialog but popovers don't allow disabling close.
            if (this.config.popover === true) {
                _closeDialogVia(this, 'mouse');
            }
            else {
                if (this.disableClose) {
                    this._containerInstance._recaptureFocus();
                }
                else {
                    _closeDialogVia(this, 'mouse');
                }
            }
        });
    }
    /**
     * Close the dialog.
     * @param dialogResult Optional result to return to the dialog opener.
     */
    close(dialogResult) {
        this._result = dialogResult;
        // Transition the backdrop in parallel to the dialog.
        this._containerInstance._animationStateChanged
            .pipe(filter((event) => event.state === 'closing'), take(1))
            .subscribe((event) => {
            this._beforeClosed.next(dialogResult);
            this._beforeClosed.complete();
            this._overlayRef.detachBackdrop();
            // The logic that disposes of the overlay depends on the exit animation completing, however
            // it isn't guaranteed if the parent view is destroyed while it's running. Add a fallback
            // timeout which will clean everything up if the animation hasn't fired within the specified
            // amount of time plus 100ms. We don't need to run this outside the NgZone, because for the
            // vast majority of cases the timeout will have been cleared before it has the chance to fire.
            this._closeFallbackTimeout = window.setTimeout(() => this._finishDialogClose(), event.totalTime + 100);
        });
        this._state = 1 /* CLOSING */;
        this._containerInstance._startExitAnimation();
    }
    /**
     * Gets an observable that is notified when the dialog is finished opening.
     */
    afterOpened() {
        return this._afterOpened;
    }
    /**
     * Gets an observable that is notified when the dialog is finished closing.
     */
    afterClosed() {
        return this._afterClosed;
    }
    /**
     * Gets an observable that is notified when the dialog has started closing.
     */
    beforeClosed() {
        return this._beforeClosed;
    }
    /**
     * Gets an observable that emits when the overlay's backdrop has been clicked.
     */
    backdropClick() {
        return this._overlayRef.backdropClick();
    }
    /**
     * Gets an observable that emits when keydown events are targeted on the overlay.
     */
    keydownEvents() {
        return this._overlayRef.keydownEvents();
    }
    /**
     * Updates the dialog's position.
     * @param position New dialog position.
     */
    updatePosition(position) {
        let strategy = this._getPositionStrategy();
        if (position && (position.left || position.right)) {
            position.left
                ? strategy.left(position.left)
                : strategy.right(position.right);
        }
        else {
            strategy.centerHorizontally();
        }
        if (position && (position.top || position.bottom)) {
            position.top
                ? strategy.top(position.top)
                : strategy.bottom(position.bottom);
        }
        else {
            strategy.centerVertically();
        }
        this._overlayRef.updatePosition();
        return this;
    }
    // VDL change: popover uses the FlexibleConnectedPositionStrategy used in tooltip
    /** Updates the position of the current popover. */
    updatePopoverPosition(overlayRef) {
        const strategy = overlayRef.getConfig()
            .positionStrategy;
        const origin = this.getOrigin();
        const overlay = this.getOverlayPosition();
        strategy.withPositions([
            this._addOffset(Object.assign(Object.assign({}, origin.main), overlay.main)),
            this._addOffset(Object.assign(Object.assign({}, origin.fallback), overlay.fallback))
        ]);
        this._overlayRef.updatePosition();
        return this;
    }
    /** Adds the configured offset to a position. Used as a hook for child classes. */
    _addOffset(position) {
        return position;
    }
    /**
     * Returns the origin position and a fallback position based on the user's position preference.
     * The fallback position is the inverse of the origin (e.g. `'below' -> 'above'`).
     */
    getOrigin() {
        const isLtr = !this.config.direction || this.config.direction == 'ltr';
        const position = this.config.popoverPosition;
        let originPosition;
        if (position === 'above' || position === 'below') {
            originPosition = {
                originX: 'center',
                originY: position == 'above' ? 'top' : 'bottom'
            };
        }
        else if (position === 'before' ||
            (position == 'left' && isLtr) ||
            (position == 'right' && !isLtr)) {
            originPosition = { originX: 'start', originY: 'center' };
        }
        else if (position === 'after' ||
            (position == 'right' && isLtr) ||
            (position == 'left' && !isLtr)) {
            originPosition = { originX: 'end', originY: 'center' };
        }
        const { x, y } = this.invertPosition(originPosition.originX, originPosition.originY);
        return {
            main: originPosition,
            fallback: { originX: x, originY: y }
        };
    }
    /** Returns the overlay position and a fallback position based on the user's preference */
    getOverlayPosition() {
        const isLtr = !this.config.direction || this.config.direction == 'ltr';
        const position = this.config.popoverPosition;
        let overlayPosition;
        if (position === 'above') {
            overlayPosition = { overlayX: 'center', overlayY: 'bottom' };
        }
        else if (position === 'below') {
            overlayPosition = { overlayX: 'center', overlayY: 'top' };
        }
        else if (position === 'before' ||
            (position == 'left' && isLtr) ||
            (position == 'right' && !isLtr)) {
            overlayPosition = { overlayX: 'end', overlayY: 'center' };
        }
        else if (position === 'after' ||
            (position == 'right' && isLtr) ||
            (position == 'left' && !isLtr)) {
            overlayPosition = { overlayX: 'start', overlayY: 'center' };
        }
        const { x, y } = this.invertPosition(overlayPosition.overlayX, overlayPosition.overlayY);
        return {
            main: overlayPosition,
            fallback: { overlayX: x, overlayY: y }
        };
    }
    /** Inverts an overlay position. */
    invertPosition(x, y) {
        if (this.config.popoverPosition === 'above' ||
            this.config.popoverPosition === 'below') {
            if (y === 'top') {
                y = 'bottom';
            }
            else if (y === 'bottom') {
                y = 'top';
            }
        }
        else {
            if (x === 'end') {
                x = 'start';
            }
            else if (x === 'start') {
                x = 'end';
            }
        }
        return { x, y };
    }
    /**
     * Updates the dialog's width and height.
     * @param width New width of the dialog.
     * @param height New height of the dialog.
     */
    updateSize(width = '', height = '') {
        this._overlayRef.updateSize({ width, height });
        this._overlayRef.updatePosition();
        return this;
    }
    /** Add a CSS class or an array of classes to the overlay pane. */
    addPanelClass(classes) {
        this._overlayRef.addPanelClass(classes);
        return this;
    }
    /** Remove a CSS class or an array of classes from the overlay pane. */
    removePanelClass(classes) {
        this._overlayRef.removePanelClass(classes);
        return this;
    }
    /** Gets the current state of the dialog's lifecycle. */
    getState() {
        return this._state;
    }
    /**
     * Finishes the dialog close by updating the state of the dialog
     * and disposing the overlay.
     */
    _finishDialogClose() {
        this._state = 2 /* CLOSED */;
        this._overlayRef.dispose();
    }
    /** Fetches the position strategy object from the overlay ref. */
    _getPositionStrategy() {
        return this._overlayRef.getConfig()
            .positionStrategy;
    }
}
/**
 * Closes the dialog with the specified interaction type. This is currently not part of
 * `MatDialogRef` as that would conflict with custom dialog ref mocks provided in tests.
 * More details. See: https://github.com/angular/components/pull/9257#issuecomment-651342226.
 */
// TODO: TODO: Move this back into `MatDialogRef` when we provide an official mock dialog ref.
function _closeDialogVia(ref, interactionType, result) {
    // Some mock dialog ref instances in tests do not have the `_containerInstance` property.
    // For those, we keep the behavior as is and do not deal with the interaction type.
    if (ref._containerInstance !== undefined) {
        ref._containerInstance._closeInteractionType = interactionType;
    }
    return ref.close(result);
}

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
/** Injection token that can be used to access the data that was passed in to a dialog. */
const MAT_DIALOG_DATA = new InjectionToken('MatDialogData');
/** Injection token that can be used to specify default dialog options. */
const MAT_DIALOG_DEFAULT_OPTIONS = new InjectionToken('mat-dialog-default-options');
/** Injection token that determines the scroll handling while the dialog is open. */
const MAT_DIALOG_SCROLL_STRATEGY = new InjectionToken('mat-dialog-scroll-strategy');
/** @docs-private */
function MAT_DIALOG_SCROLL_STRATEGY_FACTORY(overlay) {
    return () => overlay.scrollStrategies.block();
}
/** @docs-private */
function MAT_DIALOG_SCROLL_STRATEGY_PROVIDER_FACTORY(overlay) {
    return () => overlay.scrollStrategies.block();
}
/** @docs-private */
const MAT_DIALOG_SCROLL_STRATEGY_PROVIDER = {
    provide: MAT_DIALOG_SCROLL_STRATEGY,
    deps: [Overlay],
    useFactory: MAT_DIALOG_SCROLL_STRATEGY_PROVIDER_FACTORY
};
/**
 * Base class for dialog services. The base dialog service allows
 * for arbitrary dialog refs and dialog container components.
 */
class _MatDialogBase {
    constructor(_overlay, _injector, _defaultOptions, _parentDialog, _overlayContainer, scrollStrategy, _dialogRefConstructor, _dialogContainerType, _dialogDataToken, 
    /**
     * @deprecated No longer used. To be removed.
     * @breaking-change 14.0.0
     */
    _animationMode) {
        this._overlay = _overlay;
        this._injector = _injector;
        this._defaultOptions = _defaultOptions;
        this._parentDialog = _parentDialog;
        this._overlayContainer = _overlayContainer;
        this._dialogRefConstructor = _dialogRefConstructor;
        this._dialogContainerType = _dialogContainerType;
        this._dialogDataToken = _dialogDataToken;
        this._openDialogsAtThisLevel = [];
        this._afterAllClosedAtThisLevel = new Subject();
        this._afterOpenedAtThisLevel = new Subject();
        this._config = new MatDialogConfig();
        this._ariaHiddenElements = new Map();
        // VDL change: specific to popover
        this._viewportMargin = 8;
        /** Emits when the component is destroyed. */
        this._destroyed = new Subject();
        // TODO (jelbourn): tighten the typing right-hand side of this expression.
        /**
         * Stream that emits when all open dialog have finished closing.
         * Will emit on subscribe if there are no open dialogs to begin with.
         */
        this.afterAllClosed = defer(() => this.openDialogs.length
            ? this._getAfterAllClosed()
            : this._getAfterAllClosed().pipe(startWith(undefined)));
        this._scrollStrategy = scrollStrategy;
    }
    /** Keeps track of the currently-open dialogs. */
    get openDialogs() {
        // VDL change: specific Dialog has a concept of dialogs in dialogs and thus dialogs at different
        // levels. Popovers are/should only be 1 level, 1 popover ever.
        if (this._config.popover === true) {
            return this._openDialogsAtThisLevel;
        }
        else {
            return this._parentDialog
                ? this._parentDialog.openDialogs
                : this._openDialogsAtThisLevel;
        }
    }
    /** Stream that emits when a dialog has been opened. */
    get afterOpened() {
        // VDL change: specific Dialog has a concept of dialogs in dialogs and thus dialogs at different
        // levels. Popovers are/should only be 1 level, 1 popover ever.
        if (this._config.popover === true) {
            return this._afterOpenedAtThisLevel;
        }
        else {
            return this._parentDialog
                ? this._parentDialog.afterOpened
                : this._afterOpenedAtThisLevel;
        }
    }
    _getAfterAllClosed() {
        // VDL change: specific Dialog has a concept of dialogs in dialogs and thus dialogs at different
        // levels. Popovers are/should only be 1 level, 1 popover ever.
        if (this._config.popover === true) {
            return this._afterAllClosedAtThisLevel;
        }
        else {
            const parent = this._parentDialog;
            return parent
                ? parent._getAfterAllClosed()
                : this._afterAllClosedAtThisLevel;
        }
    }
    open(componentOrTemplateRef, config) {
        config = _applyConfigDefaults(config, this._defaultOptions || new MatDialogConfig());
        if (config.id &&
            this.getDialogById(config.id) // &&
        // (typeof ngDevMode === 'undefined' || ngDevMode)
        ) {
            throw Error(`Dialog with id "${config.id}" exists already. The dialog id must be unique.`);
        }
        // VDL change: specific for popover
        if (config.popover === true) {
            this._overlayRef = this._createPopoverOverlay(config);
            // close only the popover on resize
            const resizeSubscription$ = fromEvent(window, 'resize').subscribe((evt) => {
                resizeSubscription$.unsubscribe();
                dialogRef.close();
            });
        }
        else {
            this._overlayRef = this._createOverlay(config);
        }
        const dialogContainer = this._attachDialogContainer(this._overlayRef, config);
        const dialogRef = this._attachDialogContent(componentOrTemplateRef, dialogContainer, this._overlayRef, config);
        // If this is the first dialog that we're opening, hide all the non-overlay content.
        if (!this.openDialogs.length) {
            this._hideNonDialogContentFromAssistiveTechnology();
        }
        this.openDialogs.push(dialogRef);
        dialogRef.afterClosed().subscribe(() => this._removeOpenDialog(dialogRef));
        this.afterOpened.next(dialogRef);
        // Notify the dialog container that the content has been attached.
        dialogContainer._initializeWithAttachedContent();
        return dialogRef;
    }
    /**
     * Closes all of the currently-open dialogs.
     */
    closeAll() {
        this._closeDialogs(this.openDialogs);
    }
    /**
     * Finds an open dialog by its id.
     * @param id ID to use when looking up the dialog.
     */
    getDialogById(id) {
        return this.openDialogs.find((dialog) => dialog.id === id);
    }
    ngOnDestroy() {
        // Only close the dialogs at this level on destroy
        // since the parent service may still be active.
        this._closeDialogs(this._openDialogsAtThisLevel);
        this._afterAllClosedAtThisLevel.complete();
        this._afterOpenedAtThisLevel.complete();
    }
    /**
     * Creates the overlay into which the dialog will be loaded.
     * @param config The dialog configuration.
     * @returns A promise resolving to the OverlayRef for the created overlay.
     */
    _createOverlay(config) {
        const overlayConfig = this._getOverlayConfig(config);
        return this._overlay.create(overlayConfig);
    }
    // VDL change: specific to popover
    /**
     * Creates the overlay into which the popover will be loaded.
     * @param config The dialog configuration.
     * @returns A promise resolving to the OverlayRef for the created overlay.
     */
    /** Create the overlay config and position strategy */
    _createPopoverOverlay(dialogConfig) {
        let connection;
        // Initial connection based on whether the popover is before or after
        if (dialogConfig.popoverPosition === 'before') {
            connection = new ConnectionPositionPair({ originX: 'end', originY: 'top' }, { overlayX: 'end', overlayY: 'top' });
        }
        else {
            connection = new ConnectionPositionPair({ originX: 'start', originY: 'top' }, { overlayX: 'start', overlayY: 'top' });
        }
        const anchorElementRef = dialogConfig.popoverAnchor;
        // Create connected position strategy that listens for scroll events to reposition.
        const strategy = this._overlay
            .position()
            .flexibleConnectedTo(anchorElementRef)
            .withFlexibleDimensions(false)
            .withViewportMargin(this._viewportMargin)
            .withPositions([connection]);
        // VDL Change: Added to allow for offsetting dialog on the x axis
        if (dialogConfig.position && dialogConfig.position.offsetX) {
            strategy.withDefaultOffsetX(dialogConfig.position.offsetX);
        }
        strategy.positionChanges
            .pipe(takeUntil(this._destroyed))
            .subscribe((change) => {
            this._updateCurrentPositionClass(change.connectionPair);
        });
        let maxWidth = this.calculatePopoverMaxWidth(dialogConfig.maxWidth, dialogConfig.popoverAnchor);
        this._overlayRef = this._overlay.create({
            positionStrategy: strategy,
            scrollStrategy: dialogConfig.scrollStrategy || this._scrollStrategy(),
            hasBackdrop: dialogConfig.hasBackdrop,
            direction: dialogConfig.direction,
            minWidth: dialogConfig.minWidth,
            minHeight: dialogConfig.minHeight,
            maxWidth: maxWidth,
            maxHeight: dialogConfig.maxHeight,
            disposeOnNavigation: dialogConfig.closeOnNavigation,
            panelClass: 'mat-popover-container',
            backdropClass: 'cdk-overlay-transparent-backdrop'
        });
        if (dialogConfig.popover) {
            // Apply legacy predefined padding
            this._overlayRef.addPanelClass('mat-popover-predefined-container');
        }
        if (dialogConfig.panelClass) {
            this._overlayRef.addPanelClass(dialogConfig.panelClass);
        }
        this.popoverStemFlexiblePosition(dialogConfig, anchorElementRef);
        return this._overlayRef;
    }
    /**
     * Determines the amount of space to the left and right of the anchor. If the
     * config'd width is smaller than the available space on one side or the other,
     * we return the config'd width. If config'd width is less than space to left or
     * right we return the wider of the two. The flexible connect strategy will take
     * care of the which side to place it on.
     *
     * @param configWidth The width passed in the DialogConfig
     * @param anchorElementRef Anchor trigger for the popover
     * @returns maxWidth lesser of config'd withd or space to left/right of anchor.
     */
    calculatePopoverMaxWidth(configWidth, anchorElementRef) {
        const anchorDOMRect = anchorElementRef.nativeElement.getBoundingClientRect();
        const anchorX = anchorDOMRect.x;
        const pageWidth = window.innerWidth;
        const anchorWidth = anchorDOMRect.width;
        const spaceRight = pageWidth - (anchorX + anchorWidth);
        const maxWidth = Math.max(anchorX, spaceRight) - 20;
        // If there's room we just use the value from the config, if not we override it
        return configWidth < maxWidth ? configWidth : maxWidth;
    }
    /**
     * Sets the CSS value for Psuedo ::before and ::after
     * position for the popover stem
     * @param dialogConfig The dialog configuration
     * @param anchorElementRef The Element Ref
     */
    popoverStemFlexiblePosition(dialogConfig, anchorElementRef) {
        setTimeout(() => {
            const overlayElement = this._overlayRef.overlayElement;
            const dialogElement = overlayElement.querySelector('.mat-dialog-container');
            const overlayElementUniqueId = overlayElement.id;
            const stylesheet = document.styleSheets[0];
            const popoverPosition = dialogConfig.popoverPosition;
            const dialogBorderRadius = parseInt(getComputedStyle(dialogElement).borderRadius);
            // the absolute x/y position of the stem should place it in
            // the middle of the anchor unless the overlay is more than 12px
            // out of line with the anchor...
            // offset to always attach stem to the overlay
            const customOffsetStemPosition = this._viewportMargin + dialogBorderRadius;
            // Get the anchor dimensions and location:
            const anchorDOMRect = anchorElementRef.nativeElement.getBoundingClientRect();
            const anchorX = anchorDOMRect.x;
            const anchorY = anchorDOMRect.y;
            if (popoverPosition === 'below' || popoverPosition === 'above') {
                const anchorWidth = anchorElementRef.nativeElement.offsetWidth;
                const overlayX = overlayElement.getBoundingClientRect().x;
                let flexibleStemPositionLeft = anchorX - overlayX + anchorWidth / 2;
                flexibleStemPositionLeft =
                    flexibleStemPositionLeft <= customOffsetStemPosition
                        ? customOffsetStemPosition
                        : flexibleStemPositionLeft;
                stylesheet.insertRule(`#${overlayElementUniqueId}.mat-popover-${this._currentPosition}::before, #${overlayElementUniqueId}.mat-popover-${this._currentPosition}::after {left: ${flexibleStemPositionLeft}px;opacity:1;color: rgba( 0, 0, 0, 0.15 );transition-duration: 100ms;}`, // opacity for FOUC
                0);
            }
            else if (popoverPosition === 'before' ||
                popoverPosition === 'after' ||
                popoverPosition === 'right' ||
                popoverPosition === 'left') {
                const overlayY = overlayElement.getBoundingClientRect().y;
                let a = {
                    mid: anchorY + 0.5 * anchorDOMRect.height
                };
                let o = {
                    top: overlayY,
                    bottom: overlayY + overlayElement.getBoundingClientRect().height,
                    height: overlayElement.getBoundingClientRect().height
                };
                let stemTop = 0;
                if (a.mid > o.top + 8 && a.mid < o.bottom - 8) {
                    stemTop = a.mid - o.top - 9;
                }
                else if (a.mid > o.bottom - 22) {
                    stemTop = o.height - 22;
                }
                stylesheet.insertRule(`#${overlayElementUniqueId}.mat-popover-${this._currentPosition}::before, #${overlayElementUniqueId}.mat-popover-${this._currentPosition}::after {top: ${stemTop}px;opacity:1;color: rgba( 0, 0, 0, 0.15 );transition-duration: 100ms;}`, // opacity for FOUC transition: opacity 200ms ease-in;
                0);
            }
        });
    }
    /**
     * Creates an overlay config from a dialog config.
     * @param dialogConfig The dialog configuration.
     * @returns The overlay configuration.
     */
    _getOverlayConfig(dialogConfig) {
        const state = new OverlayConfig({
            positionStrategy: this._overlay.position().global(),
            scrollStrategy: dialogConfig.scrollStrategy || this._scrollStrategy(),
            panelClass: dialogConfig.panelClass,
            hasBackdrop: dialogConfig.hasBackdrop,
            direction: dialogConfig.direction,
            minWidth: dialogConfig.minWidth,
            minHeight: dialogConfig.minHeight,
            maxWidth: dialogConfig.maxWidth,
            maxHeight: dialogConfig.maxHeight,
            disposeOnNavigation: dialogConfig.closeOnNavigation
        });
        if (dialogConfig.backdropClass) {
            state.backdropClass = dialogConfig.backdropClass;
        }
        return state;
    }
    // VDL change: specific to popover
    /** Updates the class on the overlay panel based on the current position of the popover. */
    _updateCurrentPositionClass(connectionPair) {
        const { overlayY, originX, originY } = connectionPair;
        let newPosition;
        // If the overlay is in the middle along the Y axis,
        // it means that it's either before or after.
        if (overlayY === 'center') {
            // Note that since this information is used for styling, we want to
            // resolve `start` and `end` to their real values, otherwise consumers
            // would have to remember to do it themselves on each consumption.
            if (this._config.direction && this._config.direction === 'rtl') {
                newPosition = originX === 'end' ? 'before' : 'after';
            }
            else {
                newPosition = originX === 'start' ? 'before' : 'after';
            }
        }
        else {
            newPosition =
                overlayY === 'bottom' && originY === 'top' ? 'above' : 'below';
        }
        if (newPosition !== this._currentPosition) {
            const overlayRef = this._overlayRef;
            if (overlayRef) {
                const classPrefix = 'mat-popover-';
                overlayRef.removePanelClass(classPrefix + this._currentPosition);
                overlayRef.addPanelClass(classPrefix + newPosition);
            }
            this._currentPosition = newPosition;
        }
    }
    /**
     * Attaches a dialog container to a dialog's already-created overlay.
     * @param overlay Reference to the dialog's underlying overlay.
     * @param config The dialog configuration.
     * @returns A promise resolving to a ComponentRef for the attached container.
     */
    _attachDialogContainer(overlay, config) {
        const userInjector = config && config.viewContainerRef && config.viewContainerRef.injector;
        const injector = Injector.create({
            parent: userInjector || this._injector,
            providers: [{ provide: MatDialogConfig, useValue: config }]
        });
        const containerPortal = new ComponentPortal(this._dialogContainerType, config.viewContainerRef, injector, config.componentFactoryResolver);
        const containerRef = overlay.attach(containerPortal);
        return containerRef.instance;
    }
    /**
     * Attaches the user-provided component to the already-created dialog container.
     * @param componentOrTemplateRef The type of component being loaded into the dialog,
     *     or a TemplateRef to instantiate as the content.
     * @param dialogContainer Reference to the wrapping dialog container.
     * @param overlayRef Reference to the overlay in which the dialog resides.
     * @param config The dialog configuration.
     * @returns A promise resolving to the MatDialogRef that should be returned to the user.
     */
    _attachDialogContent(componentOrTemplateRef, dialogContainer, overlayRef, config) {
        // Create a reference to the dialog we're creating in order to give the user a handle
        // to modify and close it.
        const dialogRef = new this._dialogRefConstructor(overlayRef, dialogContainer, config.id);
        // VDL change: specific for popover
        if (config.popover === true) {
            // When the popover backdrop is clicked, we want to close it.
            // we always close the popover on backdrop click unless the user
            // clicked on the popover anchor/trigger.
            overlayRef.backdropClick().subscribe((click) => {
                // https://github.com/angular/components/issues/14361
                if (this._clickedInAnchor(click, config.popoverAnchor) ===
                    false) {
                    dialogRef.close();
                }
            });
            // Close the overlay when scroll is attempted
            overlayRef.backdropElement.addEventListener('wheel', () => {
                overlayRef.dispose();
            });
        }
        if (componentOrTemplateRef instanceof TemplateRef) {
            dialogContainer.attachTemplatePortal(new TemplatePortal(componentOrTemplateRef, null, {
                $implicit: config.data,
                dialogRef
            }));
        }
        else {
            const injector = this._createInjector(config, dialogRef, dialogContainer);
            const contentRef = dialogContainer.attachComponentPortal(new ComponentPortal(componentOrTemplateRef, config.viewContainerRef, injector, config.componentFactoryResolver));
            dialogRef.componentInstance = contentRef.instance;
        }
        // VDL change: specific for popover
        if (config.popover === true) {
            dialogRef
                .updateSize(config.width, config.height)
                .updatePopoverPosition(overlayRef);
            return dialogRef;
        }
        else {
            dialogRef
                .updateSize(config.width, config.height)
                .updatePosition(config.position);
            return dialogRef;
        }
    }
    // VDL change: specific for popover
    _clickedInAnchor(clickEvent, anchor) {
        // non-angular components, e.g. document.body will not have a bounding rect
        if (anchor.nativeElement && anchor.nativeElement.getBoundingClientRect) {
            const { left, right, top, bottom } = anchor.nativeElement.getBoundingClientRect();
            const { pageX, pageY } = clickEvent;
            return pageX >= left && pageX <= right && pageY >= top && pageY <= bottom;
        }
        return undefined;
    }
    /**
     * Creates a custom injector to be used inside the dialog. This allows a component loaded inside
     * of a dialog to close itself and, optionally, to return a value.
     * @param config Config object that is used to construct the dialog.
     * @param dialogRef Reference to the dialog.
     * @param dialogContainer Dialog container element that wraps all of the contents.
     * @returns The custom injector that can be used inside the dialog.
     */
    _createInjector(config, dialogRef, dialogContainer) {
        const userInjector = config && config.viewContainerRef && config.viewContainerRef.injector;
        // The dialog container should be provided as the dialog container and the dialog's
        // content are created out of the same `ViewContainerRef` and as such, are siblings
        // for injector purposes. To allow the hierarchy that is expected, the dialog
        // container is explicitly provided in the injector.
        const providers = [
            { provide: this._dialogContainerType, useValue: dialogContainer },
            { provide: this._dialogDataToken, useValue: config.data },
            { provide: this._dialogRefConstructor, useValue: dialogRef }
        ];
        if (config.direction &&
            (!userInjector ||
                !userInjector.get(Directionality, null, InjectFlags.Optional))) {
            providers.push({
                provide: Directionality,
                useValue: { value: config.direction, change: of() }
            });
        }
        return Injector.create({
            parent: userInjector || this._injector,
            providers
        });
    }
    /**
     * Removes a dialog from the array of open dialogs.
     * @param dialogRef Dialog to be removed.
     */
    _removeOpenDialog(dialogRef) {
        const index = this.openDialogs.indexOf(dialogRef);
        // VDL change: reset the overlayref and current position to default for popover
        if (this._overlayRef) {
            this._overlayRef = null;
            this._currentPosition = 'after';
        }
        if (index > -1) {
            this.openDialogs.splice(index, 1);
            // If all the dialogs were closed, remove/restore the `aria-hidden`
            // to a the siblings and emit to the `afterAllClosed` stream.
            if (!this.openDialogs.length) {
                this._ariaHiddenElements.forEach((previousValue, element) => {
                    if (previousValue) {
                        element.setAttribute('aria-hidden', previousValue);
                    }
                    else {
                        element.removeAttribute('aria-hidden');
                    }
                });
                this._ariaHiddenElements.clear();
                this._getAfterAllClosed().next();
            }
        }
    }
    /**
     * Hides all of the content that isn't an overlay from assistive technology.
     */
    _hideNonDialogContentFromAssistiveTechnology() {
        const overlayContainer = this._overlayContainer.getContainerElement();
        // Ensure that the overlay container is attached to the DOM.
        if (overlayContainer.parentElement) {
            const siblings = overlayContainer.parentElement.children;
            for (let i = siblings.length - 1; i > -1; i--) {
                let sibling = siblings[i];
                if (sibling !== overlayContainer &&
                    sibling.nodeName !== 'SCRIPT' &&
                    sibling.nodeName !== 'STYLE' &&
                    !sibling.hasAttribute('aria-live')) {
                    this._ariaHiddenElements.set(sibling, sibling.getAttribute('aria-hidden'));
                    sibling.setAttribute('aria-hidden', 'true');
                }
            }
        }
    }
    /** Closes all of the dialogs in an array. */
    _closeDialogs(dialogs) {
        let i = dialogs.length;
        while (i--) {
            // The `_openDialogs` property isn't updated after close until the rxjs subscription
            // runs on the next microtask, in addition to modifying the array as we're going
            // through it. We loop through all of them and call close without assuming that
            // they'll be removed from the list instantaneously.
            dialogs[i].close();
        }
    }
}
_MatDialogBase.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: _MatDialogBase, deps: "invalid", target: i0.ɵɵFactoryTarget.Directive });
_MatDialogBase.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.3.11", type: _MatDialogBase, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: _MatDialogBase, decorators: [{
            type: Directive
        }], ctorParameters: function () { return [{ type: i1$1.Overlay }, { type: i0.Injector }, { type: undefined }, { type: undefined }, { type: i1$1.OverlayContainer }, { type: undefined }, { type: i0.Type }, { type: i0.Type }, { type: i0.InjectionToken }, { type: undefined }]; } });
/**
 * Service to open Material Design modal dialogs.
 */
class MatDialog extends _MatDialogBase {
    constructor(overlay, injector, 
    /**
     * @deprecated `_location` parameter to be removed.
     * @breaking-change 10.0.0
     */
    location, defaultOptions, scrollStrategy, parentDialog, overlayContainer, 
    /**
     * @deprecated No longer used. To be removed.
     * @breaking-change 14.0.0
     */
    animationMode) {
        super(overlay, injector, defaultOptions, parentDialog, overlayContainer, scrollStrategy, MatDialogRef, MatDialogContainer, MAT_DIALOG_DATA, animationMode);
    }
}
MatDialog.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatDialog, deps: [{ token: i1$1.Overlay }, { token: i0.Injector }, { token: i2.Location, optional: true }, { token: MAT_DIALOG_DEFAULT_OPTIONS, optional: true }, { token: MAT_DIALOG_SCROLL_STRATEGY }, { token: MatDialog, optional: true, skipSelf: true }, { token: i1$1.OverlayContainer }, { token: ANIMATION_MODULE_TYPE, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
MatDialog.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatDialog });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatDialog, decorators: [{
            type: Injectable
        }], ctorParameters: function () {
        return [{ type: i1$1.Overlay }, { type: i0.Injector }, { type: i2.Location, decorators: [{
                        type: Optional
                    }] }, { type: MatDialogConfig, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [MAT_DIALOG_DEFAULT_OPTIONS]
                    }] }, { type: undefined, decorators: [{
                        type: Inject,
                        args: [MAT_DIALOG_SCROLL_STRATEGY]
                    }] }, { type: MatDialog, decorators: [{
                        type: Optional
                    }, {
                        type: SkipSelf
                    }] }, { type: i1$1.OverlayContainer }, { type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [ANIMATION_MODULE_TYPE]
                    }] }];
    } });
/**
 * Applies default options to the dialog config.
 * @param config Config to be modified.
 * @param defaultOptions Default options provided.
 * @returns The new configuration object.
 */
function _applyConfigDefaults(config, defaultOptions) {
    return Object.assign(Object.assign({}, defaultOptions), config);
}

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
/** Counter used to generate unique IDs for dialog elements. */
let dialogElementUid = 0;
/**
 * Button that will close the current dialog.
 */
class MatDialogClose {
    constructor(
    /**
     * Reference to the containing dialog.
     * @deprecated `dialogRef` property to become private.
     * @breaking-change 13.0.0
     */
    // The dialog title directive is always used in combination with a `MatDialogRef`.
    // tslint:disable-next-line: lightweight-tokens
    dialogRef, _elementRef, _dialog) {
        this.dialogRef = dialogRef;
        this._elementRef = _elementRef;
        this._dialog = _dialog;
        /** Default to "button" to prevents accidental form submits. */
        this.type = 'button';
    }
    ngOnInit() {
        if (!this.dialogRef) {
            // When this directive is included in a dialog via TemplateRef (rather than being
            // in a Component), the DialogRef isn't available via injection because embedded
            // views cannot be given a custom injector. Instead, we look up the DialogRef by
            // ID. This must occur in `onInit`, as the ID binding for the dialog container won't
            // be resolved at constructor time.
            this.dialogRef = getClosestDialog(this._elementRef, this._dialog.openDialogs);
        }
    }
    ngOnChanges(changes) {
        const proxiedChange = changes['_matDialogClose'] || changes['_matDialogCloseResult'];
        if (proxiedChange) {
            this.dialogResult = proxiedChange.currentValue;
        }
    }
    _onButtonClick(event) {
        // Determinate the focus origin using the click event, because using the FocusMonitor will
        // result in incorrect origins. Most of the time, close buttons will be auto focused in the
        // dialog, and therefore clicking the button won't result in a focus change. This means that
        // the FocusMonitor won't detect any origin change, and will always output `program`.
        _closeDialogVia(this.dialogRef, event.screenX === 0 && event.screenY === 0 ? 'keyboard' : 'mouse', this.dialogResult);
    }
}
MatDialogClose.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatDialogClose, deps: [{ token: MatDialogRef, optional: true }, { token: i0.ElementRef }, { token: MatDialog }], target: i0.ɵɵFactoryTarget.Directive });
MatDialogClose.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.3.11", type: MatDialogClose, selector: "[mat-dialog-close], [matDialogClose]", inputs: { ariaLabel: ["aria-label", "ariaLabel"], type: "type", dialogResult: ["mat-dialog-close", "dialogResult"], _matDialogClose: ["matDialogClose", "_matDialogClose"] }, host: { listeners: { "click": "_onButtonClick($event)" }, properties: { "attr.aria-label": "ariaLabel || null", "attr.type": "type" } }, exportAs: ["matDialogClose"], usesOnChanges: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatDialogClose, decorators: [{
            type: Directive,
            args: [{
                    selector: '[mat-dialog-close], [matDialogClose]',
                    exportAs: 'matDialogClose',
                    host: {
                        '(click)': '_onButtonClick($event)',
                        '[attr.aria-label]': 'ariaLabel || null',
                        '[attr.type]': 'type'
                    }
                }]
        }], ctorParameters: function () {
        return [{ type: MatDialogRef, decorators: [{
                        type: Optional
                    }] }, { type: i0.ElementRef }, { type: MatDialog }];
    }, propDecorators: { ariaLabel: [{
                type: Input,
                args: ['aria-label']
            }], type: [{
                type: Input
            }], dialogResult: [{
                type: Input,
                args: ['mat-dialog-close']
            }], _matDialogClose: [{
                type: Input,
                args: ['matDialogClose']
            }] } });
// VDL Change: Dialog header and header actions
/**
 * Header of a dialog element. Stays fixed to the top of the dialog when scrolling.
 */
class MatDialogHeader {
}
MatDialogHeader.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatDialogHeader, deps: [], target: i0.ɵɵFactoryTarget.Directive });
MatDialogHeader.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.3.11", type: MatDialogHeader, selector: "mat-dialog-header", host: { classAttribute: "mat-dialog-header" }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatDialogHeader, decorators: [{
            type: Directive,
            args: [{
                    selector: 'mat-dialog-header',
                    host: {
                        class: 'mat-dialog-header'
                    }
                }]
        }] });
/**
 * Header actions of a dialog element. Stays fixed to the top of the dialog when scrolling.
 */
class MatDialogHeaderActions {
}
MatDialogHeaderActions.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatDialogHeaderActions, deps: [], target: i0.ɵɵFactoryTarget.Directive });
MatDialogHeaderActions.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.3.11", type: MatDialogHeaderActions, selector: "mat-dialog-header-actions", host: { classAttribute: "mat-dialog-header-actions" }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatDialogHeaderActions, decorators: [{
            type: Directive,
            args: [{
                    selector: 'mat-dialog-header-actions',
                    host: {
                        class: 'mat-dialog-header-actions'
                    }
                }]
        }] });
/**
 * Title of a dialog element. Stays fixed to the top of the dialog when scrolling.
 */
class MatDialogTitle {
    constructor(
    // The dialog title directive is always used in combination with a `MatDialogRef`.
    // tslint:disable-next-line: lightweight-tokens
    _dialogRef, _elementRef, _dialog) {
        this._dialogRef = _dialogRef;
        this._elementRef = _elementRef;
        this._dialog = _dialog;
        /** Unique id for the dialog title. If none is supplied, it will be auto-generated. */
        this.id = `mat-dialog-title-${dialogElementUid++}`;
    }
    ngOnInit() {
        if (!this._dialogRef) {
            this._dialogRef = getClosestDialog(this._elementRef, this._dialog.openDialogs);
        }
        if (this._dialogRef) {
            Promise.resolve().then(() => {
                const container = this._dialogRef._containerInstance;
                if (container && !container._ariaLabelledBy) {
                    container._ariaLabelledBy = this.id;
                }
            });
        }
    }
}
MatDialogTitle.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatDialogTitle, deps: [{ token: MatDialogRef, optional: true }, { token: i0.ElementRef }, { token: MatDialog }], target: i0.ɵɵFactoryTarget.Directive });
MatDialogTitle.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.3.11", type: MatDialogTitle, selector: "[mat-dialog-title], [matDialogTitle], mat-dialog-title", inputs: { id: "id" }, host: { properties: { "id": "id" }, classAttribute: "mat-dialog-title" }, exportAs: ["matDialogTitle"], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatDialogTitle, decorators: [{
            type: Directive,
            args: [{
                    selector: '[mat-dialog-title], [matDialogTitle], mat-dialog-title',
                    exportAs: 'matDialogTitle',
                    host: {
                        class: 'mat-dialog-title',
                        '[id]': 'id'
                    }
                }]
        }], ctorParameters: function () {
        return [{ type: MatDialogRef, decorators: [{
                        type: Optional
                    }] }, { type: i0.ElementRef }, { type: MatDialog }];
    }, propDecorators: { id: [{
                type: Input
            }] } });
/**
 * Scrollable content container of a dialog.
 */
class MatDialogContent {
}
MatDialogContent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatDialogContent, deps: [], target: i0.ɵɵFactoryTarget.Directive });
MatDialogContent.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.3.11", type: MatDialogContent, selector: "[mat-dialog-content], mat-dialog-content, [matDialogContent]", host: { classAttribute: "mat-dialog-content" }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatDialogContent, decorators: [{
            type: Directive,
            args: [{
                    selector: `[mat-dialog-content], mat-dialog-content, [matDialogContent]`,
                    host: { class: 'mat-dialog-content' }
                }]
        }] });
/**
 * Container for the bottom action buttons in a dialog.
 * Stays fixed to the bottom when scrolling.
 */
class MatDialogActions {
}
MatDialogActions.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatDialogActions, deps: [], target: i0.ɵɵFactoryTarget.Directive });
MatDialogActions.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.3.11", type: MatDialogActions, selector: "[mat-dialog-actions], mat-dialog-actions, [matDialogActions]", host: { classAttribute: "mat-dialog-actions" }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatDialogActions, decorators: [{
            type: Directive,
            args: [{
                    selector: `[mat-dialog-actions], mat-dialog-actions, [matDialogActions]`,
                    host: { class: 'mat-dialog-actions' }
                }]
        }] });
/**
 * Finds the closest MatDialogRef to an element by looking at the DOM.
 * @param element Element relative to which to look for a dialog.
 * @param openDialogs References to the currently-open dialogs.
 */
function getClosestDialog(element, openDialogs) {
    let parent = element.nativeElement.parentElement;
    while (parent && !parent.classList.contains('mat-dialog-container')) {
        parent = parent.parentElement;
    }
    return parent ? openDialogs.find((dialog) => dialog.id === parent.id) : null;
}

class MatPopoverPredefined {
    constructor(matIconRegistry, _viewContainerRef, popoverService) {
        this._viewContainerRef = _viewContainerRef;
        this.popoverService = popoverService;
        /** Position of a popover. Accepts: `'left'`, `'right'`, `'above'`, `'below'`, `'before'`, `'after'` */
        this.matPopoverPosition = 'right';
        /** Disable the popover predefined button when true, otherwise enabled. */
        this.disabled = false;
        /** Emitter to return mat-dialog-action result from the popover. */
        this.afterClosed = new EventEmitter();
        /** Whether popover is open or not */
        this._popoverOpen = false;
        matIconRegistry.registerFontClassAlias('fontawesome', 'fa');
    }
    show(event) {
        event.stopPropagation();
        if (this.disabled) {
            return;
        }
        this.config = {
            popover: true,
            ariaLabel: this.matPopoverPredefinedAriaLabel,
            popoverAnchor: this.anchorButton,
            viewContainerRef: this._viewContainerRef,
            popoverPosition: this.matPopoverPosition
        };
        if (!this.matPopoverTemplate) {
            this.matPopoverTemplate = this.predefinedContentTemplate;
        }
        this.popoverRef = this.popoverService.open(this.matPopoverTemplate, this.config);
        // Should we keep this? I don't see the use case for popover events in the same was as for a dialog.
        // this.vdlPopoverOpen.emit(true);
        this._popoverOpen = true;
        this.popoverRef.afterClosed().subscribe((result) => {
            this._popoverOpen = false;
            this.afterClosed.emit(result); // relay the results to the application
        });
    }
}
MatPopoverPredefined.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatPopoverPredefined, deps: [{ token: i1$2.MatIconRegistry }, { token: i0.ViewContainerRef }, { token: MatDialog }], target: i0.ɵɵFactoryTarget.Component });
MatPopoverPredefined.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.11", type: MatPopoverPredefined, selector: "mat-popover-predefined", inputs: { matPredefinedPopoverType: "matPredefinedPopoverType", matPredefinedPopoverIcon: "matPredefinedPopoverIcon", matPopoverPosition: "matPopoverPosition", ariaLabel: "ariaLabel", matPopoverPredefinedAriaLabel: "matPopoverPredefinedAriaLabel", disabled: "disabled", matPopoverTemplate: "matPopoverTemplate" }, outputs: { afterClosed: "afterClosed" }, host: { listeners: { "click": "show($event)" }, properties: { "class.mat-popover-predefined": "true", "class.mat-popover-open": "_popoverOpen" } }, viewQueries: [{ propertyName: "anchorButton", first: true, predicate: ["anchor"], descendants: true, read: ElementRef, static: true }, { propertyName: "predefinedContentTemplate", first: true, predicate: ["predefinedContentTemplate"], descendants: true, read: TemplateRef, static: true }], ngImport: i0, template: "<button mat-icon-button\n        #anchor\n        type=\"button\"\n        [disabled]=\"disabled\"\n        [color]=\"matPredefinedPopoverType === 'error' ? 'error' : null\"\n        [attr.aria-label]=\"ariaLabel\">\n  <mat-icon *ngIf=\"matPredefinedPopoverType === 'info'\"\n            fontSet=\"material-symbols-outlined\"\n            class=\"mat-icon-filled\">info</mat-icon>\n  <mat-icon *ngIf=\"matPredefinedPopoverType === 'error'\"\n            fontSet=\"material-symbols-outlined\"\n            class=\"mat-icon-filled\">error</mat-icon>\n  <mat-icon *ngIf=\"matPredefinedPopoverType === 'custom'\"\n            fontSet=\"material-symbols-outlined\">{{matPredefinedPopoverIcon}}</mat-icon>\n</button>\n\n<ng-template #predefinedContentTemplate>\n  <ng-content></ng-content>\n</ng-template>", styles: [".mat-popover-predefined{display:inline-block}.mat-popover-predefined>button[mat-icon-button]{display:flex;padding:0;line-height:0;align-items:center;justify-content:center}.mat-popover-predefined>button[mat-icon-button]:hover,.mat-popover-predefined>button[mat-icon-button].hover{cursor:pointer}.mat-popover-predefined>button[mat-icon-button][disabled]{cursor:default}.mat-popover-predefined-container{overscroll-behavior-y:contain;margin-right:10px}.mat-popover-predefined-container .mat-dialog-content{overscroll-behavior-y:contain;overflow:auto;max-height:150px;max-width:400px;min-width:250px}.popover-header~.popover-container .predefined-content-template{padding-top:0}\n"], components: [{ type: i3$1.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { type: i1$2.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }], directives: [{ type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }], viewProviders: [MatIconRegistry], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatPopoverPredefined, decorators: [{
            type: Component,
            args: [{ selector: 'mat-popover-predefined', viewProviders: [MatIconRegistry], encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, host: {
                        '[class.mat-popover-predefined]': 'true',
                        '[class.mat-popover-open]': '_popoverOpen',
                        '(click)': 'show($event)' // open on host element click, usually button
                    }, template: "<button mat-icon-button\n        #anchor\n        type=\"button\"\n        [disabled]=\"disabled\"\n        [color]=\"matPredefinedPopoverType === 'error' ? 'error' : null\"\n        [attr.aria-label]=\"ariaLabel\">\n  <mat-icon *ngIf=\"matPredefinedPopoverType === 'info'\"\n            fontSet=\"material-symbols-outlined\"\n            class=\"mat-icon-filled\">info</mat-icon>\n  <mat-icon *ngIf=\"matPredefinedPopoverType === 'error'\"\n            fontSet=\"material-symbols-outlined\"\n            class=\"mat-icon-filled\">error</mat-icon>\n  <mat-icon *ngIf=\"matPredefinedPopoverType === 'custom'\"\n            fontSet=\"material-symbols-outlined\">{{matPredefinedPopoverIcon}}</mat-icon>\n</button>\n\n<ng-template #predefinedContentTemplate>\n  <ng-content></ng-content>\n</ng-template>", styles: [".mat-popover-predefined{display:inline-block}.mat-popover-predefined>button[mat-icon-button]{display:flex;padding:0;line-height:0;align-items:center;justify-content:center}.mat-popover-predefined>button[mat-icon-button]:hover,.mat-popover-predefined>button[mat-icon-button].hover{cursor:pointer}.mat-popover-predefined>button[mat-icon-button][disabled]{cursor:default}.mat-popover-predefined-container{overscroll-behavior-y:contain;margin-right:10px}.mat-popover-predefined-container .mat-dialog-content{overscroll-behavior-y:contain;overflow:auto;max-height:150px;max-width:400px;min-width:250px}.popover-header~.popover-container .predefined-content-template{padding-top:0}\n"] }]
        }], ctorParameters: function () { return [{ type: i1$2.MatIconRegistry }, { type: i0.ViewContainerRef }, { type: MatDialog }]; }, propDecorators: { matPredefinedPopoverType: [{
                type: Input
            }], matPredefinedPopoverIcon: [{
                type: Input
            }], matPopoverPosition: [{
                type: Input
            }], ariaLabel: [{
                type: Input
            }], matPopoverPredefinedAriaLabel: [{
                type: Input
            }], disabled: [{
                type: Input
            }], matPopoverTemplate: [{
                type: Input
            }], afterClosed: [{
                type: Output
            }], anchorButton: [{
                type: ViewChild,
                args: ['anchor', { static: true, read: ElementRef }]
            }], predefinedContentTemplate: [{
                type: ViewChild,
                args: ['predefinedContentTemplate', { static: true, read: TemplateRef }]
            }] } });

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
class MatDialogModule {
}
MatDialogModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatDialogModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
MatDialogModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatDialogModule, declarations: [MatDialogContainer,
        MatDialogClose,
        MatDialogHeader,
        MatDialogHeaderActions,
        MatDialogTitle,
        MatDialogActions,
        MatDialogContent,
        MatPopoverPredefined], imports: [OverlayModule,
        PortalModule,
        MatIconModule,
        MatCommonModule,
        MatButtonModule,
        CommonModule], exports: [MatDialogContainer,
        MatDialogClose,
        MatDialogHeader,
        MatDialogHeaderActions,
        MatDialogTitle,
        MatDialogContent,
        MatDialogActions,
        MatPopoverPredefined,
        MatCommonModule] });
MatDialogModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatDialogModule, providers: [MatDialog, MAT_DIALOG_SCROLL_STRATEGY_PROVIDER], imports: [[
            OverlayModule,
            PortalModule,
            MatIconModule,
            MatCommonModule,
            MatButtonModule,
            CommonModule
        ], MatCommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatDialogModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        OverlayModule,
                        PortalModule,
                        MatIconModule,
                        MatCommonModule,
                        MatButtonModule,
                        CommonModule
                    ],
                    exports: [
                        MatDialogContainer,
                        MatDialogClose,
                        MatDialogHeader,
                        MatDialogHeaderActions,
                        MatDialogTitle,
                        MatDialogContent,
                        MatDialogActions,
                        MatPopoverPredefined,
                        MatCommonModule
                    ],
                    declarations: [
                        MatDialogContainer,
                        MatDialogClose,
                        MatDialogHeader,
                        MatDialogHeaderActions,
                        MatDialogTitle,
                        MatDialogActions,
                        MatDialogContent,
                        MatPopoverPredefined
                    ],
                    providers: [MatDialog, MAT_DIALOG_SCROLL_STRATEGY_PROVIDER]
                }]
        }] });

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */

/**
 * Generated bundle index. Do not edit.
 */

export { MAT_DIALOG_DATA, MAT_DIALOG_DEFAULT_OPTIONS, MAT_DIALOG_SCROLL_STRATEGY, MAT_DIALOG_SCROLL_STRATEGY_FACTORY, MAT_DIALOG_SCROLL_STRATEGY_PROVIDER, MAT_DIALOG_SCROLL_STRATEGY_PROVIDER_FACTORY, MatDialog, MatDialogActions, MatDialogClose, MatDialogConfig, MatDialogContainer, MatDialogContent, MatDialogHeader, MatDialogHeaderActions, MatDialogModule, MatDialogRef, MatDialogTitle, MatPopoverPredefined, _MatDialogBase, _MatDialogContainerBase, _closeDialogVia, matDialogAnimations, throwMatDialogContentAlreadyAttachedError };
//# sourceMappingURL=vdlx-vdl-angular-mat-dialog.mjs.map
