import { ChangeDetectorRef, ElementRef, EventEmitter, OnDestroy, QueryList } from '@angular/core';
import { MatAppBanner } from './app-banner';
import { MatAppBarContent } from './app-bar';
import * as i0 from "@angular/core";
/** Event object that is emitted when the header animation is started/complete */
export interface MatHeaderState {
    height: number;
    appBarCollapsed: boolean;
}
/**
 * Veritas design Header
 */
export declare class MatHeader implements OnDestroy {
    private _elementRef;
    private _changeDetector;
    _disableAnimation: boolean;
    _isAnimating: boolean;
    _previousScrollDirection: 'up' | 'down' | null;
    _prevScrollValue: number;
    _prevScrollValueChecked: number;
    /** Buffer required before app bar collapses on scroll down */
    scrollBuffer: Number;
    /** Whether the App Bar is Collapsed */
    get appBarCollapsed(): boolean;
    set appBarCollapsed(value: boolean);
    _appBarCollapsed: boolean;
    /** Whether to show the Page Bar */
    get hidePageBar(): boolean;
    set hidePageBar(value: boolean);
    _hidePageBar: boolean;
    /** Whether the component has been destroyed. */
    private _destroyed;
    /** App Bar Collapsed change event for two-way binding */
    readonly appBarCollapsedChange: EventEmitter<boolean>;
    /** Animation Start Event */
    readonly animationStart: EventEmitter<MatHeaderState>;
    /** Animation Complete Event */
    readonly animationDone: EventEmitter<MatHeaderState>;
    /** Header Height Change Event */
    readonly heightChange: EventEmitter<number>;
    /** App Bar reference */
    appBarRef: ElementRef<HTMLElement>;
    /** App Banner reference */
    appBanner: MatAppBanner;
    /** Reference to the App Bar Content */
    appBarContent: QueryList<MatAppBarContent>;
    constructor(_elementRef: ElementRef<HTMLElement>, _changeDetector: ChangeDetectorRef);
    ngOnDestroy(): void;
    /** Returns true if MatAppBarContent has been added to header */
    hasAppBarContent(): boolean;
    /** Returns height of header, including app bar and page bar */
    getHeight(): number;
    /** Whether header has app banner */
    hasAppBanner(): boolean;
    /** Returns the state of the app bar */
    getState(): string;
    /** App Bar animation started */
    appBarAnimationStarted(): void;
    /** App Bar animation complete */
    appBarAnimationDone(): void;
    /** Monitors the scrollElement for scroll changes and collapses or expands the App Bar */
    pageScrolledCheck(scrollElement: HTMLElement): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<MatHeader, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MatHeader, "mat-header", never, { "scrollBuffer": "scrollBuffer"; "appBarCollapsed": "appBarCollapsed"; "hidePageBar": "hidePageBar"; }, { "appBarCollapsedChange": "appBarCollapsedChange"; "animationStart": "animationStart"; "animationDone": "animationDone"; "heightChange": "heightChange"; }, ["appBanner", "appBarContent"], ["mat-app-banner", "mat-nav-panel-button, mat-product-icon", "mat-product-name", "mat-app-bar-search", "mat-app-bar-content, [mat-app-bar-content]", "[mat-app-bar-overflow]", "mat-profile-panel-button, mat-profile-user-initials", "mat-back-button", "mat-page-title, mat-breadcrumbs", "mat-page-bar-content", "[mat-page-actions-template], [mat-page-bar-overflow]"]>;
}
