import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { Injectable, Optional, SkipSelf, Directive, Component, EventEmitter, ViewEncapsulation, Input, ViewChild, Output, NgModule } from '@angular/core';
import * as i2 from '@vdlx/vdl-angular/mat/notification';
import { MatNotificationModule } from '@vdlx/vdl-angular/mat/notification';
import { Subject } from 'rxjs';

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
/** Datepicker data that requires internationalization. */
class MatLoginIntl {
    constructor() {
        /**
         * Stream that emits whenever the labels here are changed. Use this to notify
         * components if the labels have changed after initialization.
         */
        this.changes = new Subject();
        /** Company Name */
        this.veritas = 'Veritas';
        /** Login Form Divider OR label  */
        this.formDividerLabel = `or`;
        /** Login Footer Version Label  */
        this.footerVersionLabel = 'Version';
        /** Veritas copyright notice */
        this.copyright = 'Copyright &copy; Veritas Technologies LLC. All rights reserved.';
    }
}
MatLoginIntl.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatLoginIntl, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
MatLoginIntl.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatLoginIntl, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatLoginIntl, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }] });
/** @docs-private */
function MAT_LOGIN_INTL_PROVIDER_FACTORY(parentIntl) {
    return parentIntl || new MatLoginIntl();
}
/** @docs-private */
const MAT_LOGIN_INTL_PROVIDER = {
    // If there is already an LoginFormIntl available, use that. Otherwise, provide a new one.
    provide: MatLoginIntl,
    deps: [[new Optional(), new SkipSelf(), MatLoginIntl]],
    useFactory: MAT_LOGIN_INTL_PROVIDER_FACTORY
};

/* eslint-disable @angular-eslint/directive-selector */
/** Login Product Icon directive */
class MatLoginProductIcon {
}
MatLoginProductIcon.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatLoginProductIcon, deps: [], target: i0.ɵɵFactoryTarget.Directive });
MatLoginProductIcon.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.3.11", type: MatLoginProductIcon, selector: "[mat-login-product-icon]", host: { classAttribute: "mat-login-product-icon" }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatLoginProductIcon, decorators: [{
            type: Directive,
            args: [{
                    selector: '[mat-login-product-icon]',
                    host: { class: 'mat-login-product-icon' }
                }]
        }] });
/** Login Product Name component */
class MatLoginProductName {
}
MatLoginProductName.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatLoginProductName, deps: [], target: i0.ɵɵFactoryTarget.Component });
MatLoginProductName.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.11", type: MatLoginProductName, selector: "mat-login-product-name", host: { classAttribute: "mat-login-product-name" }, ngImport: i0, template: `<ng-content></ng-content>`, isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatLoginProductName, decorators: [{
            type: Component,
            args: [{
                    selector: 'mat-login-product-name',
                    template: `<ng-content></ng-content>`,
                    host: {
                        class: 'mat-login-product-name'
                    }
                }]
        }] });
/** Login component */
class MatLogin {
    constructor(_intl, _changeDetectorRef) {
        this._intl = _intl;
        this._changeDetectorRef = _changeDetectorRef;
        /** Notifications that are being displayed */
        this.notificationOpen = {
            transient: false,
            persistent: false
        };
        /** Handles queue of notifications */
        this.notificationQueue = {
            persistent: [],
            transient: []
        };
        /** Notification closed event */
        this.notificationClosedEvent = new EventEmitter();
        this._intlChanges = this._intl.changes.subscribe(() => this._changeDetectorRef.markForCheck());
    }
    ngOnDestroy() {
        this._intlChanges.unsubscribe();
    }
    /** Add transient notification to queue. Default notification type is Transient */
    addNotification(type = 'transient', notification) {
        this.notificationQueue[type].push(notification);
        this.sendNotification(type);
    }
    /** Displays next notification in the queue */
    sendNotification(type) {
        if (this.notificationQueue[type].length > 0 &&
            !this.notificationOpen[type]) {
            try {
                const newNotification = this.notificationQueue[type][0];
                this.notificationOpen[type] = true;
                this.matLoginNotification.setNotification(newNotification.message, type, newNotification.state, newNotification.buttonText, newNotification.timer);
                this.notificationQueue[type].shift();
            }
            catch (error) { }
        }
    }
    /** On notification closed handler */
    notificationClosedHandler(event) {
        this.notificationClosedEvent.emit(event.type);
        this.notificationOpen[event.type] = false;
        if (this.notificationQueue[event.type].length > 0) {
            this.sendNotification(event.type);
        }
    }
    /** Clear alllnotifications */
    clearNotifications() {
        this.notificationQueue.persistent = [];
        this.notificationQueue.transient = [];
        this.matLoginNotification.closeAll();
    }
}
MatLogin.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatLogin, deps: [{ token: MatLoginIntl }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component });
MatLogin.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.11", type: MatLogin, selector: "mat-login", inputs: { productVersion: "productVersion" }, outputs: { notificationClosedEvent: "notificationClosedEvent" }, host: { properties: { "class.mat-login": "true" } }, viewQueries: [{ propertyName: "matLoginNotification", first: true, predicate: ["matLoginNotification"], descendants: true }], ngImport: i0, template: "<div class=\"mat-login-container\">\n  <div class=\"mat-login-dialog-container\">\n\n    <div class=\"mat-login-dialog\">\n\n      <mat-notification #matLoginNotification\n                        (notificationDone)=\"notificationClosedHandler($event)\"></mat-notification>\n\n      <div class=\"mat-login-header\">\n        <ng-content select=\"[mat-login-product-icon]\"></ng-content>\n        <div class=\"mat-login-product-title\">\n          <div class=\"mat-login-header-veritas\">{{ _intl.veritas }}</div>\n          <ng-content select=\"mat-login-product-name\"></ng-content>\n        </div>\n      </div>\n\n      <div class=\"mat-login-body\">\n        <ng-content select=\"[mat-login-form]\"></ng-content>\n      </div>\n\n      <div class=\"mat-login-footer\">\n        <div class=\"product-version-label\">{{ _intl.footerVersionLabel }}</div>\n        <div class=\"product-version\">{{ productVersion }}</div>\n      </div>\n    </div>\n\n  </div>\n</div>\n\n<div class=\"mat-login-container-footer\">\n  <div class=\"mat-login-footer-veritas-logo\">\n    <svg id=\"Veritas_Logo_RGB_RED\"\n         xmlns=\"http://www.w3.org/2000/svg\"\n         width=\"150\"\n         height=\"29.435\"\n         viewBox=\"0 0 150 29.435\">\n      <path id=\"Path_2\"\n            data-name=\"Path 2\"\n            d=\"M136.162,11.306a2.013,2.013,0,0,1,2.013-2.013H146.9a3.354,3.354,0,0,1,1.2,6.485l-6.757,2.491A4.7,4.7,0,0,0,140.96,27L153.6,32.74v-4.4l-11.06-4.891a.8.8,0,0,1,.065-1.5l6.932-2.411A7.379,7.379,0,0,0,146.9,5.269h-8.721a6.038,6.038,0,0,0-6.038,6.038V32.1h4.025Z\"\n            transform=\"translate(-82.89 -3.305)\"\n            fill=\"#ab2328\" />\n      <rect id=\"Rectangle_1\"\n            data-name=\"Rectangle 1\"\n            width=\"4.026\"\n            height=\"26.834\"\n            transform=\"translate(75.449 1.964)\"\n            fill=\"#ab2328\" />\n      <path id=\"Path_3\"\n            data-name=\"Path 3\"\n            d=\"M19.918,5.269,12.713,27.614a.671.671,0,0,1-1.275,0L4.232,5.269H0L7.609,28.858a4.7,4.7,0,0,0,8.932,0l7.61-23.589Z\"\n            transform=\"translate(0 -3.305)\"\n            fill=\"#ab2328\" />\n      <path id=\"Path_4\"\n            data-name=\"Path 4\"\n            d=\"M271.022,32.1l7.2-22.345a.671.671,0,0,1,1.276,0L286.708,32.1h4.232l-7.609-23.59a4.7,4.7,0,0,0-8.932,0L266.789,32.1Z\"\n            transform=\"translate(-167.357 -3.306)\"\n            fill=\"#ab2328\" />\n      <path id=\"Path_5\"\n            data-name=\"Path 5\"\n            d=\"M75.575,9.294H88.321V5.269H75.575a6.709,6.709,0,0,0-6.709,6.709V25.395A6.709,6.709,0,0,0,75.575,32.1H88.321V28.079H75.575A2.683,2.683,0,0,1,72.891,25.4v-4.73H85.638V16.707H72.891V11.978A2.683,2.683,0,0,1,75.575,9.294Z\"\n            transform=\"translate(-43.2 -3.305)\"\n            fill=\"#ab2328\" />\n      <path id=\"Path_6\"\n            data-name=\"Path 6\"\n            d=\"M241.83,5.269H222.241V9.294h7.782V32.1h4.025V9.294h7.782Z\"\n            transform=\"translate(-139.412 -3.305)\"\n            fill=\"#ab2328\" />\n      <path id=\"Path_7\"\n            data-name=\"Path 7\"\n            d=\"M347.424,32.1a7.715,7.715,0,0,0,0-15.43h-6.709a3.69,3.69,0,0,1,0-7.379H353.8V5.269H340.715a7.715,7.715,0,0,0,0,15.43h6.709a3.69,3.69,0,0,1,0,7.379H334.342V32.1Z\"\n            transform=\"translate(-208.891 -3.305)\"\n            fill=\"#ab2328\" />\n      <path id=\"Path_8\"\n            data-name=\"Path 8\"\n            d=\"M393.332,1.964h-.349V.328H392.4V0h1.52V.328h-.588Zm1.847-.48.124-.349L395.745,0h.407V1.964h-.335V1l.007-.335-.109.277-.392,1.018h-.291L394.639.945,394.53.668l.007.335v.96H394.2V0h.407l.444,1.135Z\"\n            transform=\"translate(-246.153)\"\n            fill=\"#ab2328\" />\n    </svg>\n  </div>\n\n  <div class=\"mat-login-footer-content\">\n    <ng-content select=\"[mat-login-footer-buttons]\"></ng-content>\n\n    <div class=\"mat-login-footer-copyright\"\n         innerHTML=\"{{ _intl.copyright }}\"></div>\n  </div>\n\n</div>", styles: [".mat-login{display:flex;flex-direction:column;height:100vh;width:100vw;position:absolute;left:0;top:0;z-index:2000}.mat-login:not(.login-session-expiring) .mat-login-container{background-image:url(\"data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' xmlns:xlink='http://www.w3.org/1999/xlink' width='1920' height='1080' viewBox='0 0 1920 1080'%3E%3Cdefs%3E%3CclipPath id='clip-path'%3E%3Crect id='Rectangle_1373' data-name='Rectangle 1373' width='1920' height='1080' transform='translate(0)' fill='%23fff' stroke='%23707070' stroke-width='1'/%3E%3C/clipPath%3E%3ClinearGradient id='linear-gradient' x1='0.5' y1='1' x2='0.5' gradientUnits='objectBoundingBox'%3E%3Cstop offset='0' stop-color='%23fff'/%3E%3Cstop offset='0.553' stop-color='%23f4f5f8'/%3E%3Cstop offset='1' stop-color='%23fff'/%3E%3C/linearGradient%3E%3ClinearGradient id='linear-gradient-2' x1='0.5' y1='1' x2='0.5' gradientUnits='objectBoundingBox'%3E%3Cstop offset='0' stop-color='%23f4f5f8'/%3E%3Cstop offset='0.553' stop-color='%23f4f5f8'/%3E%3Cstop offset='1' stop-color='%23fff'/%3E%3C/linearGradient%3E%3ClinearGradient id='linear-gradient-3' x1='4.635' y1='1' x2='4.635' gradientUnits='objectBoundingBox'%3E%3Cstop offset='0.447' stop-color='%23f4f5f8'/%3E%3Cstop offset='0.999' stop-color='%23fff'/%3E%3C/linearGradient%3E%3ClinearGradient id='linear-gradient-4' x1='4.66' y1='1' x2='4.66' gradientUnits='objectBoundingBox'%3E%3Cstop offset='0' stop-color='%23fff'/%3E%3Cstop offset='0.553' stop-color='%23f4f5f8'/%3E%3C/linearGradient%3E%3ClinearGradient id='linear-gradient-5' x1='4.718' x2='4.718' y2='0' xlink:href='%23linear-gradient-3'/%3E%3ClinearGradient id='linear-gradient-6' x1='4.787' x2='4.787' y2='0' xlink:href='%23linear-gradient-4'/%3E%3ClinearGradient id='linear-gradient-7' x1='-0.033' x2='-0.033' y2='0' xlink:href='%23linear-gradient-4'/%3E%3C/defs%3E%3Cg id='background_image' data-name='background image' transform='translate(0)' clip-path='url(%23clip-path)' style='isolation: isolate'%3E%3Cg id='Group_2406' data-name='Group 2406' transform='translate(131.214 -57.46)'%3E%3Cpath id='Path_2299' data-name='Path 2299' d='M1316.651,1220.519H76.938L-317.514,0H922.2Z' transform='translate(133.442 0)' fill-rule='evenodd' fill='url(%23linear-gradient)'/%3E%3Cpath id='Path_2300' data-name='Path 2300' d='M2412.347,1220.519H1172.635L778.183,0H2017.9Z' transform='translate(228.708 0)' fill-rule='evenodd' fill='url(%23linear-gradient-2)'/%3E%3Cg id='Group_2402' data-name='Group 2402' transform='translate(-1343.127 0)'%3E%3Cpath id='Path_2305' data-name='Path 2305' d='M-1232.9,0H6.816L401.269,1220.519H-838.444Z' transform='translate(1357.469 0)' fill-rule='evenodd' fill='url(%23linear-gradient-3)'/%3E%3Cpath id='Path_2306' data-name='Path 2306' d='M-1251.307,0H-11.594L382.859,1220.519H-856.854Z' transform='translate(1355.073 0)' fill-rule='evenodd' fill='url(%23linear-gradient-4)'/%3E%3Cpath id='Path_2307' data-name='Path 2307' d='M-1293.127,0H-53.414L341.039,1220.519H-898.674Z' transform='translate(1349.632 0)' fill-rule='evenodd' fill='url(%23linear-gradient-5)'/%3E%3Cpath id='Path_2308' data-name='Path 2308' d='M-1343.127,0H-103.414L291.038,1220.519H-948.674Z' transform='translate(1343.127 0)' fill-rule='evenodd' fill='url(%23linear-gradient-6)'/%3E%3C/g%3E%3Cpath id='Path_2309' data-name='Path 2309' d='M476.988,0h697.26L1568.7,1220.519H871.441Z' transform='translate(236.815)' fill-rule='evenodd' fill='url(%23linear-gradient-7)'/%3E%3C/g%3E%3C/g%3E%3C/svg%3E\");background-size:1920px 1080px;background-repeat:no-repeat;background-position:center center}.mat-login:not(.login-session-expiring) .mat-login-container>.mat-login-dialog-container{background-image:url(\"data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' xmlns:xlink='http://www.w3.org/1999/xlink' width='620' height='620' viewBox='0 0 620 620'%3E%3Cdefs%3E%3ClinearGradient id='linear-gradient' x1='0.5' x2='0.5' y2='1' gradientUnits='objectBoundingBox'%3E%3Cstop offset='0' stop-color='%23d51d24'/%3E%3Cstop offset='1' stop-color='%23ab2328'/%3E%3C/linearGradient%3E%3C/defs%3E%3Cpath id='Path_2318' data-name='Path 2318' d='M533.741,670.707l391.165,0A24.294,24.294,0,0,0,948.063,639.1L767.829,67.694A24.284,24.284,0,0,0,744.673,50.71H353.506a24.294,24.294,0,0,0-23.157,31.609l180.236,571.4A24.283,24.283,0,0,0,533.741,670.707Z' transform='translate(-329.206 -50.71)' fill='url(%23linear-gradient)'/%3E%3C/svg%3E\");background-size:620px 620px;background-repeat:no-repeat;background-position:center center}.mat-login .mat-login-container{flex:1 1 auto;position:relative;display:flex;width:100%;justify-content:center;align-items:center}.mat-login .mat-login-container>.mat-login-dialog-container{width:100%;max-width:620px;height:100%;min-height:620px;max-height:620px;display:flex;justify-content:center;align-items:center;position:relative;flex:1 1 auto}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog{position:relative;display:flex;flex-direction:column;width:100%;max-width:400px;height:490px;padding:20px;border-radius:12px;overflow-y:auto;overflow-x:hidden}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-header{display:flex;flex-direction:row;align-items:center;margin-top:14px}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-header .mat-login-product-icon{flex:0 0 auto}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-header .mat-login-product-title{flex:1 1 auto;display:flex;flex-direction:row;padding-left:10px}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-header .mat-login-product-title .mat-login-header-veritas{flex:0 0 auto;padding-right:5px}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-header .mat-login-product-title .mat-login-product-name{flex:1 1 auto}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-body{flex:1}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-body [mat-login-form]{display:flex;flex-direction:column;padding:20px 0;margin-top:16px}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-body [mat-login-form] .mat-form-field{width:100%}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-body [mat-login-form] .mat-form-field.mat-focused .mat-form-field-outline-thick .mat-form-field-outline-start,.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-body [mat-login-form] .mat-form-field.mat-focused .mat-form-field-outline-thick .mat-form-field-outline-gap,.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-body [mat-login-form] .mat-form-field.mat-focused .mat-form-field-outline-thick .mat-form-field-outline-end{border-width:3px}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-body [mat-login-form] .mat-form-field+.mat-form-field{margin-top:6px}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-body [mat-login-form] .mat-form-field+.mat-flat-button{margin-top:12px}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-body [mat-login-form]>.mat-stroked-button+.mat-stroked-button{margin-top:16px}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-body [mat-login-form] .mat-flat-button,.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-body [mat-login-form] .mat-stroked-button{width:100%}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-footer{flex:0 0 auto;display:flex;flex-direction:row;justify-content:center;align-items:center}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-footer .product-version-label{padding:0 5px}.mat-login .mat-login-container-footer{flex:0 0 auto;min-height:max-content;display:flex;align-items:center;padding:22px 40px}.mat-login .mat-login-container-footer .mat-login-footer-veritas-logo{flex:0 0 auto}.mat-login .mat-login-container-footer .mat-login-footer-content{display:flex;flex-direction:column;flex:1 1 auto;align-items:flex-end}[dir=rtl] .mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-header .mat-login-product-title{padding-left:unset;padding-right:10px}[dir=rtl] .mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-header .mat-login-product-title .mat-login-header-veritas{padding-right:unset;padding-left:5px}.mat-login .mat-form-field>.mat-form-field-wrapper{padding-bottom:0}.mat-login .mat-form-field.mat-form-field-appearance-outline.mat-focused .mat-form-field-outline-thick{border-width:3px}.mat-login .mat-flat-button,.mat-login .mat-stroked-button{font-size:.875rem;font-family:Roboto-Medium,sans-serif}.mat-login .mat-flat-button .mat-progress-spinner,.mat-login .mat-stroked-button .mat-progress-spinner{position:absolute;right:7px;top:calc(50% - 12px)}[dir=rtl] .mat-login .mat-flat-button .mat-progress-spinner,[dir=rtl] .mat-login .mat-stroked-button .mat-progress-spinner{right:unset;left:7px}@media only screen and (min-width: 1920px),only screen and (min-height: 1080px){.mat-login.mat-login>.mat-login-container{background-size:cover}}@media only screen and (max-width: 768px){.mat-login.mat-login .mat-login-container-footer{flex-direction:column;align-items:center;min-height:75px;padding-top:15px;padding-bottom:14px}.mat-login.mat-login .mat-login-container-footer .mat-login-footer-veritas-logo{margin-bottom:10px}.mat-login.mat-login .mat-login-container-footer .mat-login-footer-content{align-items:center}}@media only screen and (max-width: 620px),only screen and (max-height: 697px),only screen and (max-height: 724px) and (max-width: 768px){.mat-login.mat-login:not(.login-session-expiring) .mat-login-container{height:100%}.mat-login.mat-login:not(.login-session-expiring) .mat-login-container>.mat-login-dialog-container{height:unset;max-height:unset}.mat-login.mat-login:not(.login-session-expiring) .mat-login-container>.mat-login-dialog-container>.mat-login-dialog{box-shadow:none}}@media only screen and (max-width: 446px){.mat-login.mat-login:not(.login-session-expiring) .mat-login-container{overflow-y:auto;align-items:unset}.mat-login.mat-login:not(.login-session-expiring) .mat-login-container>.mat-login-dialog-container{height:initial;min-height:initial;align-items:unset;width:unset}.mat-login.mat-login:not(.login-session-expiring) .mat-login-container>.mat-login-dialog-container>.mat-login-dialog{height:unset;padding:0 15px;overflow-y:unset;max-width:unset;position:relative}}html.cdk-global-scrollblock{scrollbar-width:none}html.cdk-global-scrollblock::-webkit-scrollbar{width:0;height:0}\n"], components: [{ type: i2.MatNotification, selector: "mat-notification", inputs: ["id"], outputs: ["notificationDone", "notificationButtonClicked"] }], encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatLogin, decorators: [{
            type: Component,
            args: [{ selector: 'mat-login', host: {
                        '[class.mat-login]': 'true'
                    }, encapsulation: ViewEncapsulation.None, template: "<div class=\"mat-login-container\">\n  <div class=\"mat-login-dialog-container\">\n\n    <div class=\"mat-login-dialog\">\n\n      <mat-notification #matLoginNotification\n                        (notificationDone)=\"notificationClosedHandler($event)\"></mat-notification>\n\n      <div class=\"mat-login-header\">\n        <ng-content select=\"[mat-login-product-icon]\"></ng-content>\n        <div class=\"mat-login-product-title\">\n          <div class=\"mat-login-header-veritas\">{{ _intl.veritas }}</div>\n          <ng-content select=\"mat-login-product-name\"></ng-content>\n        </div>\n      </div>\n\n      <div class=\"mat-login-body\">\n        <ng-content select=\"[mat-login-form]\"></ng-content>\n      </div>\n\n      <div class=\"mat-login-footer\">\n        <div class=\"product-version-label\">{{ _intl.footerVersionLabel }}</div>\n        <div class=\"product-version\">{{ productVersion }}</div>\n      </div>\n    </div>\n\n  </div>\n</div>\n\n<div class=\"mat-login-container-footer\">\n  <div class=\"mat-login-footer-veritas-logo\">\n    <svg id=\"Veritas_Logo_RGB_RED\"\n         xmlns=\"http://www.w3.org/2000/svg\"\n         width=\"150\"\n         height=\"29.435\"\n         viewBox=\"0 0 150 29.435\">\n      <path id=\"Path_2\"\n            data-name=\"Path 2\"\n            d=\"M136.162,11.306a2.013,2.013,0,0,1,2.013-2.013H146.9a3.354,3.354,0,0,1,1.2,6.485l-6.757,2.491A4.7,4.7,0,0,0,140.96,27L153.6,32.74v-4.4l-11.06-4.891a.8.8,0,0,1,.065-1.5l6.932-2.411A7.379,7.379,0,0,0,146.9,5.269h-8.721a6.038,6.038,0,0,0-6.038,6.038V32.1h4.025Z\"\n            transform=\"translate(-82.89 -3.305)\"\n            fill=\"#ab2328\" />\n      <rect id=\"Rectangle_1\"\n            data-name=\"Rectangle 1\"\n            width=\"4.026\"\n            height=\"26.834\"\n            transform=\"translate(75.449 1.964)\"\n            fill=\"#ab2328\" />\n      <path id=\"Path_3\"\n            data-name=\"Path 3\"\n            d=\"M19.918,5.269,12.713,27.614a.671.671,0,0,1-1.275,0L4.232,5.269H0L7.609,28.858a4.7,4.7,0,0,0,8.932,0l7.61-23.589Z\"\n            transform=\"translate(0 -3.305)\"\n            fill=\"#ab2328\" />\n      <path id=\"Path_4\"\n            data-name=\"Path 4\"\n            d=\"M271.022,32.1l7.2-22.345a.671.671,0,0,1,1.276,0L286.708,32.1h4.232l-7.609-23.59a4.7,4.7,0,0,0-8.932,0L266.789,32.1Z\"\n            transform=\"translate(-167.357 -3.306)\"\n            fill=\"#ab2328\" />\n      <path id=\"Path_5\"\n            data-name=\"Path 5\"\n            d=\"M75.575,9.294H88.321V5.269H75.575a6.709,6.709,0,0,0-6.709,6.709V25.395A6.709,6.709,0,0,0,75.575,32.1H88.321V28.079H75.575A2.683,2.683,0,0,1,72.891,25.4v-4.73H85.638V16.707H72.891V11.978A2.683,2.683,0,0,1,75.575,9.294Z\"\n            transform=\"translate(-43.2 -3.305)\"\n            fill=\"#ab2328\" />\n      <path id=\"Path_6\"\n            data-name=\"Path 6\"\n            d=\"M241.83,5.269H222.241V9.294h7.782V32.1h4.025V9.294h7.782Z\"\n            transform=\"translate(-139.412 -3.305)\"\n            fill=\"#ab2328\" />\n      <path id=\"Path_7\"\n            data-name=\"Path 7\"\n            d=\"M347.424,32.1a7.715,7.715,0,0,0,0-15.43h-6.709a3.69,3.69,0,0,1,0-7.379H353.8V5.269H340.715a7.715,7.715,0,0,0,0,15.43h6.709a3.69,3.69,0,0,1,0,7.379H334.342V32.1Z\"\n            transform=\"translate(-208.891 -3.305)\"\n            fill=\"#ab2328\" />\n      <path id=\"Path_8\"\n            data-name=\"Path 8\"\n            d=\"M393.332,1.964h-.349V.328H392.4V0h1.52V.328h-.588Zm1.847-.48.124-.349L395.745,0h.407V1.964h-.335V1l.007-.335-.109.277-.392,1.018h-.291L394.639.945,394.53.668l.007.335v.96H394.2V0h.407l.444,1.135Z\"\n            transform=\"translate(-246.153)\"\n            fill=\"#ab2328\" />\n    </svg>\n  </div>\n\n  <div class=\"mat-login-footer-content\">\n    <ng-content select=\"[mat-login-footer-buttons]\"></ng-content>\n\n    <div class=\"mat-login-footer-copyright\"\n         innerHTML=\"{{ _intl.copyright }}\"></div>\n  </div>\n\n</div>", styles: [".mat-login{display:flex;flex-direction:column;height:100vh;width:100vw;position:absolute;left:0;top:0;z-index:2000}.mat-login:not(.login-session-expiring) .mat-login-container{background-image:url(\"data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' xmlns:xlink='http://www.w3.org/1999/xlink' width='1920' height='1080' viewBox='0 0 1920 1080'%3E%3Cdefs%3E%3CclipPath id='clip-path'%3E%3Crect id='Rectangle_1373' data-name='Rectangle 1373' width='1920' height='1080' transform='translate(0)' fill='%23fff' stroke='%23707070' stroke-width='1'/%3E%3C/clipPath%3E%3ClinearGradient id='linear-gradient' x1='0.5' y1='1' x2='0.5' gradientUnits='objectBoundingBox'%3E%3Cstop offset='0' stop-color='%23fff'/%3E%3Cstop offset='0.553' stop-color='%23f4f5f8'/%3E%3Cstop offset='1' stop-color='%23fff'/%3E%3C/linearGradient%3E%3ClinearGradient id='linear-gradient-2' x1='0.5' y1='1' x2='0.5' gradientUnits='objectBoundingBox'%3E%3Cstop offset='0' stop-color='%23f4f5f8'/%3E%3Cstop offset='0.553' stop-color='%23f4f5f8'/%3E%3Cstop offset='1' stop-color='%23fff'/%3E%3C/linearGradient%3E%3ClinearGradient id='linear-gradient-3' x1='4.635' y1='1' x2='4.635' gradientUnits='objectBoundingBox'%3E%3Cstop offset='0.447' stop-color='%23f4f5f8'/%3E%3Cstop offset='0.999' stop-color='%23fff'/%3E%3C/linearGradient%3E%3ClinearGradient id='linear-gradient-4' x1='4.66' y1='1' x2='4.66' gradientUnits='objectBoundingBox'%3E%3Cstop offset='0' stop-color='%23fff'/%3E%3Cstop offset='0.553' stop-color='%23f4f5f8'/%3E%3C/linearGradient%3E%3ClinearGradient id='linear-gradient-5' x1='4.718' x2='4.718' y2='0' xlink:href='%23linear-gradient-3'/%3E%3ClinearGradient id='linear-gradient-6' x1='4.787' x2='4.787' y2='0' xlink:href='%23linear-gradient-4'/%3E%3ClinearGradient id='linear-gradient-7' x1='-0.033' x2='-0.033' y2='0' xlink:href='%23linear-gradient-4'/%3E%3C/defs%3E%3Cg id='background_image' data-name='background image' transform='translate(0)' clip-path='url(%23clip-path)' style='isolation: isolate'%3E%3Cg id='Group_2406' data-name='Group 2406' transform='translate(131.214 -57.46)'%3E%3Cpath id='Path_2299' data-name='Path 2299' d='M1316.651,1220.519H76.938L-317.514,0H922.2Z' transform='translate(133.442 0)' fill-rule='evenodd' fill='url(%23linear-gradient)'/%3E%3Cpath id='Path_2300' data-name='Path 2300' d='M2412.347,1220.519H1172.635L778.183,0H2017.9Z' transform='translate(228.708 0)' fill-rule='evenodd' fill='url(%23linear-gradient-2)'/%3E%3Cg id='Group_2402' data-name='Group 2402' transform='translate(-1343.127 0)'%3E%3Cpath id='Path_2305' data-name='Path 2305' d='M-1232.9,0H6.816L401.269,1220.519H-838.444Z' transform='translate(1357.469 0)' fill-rule='evenodd' fill='url(%23linear-gradient-3)'/%3E%3Cpath id='Path_2306' data-name='Path 2306' d='M-1251.307,0H-11.594L382.859,1220.519H-856.854Z' transform='translate(1355.073 0)' fill-rule='evenodd' fill='url(%23linear-gradient-4)'/%3E%3Cpath id='Path_2307' data-name='Path 2307' d='M-1293.127,0H-53.414L341.039,1220.519H-898.674Z' transform='translate(1349.632 0)' fill-rule='evenodd' fill='url(%23linear-gradient-5)'/%3E%3Cpath id='Path_2308' data-name='Path 2308' d='M-1343.127,0H-103.414L291.038,1220.519H-948.674Z' transform='translate(1343.127 0)' fill-rule='evenodd' fill='url(%23linear-gradient-6)'/%3E%3C/g%3E%3Cpath id='Path_2309' data-name='Path 2309' d='M476.988,0h697.26L1568.7,1220.519H871.441Z' transform='translate(236.815)' fill-rule='evenodd' fill='url(%23linear-gradient-7)'/%3E%3C/g%3E%3C/g%3E%3C/svg%3E\");background-size:1920px 1080px;background-repeat:no-repeat;background-position:center center}.mat-login:not(.login-session-expiring) .mat-login-container>.mat-login-dialog-container{background-image:url(\"data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' xmlns:xlink='http://www.w3.org/1999/xlink' width='620' height='620' viewBox='0 0 620 620'%3E%3Cdefs%3E%3ClinearGradient id='linear-gradient' x1='0.5' x2='0.5' y2='1' gradientUnits='objectBoundingBox'%3E%3Cstop offset='0' stop-color='%23d51d24'/%3E%3Cstop offset='1' stop-color='%23ab2328'/%3E%3C/linearGradient%3E%3C/defs%3E%3Cpath id='Path_2318' data-name='Path 2318' d='M533.741,670.707l391.165,0A24.294,24.294,0,0,0,948.063,639.1L767.829,67.694A24.284,24.284,0,0,0,744.673,50.71H353.506a24.294,24.294,0,0,0-23.157,31.609l180.236,571.4A24.283,24.283,0,0,0,533.741,670.707Z' transform='translate(-329.206 -50.71)' fill='url(%23linear-gradient)'/%3E%3C/svg%3E\");background-size:620px 620px;background-repeat:no-repeat;background-position:center center}.mat-login .mat-login-container{flex:1 1 auto;position:relative;display:flex;width:100%;justify-content:center;align-items:center}.mat-login .mat-login-container>.mat-login-dialog-container{width:100%;max-width:620px;height:100%;min-height:620px;max-height:620px;display:flex;justify-content:center;align-items:center;position:relative;flex:1 1 auto}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog{position:relative;display:flex;flex-direction:column;width:100%;max-width:400px;height:490px;padding:20px;border-radius:12px;overflow-y:auto;overflow-x:hidden}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-header{display:flex;flex-direction:row;align-items:center;margin-top:14px}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-header .mat-login-product-icon{flex:0 0 auto}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-header .mat-login-product-title{flex:1 1 auto;display:flex;flex-direction:row;padding-left:10px}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-header .mat-login-product-title .mat-login-header-veritas{flex:0 0 auto;padding-right:5px}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-header .mat-login-product-title .mat-login-product-name{flex:1 1 auto}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-body{flex:1}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-body [mat-login-form]{display:flex;flex-direction:column;padding:20px 0;margin-top:16px}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-body [mat-login-form] .mat-form-field{width:100%}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-body [mat-login-form] .mat-form-field.mat-focused .mat-form-field-outline-thick .mat-form-field-outline-start,.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-body [mat-login-form] .mat-form-field.mat-focused .mat-form-field-outline-thick .mat-form-field-outline-gap,.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-body [mat-login-form] .mat-form-field.mat-focused .mat-form-field-outline-thick .mat-form-field-outline-end{border-width:3px}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-body [mat-login-form] .mat-form-field+.mat-form-field{margin-top:6px}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-body [mat-login-form] .mat-form-field+.mat-flat-button{margin-top:12px}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-body [mat-login-form]>.mat-stroked-button+.mat-stroked-button{margin-top:16px}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-body [mat-login-form] .mat-flat-button,.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-body [mat-login-form] .mat-stroked-button{width:100%}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-footer{flex:0 0 auto;display:flex;flex-direction:row;justify-content:center;align-items:center}.mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-footer .product-version-label{padding:0 5px}.mat-login .mat-login-container-footer{flex:0 0 auto;min-height:max-content;display:flex;align-items:center;padding:22px 40px}.mat-login .mat-login-container-footer .mat-login-footer-veritas-logo{flex:0 0 auto}.mat-login .mat-login-container-footer .mat-login-footer-content{display:flex;flex-direction:column;flex:1 1 auto;align-items:flex-end}[dir=rtl] .mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-header .mat-login-product-title{padding-left:unset;padding-right:10px}[dir=rtl] .mat-login .mat-login-container>.mat-login-dialog-container>.mat-login-dialog>.mat-login-header .mat-login-product-title .mat-login-header-veritas{padding-right:unset;padding-left:5px}.mat-login .mat-form-field>.mat-form-field-wrapper{padding-bottom:0}.mat-login .mat-form-field.mat-form-field-appearance-outline.mat-focused .mat-form-field-outline-thick{border-width:3px}.mat-login .mat-flat-button,.mat-login .mat-stroked-button{font-size:.875rem;font-family:Roboto-Medium,sans-serif}.mat-login .mat-flat-button .mat-progress-spinner,.mat-login .mat-stroked-button .mat-progress-spinner{position:absolute;right:7px;top:calc(50% - 12px)}[dir=rtl] .mat-login .mat-flat-button .mat-progress-spinner,[dir=rtl] .mat-login .mat-stroked-button .mat-progress-spinner{right:unset;left:7px}@media only screen and (min-width: 1920px),only screen and (min-height: 1080px){.mat-login.mat-login>.mat-login-container{background-size:cover}}@media only screen and (max-width: 768px){.mat-login.mat-login .mat-login-container-footer{flex-direction:column;align-items:center;min-height:75px;padding-top:15px;padding-bottom:14px}.mat-login.mat-login .mat-login-container-footer .mat-login-footer-veritas-logo{margin-bottom:10px}.mat-login.mat-login .mat-login-container-footer .mat-login-footer-content{align-items:center}}@media only screen and (max-width: 620px),only screen and (max-height: 697px),only screen and (max-height: 724px) and (max-width: 768px){.mat-login.mat-login:not(.login-session-expiring) .mat-login-container{height:100%}.mat-login.mat-login:not(.login-session-expiring) .mat-login-container>.mat-login-dialog-container{height:unset;max-height:unset}.mat-login.mat-login:not(.login-session-expiring) .mat-login-container>.mat-login-dialog-container>.mat-login-dialog{box-shadow:none}}@media only screen and (max-width: 446px){.mat-login.mat-login:not(.login-session-expiring) .mat-login-container{overflow-y:auto;align-items:unset}.mat-login.mat-login:not(.login-session-expiring) .mat-login-container>.mat-login-dialog-container{height:initial;min-height:initial;align-items:unset;width:unset}.mat-login.mat-login:not(.login-session-expiring) .mat-login-container>.mat-login-dialog-container>.mat-login-dialog{height:unset;padding:0 15px;overflow-y:unset;max-width:unset;position:relative}}html.cdk-global-scrollblock{scrollbar-width:none}html.cdk-global-scrollblock::-webkit-scrollbar{width:0;height:0}\n"] }]
        }], ctorParameters: function () { return [{ type: MatLoginIntl }, { type: i0.ChangeDetectorRef }]; }, propDecorators: { productVersion: [{
                type: Input
            }], matLoginNotification: [{
                type: ViewChild,
                args: ['matLoginNotification']
            }], notificationClosedEvent: [{
                type: Output
            }] } });

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
class MatLoginFormDivider {
    constructor(_intl, _changeDetectorRef) {
        this._intl = _intl;
        this._changeDetectorRef = _changeDetectorRef;
        this._intlChanges = _intl.changes.subscribe(() => this._changeDetectorRef.markForCheck());
    }
    ngOnDestroy() {
        this._intlChanges.unsubscribe();
    }
}
MatLoginFormDivider.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatLoginFormDivider, deps: [{ token: MatLoginIntl }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component });
MatLoginFormDivider.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.11", type: MatLoginFormDivider, selector: "mat-login-form-divider", host: { properties: { "class.mat-login-form-divider": "true" } }, ngImport: i0, template: `<div>{{ _intl.formDividerLabel }}</div>`, isInline: true, styles: [".mat-login-form-divider{height:1px;margin:26px 0;display:flex;align-items:center;justify-content:center;border-bottom-width:1px;border-bottom-style:solid}.mat-login-form-divider>div{padding:5px 15px;vertical-align:middle}\n"], encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatLoginFormDivider, decorators: [{
            type: Component,
            args: [{ selector: 'mat-login-form-divider', template: `<div>{{ _intl.formDividerLabel }}</div>`, host: {
                        '[class.mat-login-form-divider]': 'true'
                    }, encapsulation: ViewEncapsulation.None, styles: [".mat-login-form-divider{height:1px;margin:26px 0;display:flex;align-items:center;justify-content:center;border-bottom-width:1px;border-bottom-style:solid}.mat-login-form-divider>div{padding:5px 15px;vertical-align:middle}\n"] }]
        }], ctorParameters: function () { return [{ type: MatLoginIntl }, { type: i0.ChangeDetectorRef }]; } });

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
class MatLoginModule {
}
MatLoginModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatLoginModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
MatLoginModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatLoginModule, declarations: [MatLogin, MatLoginProductName, MatLoginFormDivider], imports: [CommonModule, MatNotificationModule], exports: [MatLogin, MatLoginProductName, MatLoginFormDivider] });
MatLoginModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatLoginModule, providers: [MAT_LOGIN_INTL_PROVIDER], imports: [[CommonModule, MatNotificationModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatLoginModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, MatNotificationModule],
                    exports: [MatLogin, MatLoginProductName, MatLoginFormDivider],
                    declarations: [MatLogin, MatLoginProductName, MatLoginFormDivider],
                    providers: [MAT_LOGIN_INTL_PROVIDER]
                }]
        }] });

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */

/**
 * Generated bundle index. Do not edit.
 */

export { MAT_LOGIN_INTL_PROVIDER, MAT_LOGIN_INTL_PROVIDER_FACTORY, MatLogin, MatLoginFormDivider, MatLoginIntl, MatLoginModule, MatLoginProductIcon, MatLoginProductName };
//# sourceMappingURL=vdlx-vdl-angular-mat-login.mjs.map
