import { A11yModule } from '@angular/cdk/a11y';
import * as i4 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { Injectable, Optional, SkipSelf, InjectionToken, EventEmitter, Component, ViewEncapsulation, ChangeDetectionStrategy, Inject, Input, ViewChild, Output, NgModule } from '@angular/core';
import * as i3 from '@vdlx/vdl-angular/mat/button';
import { MatButtonModule } from '@vdlx/vdl-angular/mat/button';
import * as i2 from '@vdlx/vdl-angular/mat/icon';
import { MatIconRegistry, MatIconModule } from '@vdlx/vdl-angular/mat/icon';
import * as i5 from '@vdlx/vdl-angular/mat/tooltip';
import { MatTooltipModule } from '@vdlx/vdl-angular/mat/tooltip';
import { trigger, state, style, transition, animate } from '@angular/animations';
import { Subject } from 'rxjs';

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
const NOTIFICATION_ANIMATION_TIMING = '300ms';
/**
 * Animations used by the VDL Notification.
 * @docs-private
 */
const matNotificationAnimations = {
    /** Animation that shows and hides a snack bar. */
    notificationState: trigger('state', [
        state('closed', style({
            maxHeight: '0'
        })),
        state('open', style({
            maxHeight: '50%'
        })),
        transition('closed <=> open, void => open', animate(NOTIFICATION_ANIMATION_TIMING))
    ])
};

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
/**
 * To modify the labels and text displayed, create a new instance of MatNotificationIntl and include it in a custom provider.
 */
class MatNotificationIntl {
    constructor() {
        /**
         * Stream that emits whenever the labels here are changed. Use this to notify
         * components if the labels have changed after initialization.
         */
        this.changes = new Subject();
        /** Labels for notification states */
        this.stateLabel = {
            default: 'neutral',
            error: 'error',
            success: 'success',
            info: 'informative',
            warning: 'warning'
        };
        /** A label for the close notification button */
        this.closeNotificationButtonLabel = 'Close Notification';
    }
}
MatNotificationIntl.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatNotificationIntl, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
MatNotificationIntl.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatNotificationIntl, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatNotificationIntl, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }] });
/** @docs-private */
function MAT_NOTIFICATION_INTL_PROVIDER_FACTORY(parentIntl) {
    return parentIntl || new MatNotificationIntl();
}
/** @docs-private */
const MAT_NOTIFICATION_INTL_PROVIDER = {
    // If there is already an MatNotificationIntl available, use that. Otherwise, provide a new one.
    provide: MatNotificationIntl,
    deps: [[new Optional(), new SkipSelf(), MatNotificationIntl]],
    useFactory: MAT_NOTIFICATION_INTL_PROVIDER_FACTORY
};

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
/** Injection token to be used to override the default options for `mat-notification`. */
const MAT_NOTIFICATION_DEFAULT_OPTIONS = new InjectionToken('mat-notification-default-options', {
    providedIn: 'root',
    factory: MAT_NOTIFICATION_DEFAULT_OPTIONS_FACTORY
});
/** @docs-private */
function MAT_NOTIFICATION_DEFAULT_OPTIONS_FACTORY() {
    return { timer: MIN_TIMER };
}
const MIN_TIMER = 3000;
const MIN_TIMER_LONG_TEXT = 6000;
let nextUniqueId = 0;
/** MAT Transient and Persistent Notifications */
class MatNotification {
    constructor(_intl, _changeDetectorRef, _elementRef, defaults) {
        this._intl = _intl;
        this._changeDetectorRef = _changeDetectorRef;
        this._elementRef = _elementRef;
        this.defaults = defaults;
        this._uid = `mat-input-${nextUniqueId++}`;
        /** @docs-private */
        this.notificationIds = {
            persistent: '',
            transient: ''
        };
        this.nextNotificationId = 0;
        /** Aria-label attribute internationalized strings. */
        /** @docs-private */
        this.uniqueNotificationId = '';
        /**
         * Data pertaining to the Notifications currently in scope.
         * persistentData: { state, message, isOpen, buttonText }
         * transientData: { state, message, isOpen, buttonText, timer }
         */
        this.notificationData = {
            persistentData: {
                state: null,
                message: null,
                isOpen: false,
                buttonText: null
            },
            transientData: {
                state: null,
                message: null,
                isOpen: false,
                buttonText: null,
                timer: MIN_TIMER
            }
        };
        /**
         * Close timer reference.
         */
        this.closeTimer = null;
        /**
         * Event emitter for notification done displaying
         */
        this.notificationDone = new EventEmitter();
        /**
         * Event emitter for notification button click
         */
        this.notificationButtonClicked = new EventEmitter();
        this._intlChanges = _intl.changes.subscribe(() => this._changeDetectorRef.markForCheck());
    }
    get id() {
        return this._id;
    }
    set id(value) {
        this._id = value || this._uid;
    }
    ngOnDestroy() {
        this._intlChanges.unsubscribe();
    }
    /**
     * Returns Aria-label attribute internationalized strings for given notification state.
     * @param state MatNotificationState
     * @returns string
     */
    getStateLabel(state) {
        return this._intl.stateLabel[state];
    }
    /**
     * Returns icon name for given notification state.
     * @param state MatNotificationState
     * @returns string
     */
    getStateIcon(state) {
        const iconNames = {
            default: null,
            error: 'error',
            success: 'check_circle',
            info: 'info',
            warning: 'warning'
        };
        return iconNames[state];
    }
    /**
     * Sets up notification object within container
     * @param message Message for the Notification
     * @param type (optional) Default is MatNotificationTypes.Persistent. Use MatNotificationTypes enum
     * @param notificationState (optional) Default is MatNotificationStates.Default. Use MatNotificationStates enum
     * @param buttonText (optional) Specifying the Button text enables the notification button
     * @param timer (optional) Used in Transient notification for how long to display message in milliseconds.
     * If less than 3000 will default to 3000. Can be configured globally through the `MAT_NOTIFICATION_DEFAULT_OPTIONS` token.
     */
    setNotification(message, type = 'persistent', notificationState = 'default', buttonText = '', timer = this.defaults.timer) {
        if (!message || message.trim().length < 1) {
            throw new Error('Notification message is required');
        }
        timer = timer ? parseInt(timer.toString()) : MIN_TIMER;
        const _notificationId = `${this._uid}-${this.nextNotificationId++}`;
        this.notificationIds[type] = `notification-${type}-${_notificationId}`;
        if (type === 'transient' && timer <= MIN_TIMER) {
            timer = MIN_TIMER;
        }
        const notificationDataKey = this.getNotificationKey(type);
        if (this.notificationData[notificationDataKey].isOpen === true) {
            throw new Error(type === 'persistent'
                ? 'Persistent notification already open'
                : 'Transient notification already open');
        }
        if (type === 'transient') {
            timer =
                message.length > 72 && timer < MIN_TIMER_LONG_TEXT
                    ? MIN_TIMER_LONG_TEXT
                    : timer;
            this.notificationData.transientData.timer = timer;
        }
        this.notificationData[notificationDataKey].buttonText = buttonText;
        this.notificationData[notificationDataKey].message = message;
        this.notificationData[notificationDataKey].state = notificationState;
        this.notificationData[notificationDataKey].isOpen = true;
        this._changeDetectorRef.markForCheck();
    }
    /**
     * Close notification by type within the container.
     *
     * @param type Specify the type fo notification to close.
     */
    close(type) {
        const notificationDataKey = this.getNotificationKey(type);
        if (type === 'transient' && this.closeTimer !== null) {
            window.clearTimeout(this.closeTimer);
            this.closeTimer = null;
        }
        this.notificationData[notificationDataKey].isOpen = false;
        this._changeDetectorRef.markForCheck();
    }
    /**
     * Closes all types of notifications within the container.
     */
    closeAll() {
        this.close('persistent');
        this.close('transient');
    }
    /** @docs-private */
    buttonClickedHandler(event) {
        this.notificationButtonClicked.emit(event);
    }
    /** @docs-private */
    closeButtonClickHandler() {
        this.close('persistent');
    }
    /** @docs-private */
    closeOnTimer(timer) {
        this.closeTimer = window.setTimeout(() => {
            this.close('transient');
        }, timer);
    }
    /** @docs-private */
    slideEnd(event) {
        const type = event.element.classList.contains('transient-container')
            ? 'transient'
            : 'persistent';
        if (type === 'transient' &&
            this.notificationData.transientData.isOpen &&
            event.fromState === 'closed' &&
            event.toState === 'open') {
            this.closeOnTimer(this.notificationData.transientData.timer);
        }
        if (event.fromState === 'open' && event.toState === 'closed') {
            this.closeNotification(type);
        }
    }
    /** @docs-private */
    closeNotification(type) {
        const key = this.getNotificationKey(type);
        const event = {
            type: type,
            item: this.notificationData[key]
        };
        this.notificationDone.emit(this.notificationData[key]);
        this.notificationData[key].buttonText = null;
        this.notificationData[key].message = null;
        this.notificationIds[type] = '';
    }
    /** @docs-private */
    getNotificationKey(type) {
        return type === 'persistent' ? 'persistentData' : 'transientData';
    }
    /** Returns list of classes for notification types */
    getNotificationClasses(type, state) {
        const newClasses = { [`notification-type-${type}`]: true, [state]: true };
        return newClasses;
    }
}
MatNotification.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatNotification, deps: [{ token: MatNotificationIntl }, { token: i0.ChangeDetectorRef }, { token: i0.ElementRef }, { token: MAT_NOTIFICATION_DEFAULT_OPTIONS }], target: i0.ɵɵFactoryTarget.Component });
MatNotification.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.11", type: MatNotification, selector: "mat-notification", inputs: { id: "id" }, outputs: { notificationDone: "notificationDone", notificationButtonClicked: "notificationButtonClicked" }, host: { attributes: { "role": "dialog" }, properties: { "class.mat-notification": "true" } }, viewQueries: [{ propertyName: "notificationButton", first: true, predicate: ["notificationButton"], descendants: true, static: true }], ngImport: i0, template: "<div class=\"slide-in-container persistent-container\"\n     [@state]=\"notificationData.persistentData.isOpen ? 'open' : 'closed'\"\n     (@state.done)=\"slideEnd($event)\"\n     [ngClass]=\"{'notification-open': notificationData.persistentData.isOpen}\">\n  <div #persistentNotification\n       class=\"mat-notification-container\"\n       [ngClass]=\"getNotificationClasses('persistent', notificationData.persistentData.state)\"\n       [attr.id]=\"notificationData.persistentData.isOpen ? notificationIds['persistent'] : ''\"\n       [attr.aria-label]=\"notificationData.persistentData.isOpen ? getStateLabel(notificationData.persistentData.state) : ''\"\n       [attr.aria-describedby]=\"notificationData.persistentData.message ? notificationIds.persistent + '-message' : ''\"\n       aria-live=\"polite\">\n    <div *ngIf=\"notificationData.persistentData.message\"\n         class=\"notification-content\">\n      <mat-icon class=\"notification-state-icon\"\n                *ngIf=\"notificationData.persistentData.state !== 'default'\"\n                fontSet=\"material-symbols-outlined\">{{ getStateIcon(notificationData.persistentData.state) }}</mat-icon>\n      <div #persistentMessage\n           [attr.id]=\"notificationData.persistentData.isOpen ? notificationIds.persistent + '-message' : ''\"\n           class=\"notification-message\">{{notificationData.persistentData.message}}\n      </div>\n      <button *ngIf=\"notificationData.persistentData.buttonText\"\n              #notificationButton\n              mat-stroked-button\n              (click)=\"buttonClickedHandler(notificationData.persistentData)\"\n              class=\"notification-button\">{{notificationData.persistentData.buttonText}}</button>\n    </div>\n    <button *ngIf=\"notificationData.persistentData.message\"\n            mat-button\n            (click)=\"closeButtonClickHandler()\"\n            [matTooltip]=\"_intl.closeNotificationButtonLabel\"\n            [matTooltipPosition]=\"'before'\"\n            class=\"notification-close-button\">\n      <mat-icon fontSet=\"material-symbols-outlined\">close</mat-icon>\n    </button>\n  </div>\n</div>\n\n<div class=\"slide-in-container transient-container\"\n     [@state]=\"notificationData.transientData.isOpen ? 'open' : 'closed'\"\n     (@state.done)=\"slideEnd($event)\"\n     [ngClass]=\"{'notification-open': notificationData.transientData.isOpen}\">\n  <div class=\"mat-notification-container\"\n       [ngClass]=\"getNotificationClasses('transient', notificationData.transientData.state)\"\n       [attr.id]=\"notificationData.transientData.isOpen ? notificationIds.transient : ''\"\n       [attr.aria-label]=\"notificationData.transientData.isOpen ? getStateLabel(notificationData.transientData.state) : ''\"\n       [attr.aria-describedby]=\"notificationData.transientData.message ? notificationIds.transient + '-message' : ''\"\n       aria-live=\"polite\"\n       #transientNotification>\n    <div *ngIf=\"notificationData.transientData.message\"\n         class=\"notification-content\">\n      <mat-icon class=\"notification-state-icon\"\n                *ngIf=\"notificationData.transientData.state !== 'default'\"\n                fontSet=\"material-symbols-outlined\">{{ getStateIcon(notificationData.transientData.state)\n        }}</mat-icon>\n      <div #transientMessage\n           [attr.id]=\"notificationData.transientData.isOpen ? notificationIds.transient + '-message' : ''\"\n           class=\"notification-message\">{{notificationData.transientData.message}}\n      </div>\n      <button *ngIf=\"notificationData.transientData.buttonText\"\n              #notificationButton\n              mat-flat-button\n              (click)=\"buttonClickedHandler(notificationData.transientData)\"\n              class=\"notification-button\">{{notificationData.transientData.buttonText}}</button>\n    </div>\n  </div>\n</div>", styles: [".mat-notification{position:absolute;left:0;right:0;top:0;height:100%;max-height:100%;overflow:hidden;z-index:1000;pointer-events:none}.mat-notification>.slide-in-container{max-height:0;width:100%;overflow:hidden;pointer-events:auto}.mat-notification>.slide-in-container.notification-open~.slide-in-container.notification-open{border-top-width:1px;border-top-style:solid;margin-top:1px}.mat-notification>.slide-in-container>.mat-notification-container{height:100%;display:flex;align-items:center;min-height:29px;padding:15px 0}.mat-notification>.slide-in-container>.mat-notification-container.notification-type-transient{padding-right:15px}.mat-notification>.slide-in-container>.mat-notification-container>.notification-content{display:flex;flex:1 1 auto;align-items:baseline;justify-content:center;margin-left:15px}.mat-notification>.slide-in-container>.mat-notification-container>.notification-content>.notification-state-icon{height:26px;width:26px}.mat-notification>.slide-in-container>.mat-notification-container>.notification-content>.notification-message{max-width:570px;overflow:hidden;flex:0 1 auto;margin-left:15px;align-self:center}.mat-notification>.slide-in-container>.mat-notification-container>.notification-content>.notification-button{margin-left:14px;pointer-events:auto}.mat-notification>.slide-in-container>.mat-notification-container>.notification-close-button{height:45px;min-width:45px;margin:-8px 0 -7px 1px;justify-self:flex-end;flex:0 1 auto;align-self:flex-start;padding:0 14px 0 13px}.mat-notification>.slide-in-container>.mat-notification-container>.notification-close-button .mat-icon{height:1.125rem;width:1.125rem}[dir=rtl] .mat-notification>.slide-in-container>.mat-notification-container>.notification-content{margin-left:0;margin-right:15px}[dir=rtl] .mat-notification>.slide-in-container>.mat-notification-container>.notification-content>.notification-message{margin-left:0;margin-right:15px}[dir=rtl] .mat-notification>.slide-in-container>.mat-notification-container>.notification-content>.notification-button{margin-left:0;margin-right:14px}[dir=rtl] .mat-notification>.slide-in-container>.mat-notification-container>.notification-content>.notification-close-button{padding-left:14px;padding-right:13px;margin-left:0;margin-right:1px}[dir=rtl] .mat-notification>.slide-in-container>.mat-notification-container>.notification-content.notification-type-transient{padding-left:15px;padding-right:0}.mat-notification+.mat-notification>.slide-in-container{top:48px}\n"], components: [{ type: i2.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { type: i3.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }], directives: [{ type: i4.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i5.MatTooltip, selector: "[matTooltip]", exportAs: ["matTooltip"] }], viewProviders: [MatIconRegistry], animations: [matNotificationAnimations.notificationState], changeDetection: i0.ChangeDetectionStrategy.Default, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatNotification, decorators: [{
            type: Component,
            args: [{ selector: 'mat-notification', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.Default, host: {
                        role: 'dialog',
                        '[class.mat-notification]': 'true'
                    }, viewProviders: [MatIconRegistry], animations: [matNotificationAnimations.notificationState], template: "<div class=\"slide-in-container persistent-container\"\n     [@state]=\"notificationData.persistentData.isOpen ? 'open' : 'closed'\"\n     (@state.done)=\"slideEnd($event)\"\n     [ngClass]=\"{'notification-open': notificationData.persistentData.isOpen}\">\n  <div #persistentNotification\n       class=\"mat-notification-container\"\n       [ngClass]=\"getNotificationClasses('persistent', notificationData.persistentData.state)\"\n       [attr.id]=\"notificationData.persistentData.isOpen ? notificationIds['persistent'] : ''\"\n       [attr.aria-label]=\"notificationData.persistentData.isOpen ? getStateLabel(notificationData.persistentData.state) : ''\"\n       [attr.aria-describedby]=\"notificationData.persistentData.message ? notificationIds.persistent + '-message' : ''\"\n       aria-live=\"polite\">\n    <div *ngIf=\"notificationData.persistentData.message\"\n         class=\"notification-content\">\n      <mat-icon class=\"notification-state-icon\"\n                *ngIf=\"notificationData.persistentData.state !== 'default'\"\n                fontSet=\"material-symbols-outlined\">{{ getStateIcon(notificationData.persistentData.state) }}</mat-icon>\n      <div #persistentMessage\n           [attr.id]=\"notificationData.persistentData.isOpen ? notificationIds.persistent + '-message' : ''\"\n           class=\"notification-message\">{{notificationData.persistentData.message}}\n      </div>\n      <button *ngIf=\"notificationData.persistentData.buttonText\"\n              #notificationButton\n              mat-stroked-button\n              (click)=\"buttonClickedHandler(notificationData.persistentData)\"\n              class=\"notification-button\">{{notificationData.persistentData.buttonText}}</button>\n    </div>\n    <button *ngIf=\"notificationData.persistentData.message\"\n            mat-button\n            (click)=\"closeButtonClickHandler()\"\n            [matTooltip]=\"_intl.closeNotificationButtonLabel\"\n            [matTooltipPosition]=\"'before'\"\n            class=\"notification-close-button\">\n      <mat-icon fontSet=\"material-symbols-outlined\">close</mat-icon>\n    </button>\n  </div>\n</div>\n\n<div class=\"slide-in-container transient-container\"\n     [@state]=\"notificationData.transientData.isOpen ? 'open' : 'closed'\"\n     (@state.done)=\"slideEnd($event)\"\n     [ngClass]=\"{'notification-open': notificationData.transientData.isOpen}\">\n  <div class=\"mat-notification-container\"\n       [ngClass]=\"getNotificationClasses('transient', notificationData.transientData.state)\"\n       [attr.id]=\"notificationData.transientData.isOpen ? notificationIds.transient : ''\"\n       [attr.aria-label]=\"notificationData.transientData.isOpen ? getStateLabel(notificationData.transientData.state) : ''\"\n       [attr.aria-describedby]=\"notificationData.transientData.message ? notificationIds.transient + '-message' : ''\"\n       aria-live=\"polite\"\n       #transientNotification>\n    <div *ngIf=\"notificationData.transientData.message\"\n         class=\"notification-content\">\n      <mat-icon class=\"notification-state-icon\"\n                *ngIf=\"notificationData.transientData.state !== 'default'\"\n                fontSet=\"material-symbols-outlined\">{{ getStateIcon(notificationData.transientData.state)\n        }}</mat-icon>\n      <div #transientMessage\n           [attr.id]=\"notificationData.transientData.isOpen ? notificationIds.transient + '-message' : ''\"\n           class=\"notification-message\">{{notificationData.transientData.message}}\n      </div>\n      <button *ngIf=\"notificationData.transientData.buttonText\"\n              #notificationButton\n              mat-flat-button\n              (click)=\"buttonClickedHandler(notificationData.transientData)\"\n              class=\"notification-button\">{{notificationData.transientData.buttonText}}</button>\n    </div>\n  </div>\n</div>", styles: [".mat-notification{position:absolute;left:0;right:0;top:0;height:100%;max-height:100%;overflow:hidden;z-index:1000;pointer-events:none}.mat-notification>.slide-in-container{max-height:0;width:100%;overflow:hidden;pointer-events:auto}.mat-notification>.slide-in-container.notification-open~.slide-in-container.notification-open{border-top-width:1px;border-top-style:solid;margin-top:1px}.mat-notification>.slide-in-container>.mat-notification-container{height:100%;display:flex;align-items:center;min-height:29px;padding:15px 0}.mat-notification>.slide-in-container>.mat-notification-container.notification-type-transient{padding-right:15px}.mat-notification>.slide-in-container>.mat-notification-container>.notification-content{display:flex;flex:1 1 auto;align-items:baseline;justify-content:center;margin-left:15px}.mat-notification>.slide-in-container>.mat-notification-container>.notification-content>.notification-state-icon{height:26px;width:26px}.mat-notification>.slide-in-container>.mat-notification-container>.notification-content>.notification-message{max-width:570px;overflow:hidden;flex:0 1 auto;margin-left:15px;align-self:center}.mat-notification>.slide-in-container>.mat-notification-container>.notification-content>.notification-button{margin-left:14px;pointer-events:auto}.mat-notification>.slide-in-container>.mat-notification-container>.notification-close-button{height:45px;min-width:45px;margin:-8px 0 -7px 1px;justify-self:flex-end;flex:0 1 auto;align-self:flex-start;padding:0 14px 0 13px}.mat-notification>.slide-in-container>.mat-notification-container>.notification-close-button .mat-icon{height:1.125rem;width:1.125rem}[dir=rtl] .mat-notification>.slide-in-container>.mat-notification-container>.notification-content{margin-left:0;margin-right:15px}[dir=rtl] .mat-notification>.slide-in-container>.mat-notification-container>.notification-content>.notification-message{margin-left:0;margin-right:15px}[dir=rtl] .mat-notification>.slide-in-container>.mat-notification-container>.notification-content>.notification-button{margin-left:0;margin-right:14px}[dir=rtl] .mat-notification>.slide-in-container>.mat-notification-container>.notification-content>.notification-close-button{padding-left:14px;padding-right:13px;margin-left:0;margin-right:1px}[dir=rtl] .mat-notification>.slide-in-container>.mat-notification-container>.notification-content.notification-type-transient{padding-left:15px;padding-right:0}.mat-notification+.mat-notification>.slide-in-container{top:48px}\n"] }]
        }], ctorParameters: function () { return [{ type: MatNotificationIntl }, { type: i0.ChangeDetectorRef }, { type: i0.ElementRef }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [MAT_NOTIFICATION_DEFAULT_OPTIONS]
                }] }]; }, propDecorators: { id: [{
                type: Input
            }], notificationButton: [{
                type: ViewChild,
                args: ['notificationButton', { static: true }]
            }], notificationDone: [{
                type: Output
            }], notificationButtonClicked: [{
                type: Output
            }] } });

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
class MatNotificationModule {
}
MatNotificationModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatNotificationModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
MatNotificationModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatNotificationModule, declarations: [MatNotification], imports: [A11yModule,
        CommonModule,
        MatButtonModule,
        MatIconModule,
        MatTooltipModule], exports: [MatNotification] });
MatNotificationModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatNotificationModule, providers: [MAT_NOTIFICATION_INTL_PROVIDER], imports: [[
            A11yModule,
            CommonModule,
            MatButtonModule,
            MatIconModule,
            MatTooltipModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatNotificationModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        A11yModule,
                        CommonModule,
                        MatButtonModule,
                        MatIconModule,
                        MatTooltipModule
                    ],
                    exports: [MatNotification],
                    declarations: [MatNotification],
                    providers: [MAT_NOTIFICATION_INTL_PROVIDER]
                }]
        }] });

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */

/**
 * Generated bundle index. Do not edit.
 */

export { MAT_NOTIFICATION_DEFAULT_OPTIONS, MAT_NOTIFICATION_DEFAULT_OPTIONS_FACTORY, MAT_NOTIFICATION_INTL_PROVIDER, MAT_NOTIFICATION_INTL_PROVIDER_FACTORY, MatNotification, MatNotificationIntl, MatNotificationModule, NOTIFICATION_ANIMATION_TIMING, matNotificationAnimations };
//# sourceMappingURL=vdlx-vdl-angular-mat-notification.mjs.map
