/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
import { AfterContentInit, ElementRef, QueryList, TemplateRef } from '@angular/core';
import { OverflowBarIntl } from './overflow-bar-intl';
import * as i0 from "@angular/core";
export interface ActionButtonOverflowBoundary {
    width: 'default' | number;
    buttonCount: number;
}
/**
 * Overflow bar to be rendered within the App Bar.
 */
export declare class MatAppBarOverflow {
    constructor();
    static ɵfac: i0.ɵɵFactoryDeclaration<MatAppBarOverflow, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<MatAppBarOverflow, "[mat-app-bar-overflow]", never, {}, {}, never>;
}
/**
 * Overflow bar to be rendered within the Page Bar.
 */
export declare class MatPageBarOverflow {
    constructor();
    static ɵfac: i0.ɵɵFactoryDeclaration<MatPageBarOverflow, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<MatPageBarOverflow, "[mat-page-bar-overflow]", never, {}, {}, never>;
}
/**
 * Directive applied to handle button, anchor and checkbox actions within the overflow bar.
 */
export declare class MatBarItem {
    barItemElementRef: ElementRef<HTMLElement>;
    constructor(barItemElementRef: ElementRef<HTMLElement>);
    static ɵfac: i0.ɵɵFactoryDeclaration<MatBarItem, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<MatBarItem, "[mat-overflow-bar-action]", never, {}, {}, never>;
}
/**
 * Defines overflow bar contents to be rendered as both menu and non-menu actions
 */
export declare class MatOverflowBarItem {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<MatOverflowBarItem, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<MatOverflowBarItem, "ng-template[mat-overflow-bar-item]", never, {}, {}, never>;
}
/**
 * Adds bar overflow button, checkbox, link and menu action
 */
export declare class MatOverflowBar implements AfterContentInit {
    _intl: OverflowBarIntl;
    actionItems: MatOverflowBarItem[];
    showButtonText: boolean;
    disableOverflow: boolean;
    get overflowBoundaries(): ActionButtonOverflowBoundary[];
    set overflowBoundaries(value: ActionButtonOverflowBoundary[]);
    _overflowBoundaries: ActionButtonOverflowBoundary[];
    matOverflowBarItems: QueryList<MatOverflowBarItem>;
    constructor(_intl: OverflowBarIntl);
    ngAfterContentInit(): void;
    matMenuItem(actionItem: MatOverflowBarItem): TemplateRef<any>;
    getWidth(): number;
    hasOverflowButtons(): boolean;
    isOverflowButton(index: number): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<MatOverflowBar, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MatOverflowBar, "mat-overflow-bar", never, { "showButtonText": "showButtonText"; "disableOverflow": "disableOverflow"; "overflowBoundaries": "overflowBoundaries"; }, {}, ["matOverflowBarItems"], never>;
}
