import * as i1 from '@angular/common';
import { DOCUMENT, CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { InjectionToken, inject, EventEmitter, Component, ChangeDetectionStrategy, ViewEncapsulation, Optional, Inject, Input, ViewChild, Output, NgModule } from '@angular/core';
import { mixinColor, MatCommonModule } from '@vdlx/vdl-angular/mat/core';
import { coerceNumberProperty } from '@angular/cdk/coercion';
import { ANIMATION_MODULE_TYPE } from '@angular/platform-browser/animations';
import { Subscription, fromEvent } from 'rxjs';
import { filter } from 'rxjs/operators';

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
// Boilerplate for applying mixins to MatProgressBar.
/** @docs-private */
const _MatProgressBarBase = mixinColor(class {
    constructor(_elementRef) {
        this._elementRef = _elementRef;
    }
}, 'primary');
/**
 * Injection token used to provide the current location to `MatProgressBar`.
 * Used to handle server-side rendering and to stub out during unit tests.
 * @docs-private
 */
const MAT_PROGRESS_BAR_LOCATION = new InjectionToken('mat-progress-bar-location', {
    providedIn: 'root',
    factory: MAT_PROGRESS_BAR_LOCATION_FACTORY
});
/** @docs-private */
function MAT_PROGRESS_BAR_LOCATION_FACTORY() {
    const _document = inject(DOCUMENT);
    const _location = _document ? _document.location : null;
    return {
        // Note that this needs to be a function, rather than a property, because Angular
        // will only resolve it once, but we want the current path on each call.
        getPathname: () => (_location ? _location.pathname + _location.search : '')
    };
}
/** Injection token to be used to override the default options for `mat-progress-bar`. */
const MAT_PROGRESS_BAR_DEFAULT_OPTIONS = new InjectionToken('MAT_PROGRESS_BAR_DEFAULT_OPTIONS');
/** Counter used to generate unique IDs for progress bars. */
let progressbarId = 0;
/**
 * `<mat-progress-bar>` component.
 */
class MatProgressBar extends _MatProgressBarBase {
    constructor(elementRef, _ngZone, _animationMode, 
    /**
     * @deprecated `location` parameter to be made required.
     * @breaking-change 8.0.0
     */
    location, defaults, 
    /**
     * @deprecated `_changeDetectorRef` parameter to be made required.
     * @breaking-change 11.0.0
     */
    _changeDetectorRef) {
        super(elementRef);
        this._ngZone = _ngZone;
        this._animationMode = _animationMode;
        this._changeDetectorRef = _changeDetectorRef;
        /** Setting this to true will make the label appear before the vdl-progress-bar **/
        this.labelBefore = false;
        /** Flag that indicates whether NoopAnimations mode is set to true. */
        this._isNoopAnimation = false;
        this._value = 0;
        this._bufferValue = 0;
        /**
         * Event emitted when animation of the primary progress bar completes. This event will not
         * be emitted when animations are disabled, nor will it be emitted for modes with continuous
         * animations (indeterminate and query).
         */
        this.animationEnd = new EventEmitter();
        /** Reference to animation end subscription to be unsubscribed on destroy. */
        this._animationEndSubscription = Subscription.EMPTY;
        /**
         * Mode of the progress bar.
         *
         * Input must be one of these values: determinate, indeterminate, buffer, query, defaults to
         * 'determinate'.
         * Mirrored to mode attribute.
         */
        this.mode = 'determinate';
        /** ID of the progress bar. */
        this.progressbarId = `mat-progress-bar-${progressbarId++}`;
        // We need to prefix the SVG reference with the current path, otherwise they won't work
        // in Safari if the page has a `<base>` tag. Note that we need quotes inside the `url()`,
        // because named route URLs can contain parentheses (see #12338). Also we don't use `Location`
        // since we can't tell the difference between whether the consumer is using the hash location
        // strategy or not, because `Location` normalizes both `/#/foo/bar` and `/foo/bar` to
        // the same thing.
        const path = location ? location.getPathname().split('#')[0] : '';
        this._rectangleFillValue = `url('${path}#${this.progressbarId}')`;
        this._isNoopAnimation = _animationMode === 'NoopAnimations';
        if (defaults) {
            if (defaults.color) {
                this.color = this.defaultColor = defaults.color;
            }
            this.mode = defaults.mode || this.mode;
        }
    }
    /** Value of the progress bar. Defaults to zero. Mirrored to aria-valuenow. */
    get value() {
        return this._value;
    }
    set value(v) {
        var _a;
        this._value = clamp(coerceNumberProperty(v) || 0);
        // @breaking-change 11.0.0 Remove null check for _changeDetectorRef.
        (_a = this._changeDetectorRef) === null || _a === void 0 ? void 0 : _a.markForCheck();
    }
    /** Buffer value of the progress bar. Defaults to zero. */
    get bufferValue() {
        return this._bufferValue;
    }
    set bufferValue(v) {
        var _a;
        this._bufferValue = clamp(v || 0);
        // @breaking-change 11.0.0 Remove null check for _changeDetectorRef.
        (_a = this._changeDetectorRef) === null || _a === void 0 ? void 0 : _a.markForCheck();
    }
    /** Gets the current transform value for the progress bar's primary indicator. */
    _primaryTransform() {
        // We use a 3d transform to work around some rendering issues in iOS Safari. See #19328.
        const scale = this.value / 100;
        return { transform: `scale3d(${scale}, 1, 1)` };
    }
    /**
     * Gets the current transform value for the progress bar's buffer indicator. Only used if the
     * progress mode is set to buffer, otherwise returns an undefined, causing no transformation.
     */
    _bufferTransform() {
        if (this.mode === 'buffer') {
            // We use a 3d transform to work around some rendering issues in iOS Safari. See #19328.
            const scale = this.bufferValue / 100;
            return { transform: `scale3d(${scale}, 1, 1)` };
        }
        return null;
    }
    ngAfterViewInit() {
        // Run outside angular so change detection didn't get triggered on every transition end
        // instead only on the animation that we care about (primary value bar's transitionend)
        this._ngZone.runOutsideAngular(() => {
            const element = this._primaryValueBar.nativeElement;
            this._animationEndSubscription = fromEvent(element, 'transitionend')
                .pipe(filter((e) => e.target === element))
                .subscribe(() => {
                if (this.animationEnd.observers.length === 0) {
                    return;
                }
                if (this.mode === 'determinate' || this.mode === 'buffer') {
                    this._ngZone.run(() => this.animationEnd.next({ value: this.value }));
                }
            });
        });
    }
    ngOnDestroy() {
        this._animationEndSubscription.unsubscribe();
    }
}
MatProgressBar.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatProgressBar, deps: [{ token: i0.ElementRef }, { token: i0.NgZone }, { token: ANIMATION_MODULE_TYPE, optional: true }, { token: MAT_PROGRESS_BAR_LOCATION, optional: true }, { token: MAT_PROGRESS_BAR_DEFAULT_OPTIONS, optional: true }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component });
MatProgressBar.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.11", type: MatProgressBar, selector: "mat-progress-bar", inputs: { color: "color", label: "label", labelBefore: "labelBefore", value: "value", bufferValue: "bufferValue", mode: "mode" }, outputs: { animationEnd: "animationEnd" }, host: { attributes: { "role": "progressbar", "aria-valuemin": "0", "aria-valuemax": "100", "tabindex": "-1" }, properties: { "attr.aria-valuenow": "(mode === \"indeterminate\" || mode === \"query\") ? null : value", "attr.mode": "mode", "class._mat-animation-noopable": "_isNoopAnimation", "class.mat-progress-bar-label-before": "labelBefore" }, classAttribute: "mat-progress-bar" }, viewQueries: [{ propertyName: "_primaryValueBar", first: true, predicate: ["primaryValueBar"], descendants: true }], exportAs: ["matProgressBar"], usesInheritance: true, ngImport: i0, template: "<!-- VDL Change: Progress bar label and container -->\n<div *ngIf=\"label\"\n     class=\"mat-progress-bar-label\">{{label}}\n</div>\n<!--\n  All children need to be hidden for screen readers in order to support ChromeVox.\n  More context in the issue: https://github.com/angular/components/issues/22165.\n-->\n<div aria-hidden=\"true\"\n     class=\"mat-progress-bar-container\">\n  <svg width=\"100%\"\n       height=\"4\"\n       focusable=\"false\"\n       class=\"mat-progress-bar-background mat-progress-bar-element\">\n    <defs>\n      <pattern [id]=\"progressbarId\"\n               x=\"4\"\n               y=\"0\"\n               width=\"8\"\n               height=\"4\"\n               patternUnits=\"userSpaceOnUse\">\n        <circle cx=\"2\"\n                cy=\"2\"\n                r=\"2\" />\n      </pattern>\n    </defs>\n    <rect [attr.fill]=\"_rectangleFillValue\"\n          width=\"100%\"\n          height=\"100%\" />\n  </svg>\n  <!--\n    The background div is named as such because it appears below the other divs and is not sized based\n    on values.\n  -->\n  <div class=\"mat-progress-bar-buffer mat-progress-bar-element\"\n       [ngStyle]=\"_bufferTransform()\"></div>\n  <div class=\"mat-progress-bar-primary mat-progress-bar-fill mat-progress-bar-element\"\n       [ngStyle]=\"_primaryTransform()\"\n       #primaryValueBar></div>\n  <div class=\"mat-progress-bar-secondary mat-progress-bar-fill mat-progress-bar-element\"></div>\n</div>\n", styles: [".mat-progress-bar{display:flex;flex-direction:column-reverse;width:100%}.mat-progress-bar .mat-progress-bar-label{padding-top:5px;font-size:.875rem;letter-spacing:0;flex:0 0 auto}.mat-progress-bar.mat-progress-bar-label-before{flex-direction:row;flex-wrap:nowrap}.mat-progress-bar.mat-progress-bar-label-before .mat-progress-bar-label{padding-top:0;padding-right:15px}[dir=rtl] .mat-progress-bar.mat-progress-bar-label-before .mat-progress-bar-label{padding-left:15px;padding-right:0}.mat-progress-bar .mat-progress-bar-container{display:block;height:4px;overflow:hidden;position:relative;transition:opacity .25s linear;width:100%;flex:1 1 auto;align-self:center}._mat-animation-noopable.mat-progress-bar .mat-progress-bar-container{transition:none;animation:none}.mat-progress-bar .mat-progress-bar-container .mat-progress-bar-element,.mat-progress-bar .mat-progress-bar-container .mat-progress-bar-fill:after{height:100%;position:absolute;width:100%}.mat-progress-bar .mat-progress-bar-container .mat-progress-bar-background{width:calc(100% + 10px)}.cdk-high-contrast-active .mat-progress-bar .mat-progress-bar-container .mat-progress-bar-background{display:none}.mat-progress-bar .mat-progress-bar-container .mat-progress-bar-buffer{transform-origin:top left;transition:transform .25s ease}.cdk-high-contrast-active .mat-progress-bar .mat-progress-bar-container .mat-progress-bar-buffer{border-top:solid 5px;opacity:.5}.mat-progress-bar .mat-progress-bar-container .mat-progress-bar-secondary{display:none}.mat-progress-bar .mat-progress-bar-container .mat-progress-bar-fill{animation:none;transform-origin:top left;transition:transform .25s ease}.cdk-high-contrast-active .mat-progress-bar .mat-progress-bar-container .mat-progress-bar-fill{border-top:solid 4px}.mat-progress-bar .mat-progress-bar-container .mat-progress-bar-fill:after{animation:none;content:\"\";display:inline-block;left:0}.mat-progress-bar .mat-progress-bar-container[dir=rtl],[dir=rtl] .mat-progress-bar .mat-progress-bar-container{transform:rotateY(180deg)}.mat-progress-bar[mode=query] .mat-progress-bar-container{transform:rotate(180deg)}.mat-progress-bar[mode=query] .mat-progress-bar-container[dir=rtl],[dir=rtl] .mat-progress-bar[mode=query] .mat-progress-bar-container{transform:rotate(180deg) rotateY(180deg)}.mat-progress-bar[mode=indeterminate] .mat-progress-bar-container .mat-progress-bar-fill,.mat-progress-bar[mode=query] .mat-progress-bar-container .mat-progress-bar-fill{transition:none}.mat-progress-bar[mode=indeterminate] .mat-progress-bar-container .mat-progress-bar-primary,.mat-progress-bar[mode=query] .mat-progress-bar-container .mat-progress-bar-primary{backface-visibility:hidden;animation:mat-progress-bar-primary-indeterminate-translate 2s infinite linear;left:-145.166611%}.mat-progress-bar[mode=indeterminate] .mat-progress-bar-container .mat-progress-bar-primary.mat-progress-bar-fill:after,.mat-progress-bar[mode=query] .mat-progress-bar-container .mat-progress-bar-primary.mat-progress-bar-fill:after{backface-visibility:hidden;animation:mat-progress-bar-primary-indeterminate-scale 2s infinite linear}.mat-progress-bar[mode=indeterminate] .mat-progress-bar-container .mat-progress-bar-secondary,.mat-progress-bar[mode=query] .mat-progress-bar-container .mat-progress-bar-secondary{backface-visibility:hidden;animation:mat-progress-bar-secondary-indeterminate-translate 2s infinite linear;left:-54.888891%;display:block}.mat-progress-bar[mode=indeterminate] .mat-progress-bar-container .mat-progress-bar-secondary.mat-progress-bar-fill:after,.mat-progress-bar[mode=query] .mat-progress-bar-container .mat-progress-bar-secondary.mat-progress-bar-fill:after{backface-visibility:hidden;animation:mat-progress-bar-secondary-indeterminate-scale 2s infinite linear}.mat-progress-bar[mode=buffer] .mat-progress-bar-container .mat-progress-bar-background{backface-visibility:hidden;animation:mat-progress-bar-background-scroll .25s infinite linear;display:block}.mat-progress-bar._mat-animation-noopable .mat-progress-bar-fill,.mat-progress-bar._mat-animation-noopable .mat-progress-bar-fill:after,.mat-progress-bar._mat-animation-noopable .mat-progress-bar-buffer,.mat-progress-bar._mat-animation-noopable .mat-progress-bar-primary,.mat-progress-bar._mat-animation-noopable .mat-progress-bar-primary.mat-progress-bar-fill:after,.mat-progress-bar._mat-animation-noopable .mat-progress-bar-secondary,.mat-progress-bar._mat-animation-noopable .mat-progress-bar-secondary.mat-progress-bar-fill:after,.mat-progress-bar._mat-animation-noopable .mat-progress-bar-background{animation:none;transition-duration:1ms}@keyframes mat-progress-bar-primary-indeterminate-translate{0%{transform:translate(0)}20%{animation-timing-function:cubic-bezier(.5,0,.701732,.495819);transform:translate(0)}59.15%{animation-timing-function:cubic-bezier(.302435,.381352,.55,.956352);transform:translate(83.67142%)}to{transform:translate(200.611057%)}}@keyframes mat-progress-bar-primary-indeterminate-scale{0%{transform:scaleX(.08)}36.65%{animation-timing-function:cubic-bezier(.334731,.12482,.785844,1);transform:scaleX(.08)}69.15%{animation-timing-function:cubic-bezier(.06,.11,.6,1);transform:scaleX(.661479)}to{transform:scaleX(.08)}}@keyframes mat-progress-bar-secondary-indeterminate-translate{0%{animation-timing-function:cubic-bezier(.15,0,.515058,.409685);transform:translate(0)}25%{animation-timing-function:cubic-bezier(.31033,.284058,.8,.733712);transform:translate(37.651913%)}48.35%{animation-timing-function:cubic-bezier(.4,.627035,.6,.902026);transform:translate(84.386165%)}to{transform:translate(160.277782%)}}@keyframes mat-progress-bar-secondary-indeterminate-scale{0%{animation-timing-function:cubic-bezier(.15,0,.515058,.409685);transform:scaleX(.08)}19.15%{animation-timing-function:cubic-bezier(.31033,.284058,.8,.733712);transform:scaleX(.457104)}44.15%{animation-timing-function:cubic-bezier(.4,.627035,.6,.902026);transform:scaleX(.72796)}to{transform:scaleX(.08)}}@keyframes mat-progress-bar-background-scroll{to{transform:translate(-8px)}}\n"], directives: [{ type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i1.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatProgressBar, decorators: [{
            type: Component,
            args: [{ selector: 'mat-progress-bar', exportAs: 'matProgressBar', host: {
                        role: 'progressbar',
                        'aria-valuemin': '0',
                        'aria-valuemax': '100',
                        // set tab index to -1 so screen readers will read the aria-label
                        // Note: there is a known issue with JAWS that does not read progressbar aria labels on FireFox
                        tabindex: '-1',
                        '[attr.aria-valuenow]': '(mode === "indeterminate" || mode === "query") ? null : value',
                        '[attr.mode]': 'mode',
                        class: 'mat-progress-bar',
                        '[class._mat-animation-noopable]': '_isNoopAnimation',
                        '[class.mat-progress-bar-label-before]': 'labelBefore'
                    }, inputs: ['color'], changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, template: "<!-- VDL Change: Progress bar label and container -->\n<div *ngIf=\"label\"\n     class=\"mat-progress-bar-label\">{{label}}\n</div>\n<!--\n  All children need to be hidden for screen readers in order to support ChromeVox.\n  More context in the issue: https://github.com/angular/components/issues/22165.\n-->\n<div aria-hidden=\"true\"\n     class=\"mat-progress-bar-container\">\n  <svg width=\"100%\"\n       height=\"4\"\n       focusable=\"false\"\n       class=\"mat-progress-bar-background mat-progress-bar-element\">\n    <defs>\n      <pattern [id]=\"progressbarId\"\n               x=\"4\"\n               y=\"0\"\n               width=\"8\"\n               height=\"4\"\n               patternUnits=\"userSpaceOnUse\">\n        <circle cx=\"2\"\n                cy=\"2\"\n                r=\"2\" />\n      </pattern>\n    </defs>\n    <rect [attr.fill]=\"_rectangleFillValue\"\n          width=\"100%\"\n          height=\"100%\" />\n  </svg>\n  <!--\n    The background div is named as such because it appears below the other divs and is not sized based\n    on values.\n  -->\n  <div class=\"mat-progress-bar-buffer mat-progress-bar-element\"\n       [ngStyle]=\"_bufferTransform()\"></div>\n  <div class=\"mat-progress-bar-primary mat-progress-bar-fill mat-progress-bar-element\"\n       [ngStyle]=\"_primaryTransform()\"\n       #primaryValueBar></div>\n  <div class=\"mat-progress-bar-secondary mat-progress-bar-fill mat-progress-bar-element\"></div>\n</div>\n", styles: [".mat-progress-bar{display:flex;flex-direction:column-reverse;width:100%}.mat-progress-bar .mat-progress-bar-label{padding-top:5px;font-size:.875rem;letter-spacing:0;flex:0 0 auto}.mat-progress-bar.mat-progress-bar-label-before{flex-direction:row;flex-wrap:nowrap}.mat-progress-bar.mat-progress-bar-label-before .mat-progress-bar-label{padding-top:0;padding-right:15px}[dir=rtl] .mat-progress-bar.mat-progress-bar-label-before .mat-progress-bar-label{padding-left:15px;padding-right:0}.mat-progress-bar .mat-progress-bar-container{display:block;height:4px;overflow:hidden;position:relative;transition:opacity .25s linear;width:100%;flex:1 1 auto;align-self:center}._mat-animation-noopable.mat-progress-bar .mat-progress-bar-container{transition:none;animation:none}.mat-progress-bar .mat-progress-bar-container .mat-progress-bar-element,.mat-progress-bar .mat-progress-bar-container .mat-progress-bar-fill:after{height:100%;position:absolute;width:100%}.mat-progress-bar .mat-progress-bar-container .mat-progress-bar-background{width:calc(100% + 10px)}.cdk-high-contrast-active .mat-progress-bar .mat-progress-bar-container .mat-progress-bar-background{display:none}.mat-progress-bar .mat-progress-bar-container .mat-progress-bar-buffer{transform-origin:top left;transition:transform .25s ease}.cdk-high-contrast-active .mat-progress-bar .mat-progress-bar-container .mat-progress-bar-buffer{border-top:solid 5px;opacity:.5}.mat-progress-bar .mat-progress-bar-container .mat-progress-bar-secondary{display:none}.mat-progress-bar .mat-progress-bar-container .mat-progress-bar-fill{animation:none;transform-origin:top left;transition:transform .25s ease}.cdk-high-contrast-active .mat-progress-bar .mat-progress-bar-container .mat-progress-bar-fill{border-top:solid 4px}.mat-progress-bar .mat-progress-bar-container .mat-progress-bar-fill:after{animation:none;content:\"\";display:inline-block;left:0}.mat-progress-bar .mat-progress-bar-container[dir=rtl],[dir=rtl] .mat-progress-bar .mat-progress-bar-container{transform:rotateY(180deg)}.mat-progress-bar[mode=query] .mat-progress-bar-container{transform:rotate(180deg)}.mat-progress-bar[mode=query] .mat-progress-bar-container[dir=rtl],[dir=rtl] .mat-progress-bar[mode=query] .mat-progress-bar-container{transform:rotate(180deg) rotateY(180deg)}.mat-progress-bar[mode=indeterminate] .mat-progress-bar-container .mat-progress-bar-fill,.mat-progress-bar[mode=query] .mat-progress-bar-container .mat-progress-bar-fill{transition:none}.mat-progress-bar[mode=indeterminate] .mat-progress-bar-container .mat-progress-bar-primary,.mat-progress-bar[mode=query] .mat-progress-bar-container .mat-progress-bar-primary{backface-visibility:hidden;animation:mat-progress-bar-primary-indeterminate-translate 2s infinite linear;left:-145.166611%}.mat-progress-bar[mode=indeterminate] .mat-progress-bar-container .mat-progress-bar-primary.mat-progress-bar-fill:after,.mat-progress-bar[mode=query] .mat-progress-bar-container .mat-progress-bar-primary.mat-progress-bar-fill:after{backface-visibility:hidden;animation:mat-progress-bar-primary-indeterminate-scale 2s infinite linear}.mat-progress-bar[mode=indeterminate] .mat-progress-bar-container .mat-progress-bar-secondary,.mat-progress-bar[mode=query] .mat-progress-bar-container .mat-progress-bar-secondary{backface-visibility:hidden;animation:mat-progress-bar-secondary-indeterminate-translate 2s infinite linear;left:-54.888891%;display:block}.mat-progress-bar[mode=indeterminate] .mat-progress-bar-container .mat-progress-bar-secondary.mat-progress-bar-fill:after,.mat-progress-bar[mode=query] .mat-progress-bar-container .mat-progress-bar-secondary.mat-progress-bar-fill:after{backface-visibility:hidden;animation:mat-progress-bar-secondary-indeterminate-scale 2s infinite linear}.mat-progress-bar[mode=buffer] .mat-progress-bar-container .mat-progress-bar-background{backface-visibility:hidden;animation:mat-progress-bar-background-scroll .25s infinite linear;display:block}.mat-progress-bar._mat-animation-noopable .mat-progress-bar-fill,.mat-progress-bar._mat-animation-noopable .mat-progress-bar-fill:after,.mat-progress-bar._mat-animation-noopable .mat-progress-bar-buffer,.mat-progress-bar._mat-animation-noopable .mat-progress-bar-primary,.mat-progress-bar._mat-animation-noopable .mat-progress-bar-primary.mat-progress-bar-fill:after,.mat-progress-bar._mat-animation-noopable .mat-progress-bar-secondary,.mat-progress-bar._mat-animation-noopable .mat-progress-bar-secondary.mat-progress-bar-fill:after,.mat-progress-bar._mat-animation-noopable .mat-progress-bar-background{animation:none;transition-duration:1ms}@keyframes mat-progress-bar-primary-indeterminate-translate{0%{transform:translate(0)}20%{animation-timing-function:cubic-bezier(.5,0,.701732,.495819);transform:translate(0)}59.15%{animation-timing-function:cubic-bezier(.302435,.381352,.55,.956352);transform:translate(83.67142%)}to{transform:translate(200.611057%)}}@keyframes mat-progress-bar-primary-indeterminate-scale{0%{transform:scaleX(.08)}36.65%{animation-timing-function:cubic-bezier(.334731,.12482,.785844,1);transform:scaleX(.08)}69.15%{animation-timing-function:cubic-bezier(.06,.11,.6,1);transform:scaleX(.661479)}to{transform:scaleX(.08)}}@keyframes mat-progress-bar-secondary-indeterminate-translate{0%{animation-timing-function:cubic-bezier(.15,0,.515058,.409685);transform:translate(0)}25%{animation-timing-function:cubic-bezier(.31033,.284058,.8,.733712);transform:translate(37.651913%)}48.35%{animation-timing-function:cubic-bezier(.4,.627035,.6,.902026);transform:translate(84.386165%)}to{transform:translate(160.277782%)}}@keyframes mat-progress-bar-secondary-indeterminate-scale{0%{animation-timing-function:cubic-bezier(.15,0,.515058,.409685);transform:scaleX(.08)}19.15%{animation-timing-function:cubic-bezier(.31033,.284058,.8,.733712);transform:scaleX(.457104)}44.15%{animation-timing-function:cubic-bezier(.4,.627035,.6,.902026);transform:scaleX(.72796)}to{transform:scaleX(.08)}}@keyframes mat-progress-bar-background-scroll{to{transform:translate(-8px)}}\n"] }]
        }], ctorParameters: function () {
        return [{ type: i0.ElementRef }, { type: i0.NgZone }, { type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [ANIMATION_MODULE_TYPE]
                    }] }, { type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [MAT_PROGRESS_BAR_LOCATION]
                    }] }, { type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [MAT_PROGRESS_BAR_DEFAULT_OPTIONS]
                    }] }, { type: i0.ChangeDetectorRef }];
    }, propDecorators: { label: [{
                type: Input
            }], labelBefore: [{
                type: Input
            }], value: [{
                type: Input
            }], bufferValue: [{
                type: Input
            }], _primaryValueBar: [{
                type: ViewChild,
                args: ['primaryValueBar']
            }], animationEnd: [{
                type: Output
            }], mode: [{
                type: Input
            }] } });
/** Clamps a value to be between two numbers, by default 0 and 100. */
function clamp(v, min = 0, max = 100) {
    return Math.max(min, Math.min(max, v));
}

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
class MatProgressBarModule {
}
MatProgressBarModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatProgressBarModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
MatProgressBarModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatProgressBarModule, declarations: [MatProgressBar], imports: [CommonModule, MatCommonModule], exports: [MatProgressBar, MatCommonModule] });
MatProgressBarModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatProgressBarModule, imports: [[CommonModule, MatCommonModule], MatCommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatProgressBarModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, MatCommonModule],
                    exports: [MatProgressBar, MatCommonModule],
                    declarations: [MatProgressBar]
                }]
        }] });

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */

/**
 * Generated bundle index. Do not edit.
 */

export { MAT_PROGRESS_BAR_DEFAULT_OPTIONS, MAT_PROGRESS_BAR_LOCATION, MAT_PROGRESS_BAR_LOCATION_FACTORY, MatProgressBar, MatProgressBarModule };
//# sourceMappingURL=vdlx-vdl-angular-mat-progress-bar.mjs.map
