import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { InjectionToken, forwardRef, Component, ViewEncapsulation, ChangeDetectionStrategy, EventEmitter, Directive, Input, Output, ContentChildren, ViewChild, Optional, Inject, Attribute, NgModule } from '@angular/core';
import * as i5 from '@vdlx/vdl-angular/mat/core';
import { mixinDisableRipple, mixinTabIndex, MatRippleModule, MatCommonModule } from '@vdlx/vdl-angular/mat/core';
import * as i2 from '@vdlx/vdl-angular/mat/form-field';
import { MatError, MatHint, MatFormFieldModule } from '@vdlx/vdl-angular/mat/form-field';
import * as i3 from '@angular/cdk/a11y';
import { coerceBooleanProperty, coerceNumberProperty } from '@angular/cdk/coercion';
import * as i4 from '@angular/cdk/collections';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { ANIMATION_MODULE_TYPE } from '@angular/platform-browser/animations';

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
const MAT_RADIO_DEFAULT_OPTIONS = new InjectionToken('mat-radio-default-options', {
    providedIn: 'root',
    factory: MAT_RADIO_DEFAULT_OPTIONS_FACTORY
});
function MAT_RADIO_DEFAULT_OPTIONS_FACTORY() {
    return {
        color: 'primary' // VDL Change: default color changed to primary
    };
}
// Increasing integer for generating unique ids for radio components.
let nextUniqueId = 0;
/**
 * Provider Expression that allows mat-radio-group to register as a ControlValueAccessor. This
 * allows it to support [(ngModel)] and ngControl.
 * @docs-private
 */
const MAT_RADIO_GROUP_CONTROL_VALUE_ACCESSOR = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => MatRadioGroup),
    multi: true
};
/** Change event object emitted by MatRadio and MatRadioGroup. */
class MatRadioChange {
    constructor(
    /** The MatRadioButton that emits the change event. */
    source, 
    /** The value of the MatRadioButton. */
    value) {
        this.source = source;
        this.value = value;
    }
}
/**
 * Radio Group Label, needed as it's used as a selector in the API.
 */
class MatRadioGroupLabel {
}
MatRadioGroupLabel.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatRadioGroupLabel, deps: [], target: i0.ɵɵFactoryTarget.Component });
MatRadioGroupLabel.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.11", type: MatRadioGroupLabel, selector: "mat-radio-group-label", host: { properties: { "class.mat-radio-group-label": "true" } }, ngImport: i0, template: "<div class=\"mat-radio-label-text\">\n  <ng-content></ng-content>\n</div>\n<div class=\"mat-radio-label-popovers\">\n  <ng-content select=\"mat-popover-predefined\"></ng-content>\n</div>", changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatRadioGroupLabel, decorators: [{
            type: Component,
            args: [{ selector: 'mat-radio-group-label', host: {
                        '[class.mat-radio-group-label]': 'true'
                    }, encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, template: "<div class=\"mat-radio-label-text\">\n  <ng-content></ng-content>\n</div>\n<div class=\"mat-radio-label-popovers\">\n  <ng-content select=\"mat-popover-predefined\"></ng-content>\n</div>" }]
        }] });
/**
 * Injection token that can be used to inject instances of `MatRadioGroup`. It serves as
 * alternative token to the actual `MatRadioGroup` class which could cause unnecessary
 * retention of the class and its component metadata.
 */
const MAT_RADIO_GROUP = new InjectionToken('MatRadioGroup');
/**
 * Base class with all of the `MatRadioGroup` functionality.
 * @docs-private
 */
class _MatRadioGroupBase {
    constructor(_changeDetector) {
        this._changeDetector = _changeDetector;
        /** Selected value for the radio group. */
        this._value = null;
        /** The HTML name attribute applied to radio buttons in this group. */
        this._name = `mat-radio-group-${nextUniqueId++}`;
        /** The currently selected radio button. Should match value. */
        this._selected = null;
        /** Whether the `value` has been set to its initial value. */
        this._isInitialized = false;
        /** Whether the labels should appear after or before the radio-buttons. Defaults to 'after' */
        this._labelPosition = 'after';
        /** Whether the radio group is disabled. */
        this._disabled = false;
        /** Whether the radio group is required. */
        this._required = false;
        /** The method to be called in order to update ngModel */
        this._controlValueAccessorChangeFn = () => { };
        /**
         * onTouch function registered via registerOnTouch (ControlValueAccessor).
         * @docs-private
         */
        this.onTouched = () => { };
        /** Change layout of radio buttons within group to horizontal */
        this.layoutHorizontal = false;
        /**
         * Event emitted when the group value changes.
         * Change events are only emitted when the value changes due to user interaction with
         * a radio button (the same behavior as `<input type-"radio">`).
         */
        this.change = new EventEmitter();
    }
    /** Name of the radio button group. All radio buttons inside this group will use this name. */
    get name() {
        return this._name;
    }
    set name(value) {
        this._name = value;
        this._updateRadioButtonNames();
    }
    /** Whether the labels should appear after or before the radio-buttons. Defaults to 'after' */
    get labelPosition() {
        return this._labelPosition;
    }
    set labelPosition(v) {
        this._labelPosition = v === 'before' ? 'before' : 'after';
        this._markRadiosForCheck();
    }
    /**
     * Value for the radio-group. Should equal the value of the selected radio button if there is
     * a corresponding radio button with a matching value. If there is not such a corresponding
     * radio button, this value persists to be applied in case a new radio button is added with a
     * matching value.
     */
    get value() {
        return this._value;
    }
    set value(newValue) {
        if (this._value !== newValue) {
            // Set this before proceeding to ensure no circular loop occurs with selection.
            this._value = newValue;
            this._updateSelectedRadioFromValue();
            this._checkSelectedRadioButton();
        }
    }
    _checkSelectedRadioButton() {
        if (this._selected && !this._selected.checked) {
            this._selected.checked = true;
        }
    }
    /**
     * The currently selected radio button. If set to a new radio button, the radio group value
     * will be updated to match the new selected button.
     */
    get selected() {
        return this._selected;
    }
    set selected(selected) {
        this._selected = selected;
        this.value = selected ? selected.value : null;
        this._checkSelectedRadioButton();
    }
    /** Whether the radio group is disabled */
    get disabled() {
        return this._disabled;
    }
    set disabled(value) {
        this._disabled = coerceBooleanProperty(value);
        this._markRadiosForCheck();
    }
    /** Whether the radio group is required */
    get required() {
        return this._required;
    }
    set required(value) {
        this._required = coerceBooleanProperty(value);
        this._markRadiosForCheck();
    }
    /**
     * Initialize properties once content children are available.
     * This allows us to propagate relevant attributes to associated buttons.
     */
    ngAfterContentInit() {
        // Mark this component as initialized in AfterContentInit because the initial value can
        // possibly be set by NgModel on MatRadioGroup, and it is possible that the OnInit of the
        // NgModel occurs *after* the OnInit of the MatRadioGroup.
        this._isInitialized = true;
    }
    /**
     * Mark this group as being "touched" (for ngModel). Meant to be called by the contained
     * radio buttons upon their blur.
     */
    _touch() {
        if (this.onTouched) {
            this.onTouched();
        }
    }
    _updateRadioButtonNames() {
        if (this._radios) {
            this._radios.forEach((radio) => {
                radio.name = this.name;
                radio._markForCheck();
            });
        }
    }
    /** Updates the `selected` radio button from the internal _value state. */
    _updateSelectedRadioFromValue() {
        // If the value already matches the selected radio, do nothing.
        const isAlreadySelected = this._selected !== null && this._selected.value === this._value;
        if (this._radios && !isAlreadySelected) {
            this._selected = null;
            this._radios.forEach((radio) => {
                radio.checked = this.value === radio.value;
                if (radio.checked) {
                    this._selected = radio;
                }
            });
        }
    }
    /** Determines whether to display hints or errors. */
    // This code is used across slide-toggle, radio, and checkboxes if update this here make sure to update in
    // the other places as well. We have decided for now not to make this in one spot because it would make it harder on
    // the user.
    _isError() {
        return this._errorChildren && this._errorChildren.length > 0;
    }
    /** Dispatch change event with current selection and group value. */
    _emitChangeEvent() {
        if (this._isInitialized) {
            this.change.emit(new MatRadioChange(this._selected, this._value));
        }
    }
    _markRadiosForCheck() {
        if (this._radios) {
            this._radios.forEach((radio) => radio._markForCheck());
        }
    }
    /**
     * Sets the model value. Implemented as part of ControlValueAccessor.
     * @param value
     */
    writeValue(value) {
        this.value = value;
        this._changeDetector.markForCheck();
    }
    /**
     * Registers a callback to be triggered when the model value changes.
     * Implemented as part of ControlValueAccessor.
     * @param fn Callback to be registered.
     */
    registerOnChange(fn) {
        this._controlValueAccessorChangeFn = fn;
    }
    /**
     * Registers a callback to be triggered when the control is touched.
     * Implemented as part of ControlValueAccessor.
     * @param fn Callback to be registered.
     */
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    /**
     * Sets the disabled state of the control. Implemented as a part of ControlValueAccessor.
     * @param isDisabled Whether the control should be disabled.
     */
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
        this._changeDetector.markForCheck();
    }
}
_MatRadioGroupBase.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: _MatRadioGroupBase, deps: [{ token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Directive });
_MatRadioGroupBase.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.3.11", type: _MatRadioGroupBase, inputs: { layoutHorizontal: "layoutHorizontal", errorText: "errorText", hintText: "hintText", color: "color", name: "name", labelPosition: "labelPosition", value: "value", selected: "selected", disabled: "disabled", required: "required" }, outputs: { change: "change" }, queries: [{ propertyName: "_errorChildren", predicate: MatError }], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: _MatRadioGroupBase, decorators: [{
            type: Directive
        }], ctorParameters: function () { return [{ type: i0.ChangeDetectorRef }]; }, propDecorators: { layoutHorizontal: [{
                type: Input
            }], errorText: [{
                type: Input
            }], hintText: [{
                type: Input
            }], change: [{
                type: Output
            }], _errorChildren: [{
                type: ContentChildren,
                args: [MatError]
            }], color: [{
                type: Input
            }], name: [{
                type: Input
            }], labelPosition: [{
                type: Input
            }], value: [{
                type: Input
            }], selected: [{
                type: Input
            }], disabled: [{
                type: Input
            }], required: [{
                type: Input
            }] } });
/**
 * A group of radio buttons. May contain one or more `<mat-radio-button>` elements.
 */
class MatRadioGroup extends _MatRadioGroupBase {
}
MatRadioGroup.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatRadioGroup, deps: null, target: i0.ɵɵFactoryTarget.Component });
MatRadioGroup.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.11", type: MatRadioGroup, selector: "mat-radio-group", host: { attributes: { "role": "radiogroup" }, classAttribute: "mat-radio-group" }, providers: [
        MAT_RADIO_GROUP_CONTROL_VALUE_ACCESSOR,
        { provide: MAT_RADIO_GROUP, useExisting: MatRadioGroup }
    ], queries: [{ propertyName: "_radios", predicate: i0.forwardRef(function () { return MatRadioButton; }), descendants: true }], exportAs: ["matRadioGroup"], usesInheritance: true, ngImport: i0, template: "<ng-content select=\"mat-radio-group-label\">\n</ng-content>\n<ng-content select=\"mat-popover-predefined\"></ng-content>\n\n<span class=\"mat-subscript-wrapper\">\n  <mat-hint *ngIf=\"hintText && !errorText\">{{hintText}}</mat-hint>\n  <mat-error *ngIf=\"errorText && errorText.length > 0\">{{errorText}}</mat-error>\n\n  <ng-content *ngIf=\"_isError() === false\"\n              select=\"mat-hint\"></ng-content>\n  <ng-content *ngIf=\"_isError()\"\n              select=\"mat-error\"></ng-content>\n</span>\n<span class=\"mat-radio-group-content\"\n      [class.mat-radio-group-horizontal]=\"layoutHorizontal\">\n  <ng-content></ng-content>\n</span>", styles: [".mat-radio-group{display:flex;flex-flow:column nowrap;padding-top:5px}.mat-radio-group .mat-radio-group-label{display:flex;font-size:.875rem;line-height:1rem;align-items:center}.mat-radio-group .mat-radio-group-label [vdl-icon-button]{height:16px}.mat-radio-group .mat-radio-group-label .mat-radio-label-popovers{padding-left:10px}[dir=rtl] .mat-radio-group .mat-radio-group-label .mat-radio-label-popovers{padding-right:10px;padding-left:0}.mat-radio-group>.mat-subscript-wrapper{display:flex;flex-direction:row;flex-shrink:0;max-width:100%;white-space:nowrap;overflow:hidden;margin-top:2px;margin-bottom:0;margin-left:0}.mat-radio-group .mat-radio-group-content{display:flex;flex-flow:column nowrap;margin:0;padding:0}.mat-radio-group .mat-radio-group-content.mat-radio-group-horizontal{flex-direction:row}.mat-radio-group .mat-radio-group-content.mat-radio-group-horizontal .mat-radio-button{margin-right:8px}[dir=rtl] .mat-radio-group .mat-radio-group-content.mat-radio-group-horizontal .mat-radio-button{margin-right:0;margin-left:8px}[dir=rtl] .mat-radio-group .mat-radio-group-content>.mat-radio-button .mat-subscript-wrapper{padding-left:0;margin-left:0}.mat-radio-group .mat-radio-group-content>.mat-radio-button.mat-radio-label-before .mat-subscript-wrapper{margin-left:0}[dir=rtl] .mat-radio-group .mat-radio-group-content>.mat-radio-button.mat-radio-label-before .mat-subscript-wrapper{padding-right:0}[dir=rtl] .mat-radio-group .mat-radio-group-content.mat-radio-group-horizontal>.mat-radio-button.mat-radio-label-before .mat-subscript-wrapper{margin-left:0;padding-right:0}.mat-radio-group.mat-radio-group-disabled .mat-radio-label-text,.mat-radio-group.mat-radio-group-disabled .mat-subscript-wrapper{opacity:.5;cursor:default}\n"], directives: [{ type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i2.MatHint, selector: "mat-hint", inputs: ["align", "id"] }, { type: i2.MatError, selector: "mat-error", inputs: ["id"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatRadioGroup, decorators: [{
            type: Component,
            args: [{ selector: 'mat-radio-group', exportAs: 'matRadioGroup', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        MAT_RADIO_GROUP_CONTROL_VALUE_ACCESSOR,
                        { provide: MAT_RADIO_GROUP, useExisting: MatRadioGroup }
                    ], host: {
                        role: 'radiogroup',
                        class: 'mat-radio-group'
                    }, template: "<ng-content select=\"mat-radio-group-label\">\n</ng-content>\n<ng-content select=\"mat-popover-predefined\"></ng-content>\n\n<span class=\"mat-subscript-wrapper\">\n  <mat-hint *ngIf=\"hintText && !errorText\">{{hintText}}</mat-hint>\n  <mat-error *ngIf=\"errorText && errorText.length > 0\">{{errorText}}</mat-error>\n\n  <ng-content *ngIf=\"_isError() === false\"\n              select=\"mat-hint\"></ng-content>\n  <ng-content *ngIf=\"_isError()\"\n              select=\"mat-error\"></ng-content>\n</span>\n<span class=\"mat-radio-group-content\"\n      [class.mat-radio-group-horizontal]=\"layoutHorizontal\">\n  <ng-content></ng-content>\n</span>", styles: [".mat-radio-group{display:flex;flex-flow:column nowrap;padding-top:5px}.mat-radio-group .mat-radio-group-label{display:flex;font-size:.875rem;line-height:1rem;align-items:center}.mat-radio-group .mat-radio-group-label [vdl-icon-button]{height:16px}.mat-radio-group .mat-radio-group-label .mat-radio-label-popovers{padding-left:10px}[dir=rtl] .mat-radio-group .mat-radio-group-label .mat-radio-label-popovers{padding-right:10px;padding-left:0}.mat-radio-group>.mat-subscript-wrapper{display:flex;flex-direction:row;flex-shrink:0;max-width:100%;white-space:nowrap;overflow:hidden;margin-top:2px;margin-bottom:0;margin-left:0}.mat-radio-group .mat-radio-group-content{display:flex;flex-flow:column nowrap;margin:0;padding:0}.mat-radio-group .mat-radio-group-content.mat-radio-group-horizontal{flex-direction:row}.mat-radio-group .mat-radio-group-content.mat-radio-group-horizontal .mat-radio-button{margin-right:8px}[dir=rtl] .mat-radio-group .mat-radio-group-content.mat-radio-group-horizontal .mat-radio-button{margin-right:0;margin-left:8px}[dir=rtl] .mat-radio-group .mat-radio-group-content>.mat-radio-button .mat-subscript-wrapper{padding-left:0;margin-left:0}.mat-radio-group .mat-radio-group-content>.mat-radio-button.mat-radio-label-before .mat-subscript-wrapper{margin-left:0}[dir=rtl] .mat-radio-group .mat-radio-group-content>.mat-radio-button.mat-radio-label-before .mat-subscript-wrapper{padding-right:0}[dir=rtl] .mat-radio-group .mat-radio-group-content.mat-radio-group-horizontal>.mat-radio-button.mat-radio-label-before .mat-subscript-wrapper{margin-left:0;padding-right:0}.mat-radio-group.mat-radio-group-disabled .mat-radio-label-text,.mat-radio-group.mat-radio-group-disabled .mat-subscript-wrapper{opacity:.5;cursor:default}\n"] }]
        }], propDecorators: { _radios: [{
                type: ContentChildren,
                args: [forwardRef(() => MatRadioButton), { descendants: true }]
            }] } });
// Boilerplate for applying mixins to MatRadioButton.
/** @docs-private */
class MatRadioButtonBase {
    constructor(_elementRef) {
        this._elementRef = _elementRef;
    }
}
const _MatRadioButtonMixinBase = mixinDisableRipple(mixinTabIndex(MatRadioButtonBase));
/**
 * Base class with all of the `MatRadioButton` functionality.
 * @docs-private
 */
class _MatRadioButtonBase extends _MatRadioButtonMixinBase {
    constructor(radioGroup, elementRef, _changeDetector, _focusMonitor, _radioDispatcher, animationMode, _providerOverride, tabIndex) {
        super(elementRef);
        this._changeDetector = _changeDetector;
        this._focusMonitor = _focusMonitor;
        this._radioDispatcher = _radioDispatcher;
        this._providerOverride = _providerOverride;
        this._uniqueId = `mat-radio-${++nextUniqueId}`;
        this.prevHintIDs = [];
        /** The unique ID for the radio button. */
        this.id = this._uniqueId;
        /**
         * Event emitted when the checked state of this radio button changes.
         * Change events are only emitted when the value changes due to user interaction with
         * the radio button (the same behavior as `<input type-"radio">`).
         */
        this.change = new EventEmitter();
        /** Whether this radio is checked. */
        this._checked = false;
        /** Value assigned to this radio. */
        this._value = null;
        /** Unregister function for _radioDispatcher */
        this._removeUniqueSelectionListener = () => { };
        // Assertions. Ideally these should be stripped out by the compiler.
        // TODO(jelbourn): Assert that there's no name binding AND a parent radio group.
        this.radioGroup = radioGroup;
        this._noopAnimations = animationMode === 'NoopAnimations';
        if (tabIndex) {
            this.tabIndex = coerceNumberProperty(tabIndex, 0);
        }
        this._removeUniqueSelectionListener = _radioDispatcher.listen((id, name) => {
            if (id !== this.id && name === this.name) {
                this.checked = false;
            }
        });
    }
    /** Optionally specify the hint text, which is rendered below the radio button. */
    get hintText() {
        return this._hintText;
    }
    set hintText(value) {
        const hintChanged = !this._hintText || !value;
        this._hintText = value;
        if (hintChanged) {
            this._changeDetector.detectChanges();
            this._processHints();
        }
    }
    /** Whether this radio button is checked. */
    get checked() {
        return this._checked;
    }
    set checked(value) {
        const newCheckedState = coerceBooleanProperty(value);
        if (this._checked !== newCheckedState) {
            this._checked = newCheckedState;
            if (newCheckedState &&
                this.radioGroup &&
                this.radioGroup.value !== this.value) {
                this.radioGroup.selected = this;
            }
            else if (!newCheckedState &&
                this.radioGroup &&
                this.radioGroup.value === this.value) {
                // When unchecking the selected radio button, update the selected radio
                // property on the group.
                this.radioGroup.selected = null;
            }
            if (newCheckedState) {
                // Notify all radio buttons with the same name to un-check.
                this._radioDispatcher.notify(this.id, this.name);
            }
            this._changeDetector.markForCheck();
        }
    }
    /** The value of this radio button. */
    get value() {
        return this._value;
    }
    set value(value) {
        if (this._value !== value) {
            this._value = value;
            if (this.radioGroup !== null) {
                if (!this.checked) {
                    // Update checked when the value changed to match the radio group's value
                    this.checked = this.radioGroup.value === value;
                }
                if (this.checked) {
                    this.radioGroup.selected = this;
                }
            }
        }
    }
    /** Whether the label should appear after or before the radio button. Defaults to 'after' */
    get labelPosition() {
        return (this._labelPosition ||
            (this.radioGroup && this.radioGroup.labelPosition) ||
            'after');
    }
    set labelPosition(value) {
        this._labelPosition = value;
    }
    /** Whether the radio button is disabled. */
    get disabled() {
        return (this._disabled || (this.radioGroup !== null && this.radioGroup.disabled));
    }
    set disabled(value) {
        this._setDisabled(coerceBooleanProperty(value));
    }
    /** Whether the radio button is required. */
    get required() {
        return this._required || (this.radioGroup && this.radioGroup.required);
    }
    set required(value) {
        this._required = coerceBooleanProperty(value);
    }
    /** Theme color of the radio button. */
    get color() {
        // As per Material design specifications the selection control radio should use the accent color
        // palette by default. https://material.io/guidelines/components/selection-controls.html
        // VDL Change: changes default color to primary
        return (this._color ||
            (this.radioGroup && this.radioGroup.color) ||
            (this._providerOverride && this._providerOverride.color) ||
            'primary');
    }
    set color(newValue) {
        this._color = newValue;
    }
    /** ID of the native input element inside `<mat-radio-button>` */
    get inputId() {
        return `${this.id || this._uniqueId}-input`;
    }
    /** Focuses the radio button. */
    focus(options, origin) {
        if (origin) {
            this._focusMonitor.focusVia(this._inputElement, origin, options);
        }
        else {
            this._inputElement.nativeElement.focus(options);
        }
    }
    /**
     * Marks the radio button as needing checking for change detection.
     * This method is exposed because the parent radio group will directly
     * update bound properties of the radio button.
     */
    _markForCheck() {
        // When group value changes, the button will not be notified. Use `markForCheck` to explicit
        // update radio button's status
        this._changeDetector.markForCheck();
    }
    ngOnInit() {
        if (this.radioGroup) {
            // If the radio is inside a radio group, determine if it should be checked
            this.checked = this.radioGroup.value === this._value;
            if (this.checked) {
                this.radioGroup.selected = this;
            }
            // Copy name from parent radio group
            this.name = this.radioGroup.name;
        }
    }
    ngDoCheck() {
        this._updateTabIndex();
    }
    ngAfterViewInit() {
        this._updateTabIndex();
        this._focusMonitor
            .monitor(this._elementRef, true)
            .subscribe((focusOrigin) => {
            if (!focusOrigin && this.radioGroup) {
                this.radioGroup._touch();
            }
        });
        this._processHints();
        this._matHints.changes.subscribe(() => {
            this._processHints();
        });
    }
    ngOnDestroy() {
        this._focusMonitor.stopMonitoring(this._elementRef);
        this._removeUniqueSelectionListener();
    }
    /** Dispatch change event with current value. */
    _emitChangeEvent() {
        this.change.emit(new MatRadioChange(this, this._value));
    }
    _isRippleDisabled() {
        return this.disableRipple || this.disabled;
    }
    _onInputClick(event) {
        // We have to stop propagation for click events on the visual hidden input element.
        // By default, when a user clicks on a label element, a generated click event will be
        // dispatched on the associated input element. Since we are using a label element as our
        // root container, the click event on the `radio-button` will be executed twice.
        // The real click event will bubble up, and the generated click event also tries to bubble up.
        // This will lead to multiple click events.
        // Preventing bubbling for the second event will solve that issue.
        event.stopPropagation();
    }
    /** Triggered when the radio button receives an interaction from the user. */
    _onInputInteraction(event) {
        // We always have to stop propagation on the change event.
        // Otherwise the change event, from the input element, will bubble up and
        // emit its event object to the `change` output.
        event.stopPropagation();
        if (!this.checked && !this.disabled) {
            const groupValueChanged = this.radioGroup && this.value !== this.radioGroup.value;
            this.checked = true;
            this._emitChangeEvent();
            if (this.radioGroup) {
                this.radioGroup._controlValueAccessorChangeFn(this.value);
                if (groupValueChanged) {
                    this.radioGroup._emitChangeEvent();
                }
            }
        }
    }
    /** Processes mat-hint ids and adds them to the input aria-describedby */
    _processHints() {
        if (!this._matHints && !this._staticHint) {
            return;
        }
        const hintIDs = [];
        if (this._staticHint) {
            hintIDs.push(this._staticHint.nativeElement.id);
        }
        if (this._matHints) {
            this._matHints.forEach((hint) => {
                hintIDs.push(hint.id);
            });
        }
        let currentIDs = this.ariaDescribedby
            ? this.ariaDescribedby.split(',')
            : [];
        currentIDs = currentIDs.filter((id) => !this.prevHintIDs.includes(id));
        const newAriaDescribedby = currentIDs.concat(hintIDs).toString();
        this.ariaDescribedby =
            newAriaDescribedby.length > 0 ? newAriaDescribedby : undefined;
        this._changeDetector.detectChanges();
        this.prevHintIDs = hintIDs;
    }
    /** Sets the disabled state and marks for check if a change occurred. */
    _setDisabled(value) {
        if (this._disabled !== value) {
            this._disabled = value;
            this._changeDetector.markForCheck();
        }
    }
    /** Gets the tabindex for the underlying input element. */
    _updateTabIndex() {
        const group = this.radioGroup;
        let value;
        // Implement a roving tabindex if the button is inside a group. For most cases this isn't
        // necessary, because the browser handles the tab order for inputs inside a group automatically,
        // but we need an explicitly higher tabindex for the selected button in order for things like
        // the focus trap to pick it up correctly.
        if (!group || !group.selected || this.disabled) {
            value = this.tabIndex;
        }
        else {
            value = group.selected === this ? this.tabIndex : -1;
        }
        if (value !== this._previousTabIndex) {
            // We have to set the tabindex directly on the DOM node, because it depends on
            // the selected state which is prone to "changed after checked errors".
            const input = this._inputElement?.nativeElement;
            if (input) {
                input.setAttribute('tabindex', value + '');
                this._previousTabIndex = value;
            }
        }
    }
}
_MatRadioButtonBase.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: _MatRadioButtonBase, deps: "invalid", target: i0.ɵɵFactoryTarget.Directive });
_MatRadioButtonBase.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.3.11", type: _MatRadioButtonBase, inputs: { id: "id", name: "name", ariaLabel: ["aria-label", "ariaLabel"], ariaLabelledby: ["aria-labelledby", "ariaLabelledby"], ariaDescribedby: ["aria-describedby", "ariaDescribedby"], hintText: "hintText", checked: "checked", value: "value", labelPosition: "labelPosition", disabled: "disabled", required: "required", color: "color" }, outputs: { change: "change" }, queries: [{ propertyName: "_matHints", predicate: i0.forwardRef(function () { return MatHint; }) }], viewQueries: [{ propertyName: "_inputElement", first: true, predicate: ["input"], descendants: true }, { propertyName: "_staticHint", first: true, predicate: ["staticHint"], descendants: true }], usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: _MatRadioButtonBase, decorators: [{
            type: Directive
        }], ctorParameters: function () { return [{ type: _MatRadioGroupBase }, { type: i0.ElementRef }, { type: i0.ChangeDetectorRef }, { type: i3.FocusMonitor }, { type: i4.UniqueSelectionDispatcher }, { type: undefined }, { type: undefined }, { type: undefined }]; }, propDecorators: { id: [{
                type: Input
            }], name: [{
                type: Input
            }], ariaLabel: [{
                type: Input,
                args: ['aria-label']
            }], ariaLabelledby: [{
                type: Input,
                args: ['aria-labelledby']
            }], ariaDescribedby: [{
                type: Input,
                args: ['aria-describedby']
            }], hintText: [{
                type: Input
            }], checked: [{
                type: Input
            }], value: [{
                type: Input
            }], labelPosition: [{
                type: Input
            }], disabled: [{
                type: Input
            }], required: [{
                type: Input
            }], color: [{
                type: Input
            }], change: [{
                type: Output
            }], _inputElement: [{
                type: ViewChild,
                args: ['input']
            }], _staticHint: [{
                type: ViewChild,
                args: ['staticHint']
            }], _matHints: [{
                type: ContentChildren,
                args: [forwardRef(() => MatHint)]
            }] } });
/**
 * A Material design radio-button. Typically placed inside of `<mat-radio-group>` elements.
 */
class MatRadioButton extends _MatRadioButtonBase {
    constructor(radioGroup, elementRef, changeDetector, focusMonitor, radioDispatcher, animationMode, providerOverride, tabIndex) {
        super(radioGroup, elementRef, changeDetector, focusMonitor, radioDispatcher, animationMode, providerOverride, tabIndex);
    }
}
MatRadioButton.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatRadioButton, deps: [{ token: MAT_RADIO_GROUP, optional: true }, { token: i0.ElementRef }, { token: i0.ChangeDetectorRef }, { token: i3.FocusMonitor }, { token: i4.UniqueSelectionDispatcher }, { token: ANIMATION_MODULE_TYPE, optional: true }, { token: MAT_RADIO_DEFAULT_OPTIONS, optional: true }, { token: 'tabindex', attribute: true }], target: i0.ɵɵFactoryTarget.Component });
MatRadioButton.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.11", type: MatRadioButton, selector: "mat-radio-button", inputs: { disableRipple: "disableRipple", tabIndex: "tabIndex" }, host: { listeners: { "focus": "_inputElement.nativeElement.focus()" }, properties: { "class.mat-radio-checked": "checked", "class.mat-radio-disabled": "disabled", "class._mat-animation-noopable": "_noopAnimations", "class.mat-primary": "color === \"primary\"", "class.mat-accent": "color === \"accent\"", "class.mat-warn": "color === \"warn\"", "attr.tabindex": "null", "attr.id": "id", "attr.aria-label": "null", "attr.aria-labelledby": "null", "attr.aria-describedby": "null" }, classAttribute: "mat-radio-button" }, exportAs: ["matRadioButton"], usesInheritance: true, ngImport: i0, template: "<!-- TODO(jelbourn): render the radio on either side of the content -->\n<!-- TODO(mtlin): Evaluate trade-offs of using native radio vs. cost of additional bindings. -->\n\n<span class=\"mat-radio-wrapper\">\n\n  <label [attr.for]=\"inputId\"\n         class=\"mat-radio-label\"\n         #label>\n    <!-- The actual 'radio' part of the control. -->\n    <span class=\"mat-radio-container\">\n      <span class=\"mat-radio-outer-circle\"></span>\n      <span class=\"mat-radio-inner-circle\"></span>\n      <input #input\n             class=\"mat-radio-input\"\n             type=\"radio\"\n             [id]=\"inputId\"\n             [checked]=\"checked\"\n             [disabled]=\"disabled\"\n             [attr.name]=\"name\"\n             [attr.value]=\"value\"\n             [required]=\"required\"\n             [attr.aria-label]=\"ariaLabel\"\n             [attr.aria-labelledby]=\"ariaLabelledby\"\n             [attr.aria-describedby]=\"ariaDescribedby\"\n             (change)=\"_onInputInteraction($event)\"\n             (click)=\"_onInputClick($event)\">\n\n      <!-- The ripple comes after the input so that we can target it with a CSS\n         sibling selector when the input is focused. -->\n      <span mat-ripple\n            class=\"mat-radio-ripple mat-focus-indicator\"\n            [matRippleTrigger]=\"label\"\n            [matRippleDisabled]=\"_isRippleDisabled()\"\n            [matRippleCentered]=\"true\"\n            [matRippleRadius]=\"20\"\n            [matRippleAnimation]=\"{enterDuration: _noopAnimations ? 0 : 150}\">\n\n        <span class=\"mat-ripple-element mat-radio-persistent-ripple\"></span>\n      </span>\n    </span>\n    <span class=\"mat-radio-label-content\"\n          [class.mat-radio-label-before]=\"labelPosition === 'before'\">\n      <!-- Add an invisible span so JAWS can read the label -->\n      <span style=\"display:none\">&nbsp;</span>\n      <ng-content></ng-content>\n    </span>\n\n  </label>\n  <ng-content select=\"mat-popover-predefined\"></ng-content>\n</span>\n\n<span #matHintContainer\n      class=\"mat-subscript-wrapper\">\n  <mat-hint *ngIf=\"hintText\"\n            #staticHint>{{hintText}}</mat-hint>\n  <ng-content select=\"mat-hint\"></ng-content>\n</span>", styles: [".mat-radio-button{display:inline-block;-webkit-tap-highlight-color:transparent;outline:0;padding-top:5px}.mat-radio-button .mat-radio-wrapper{align-self:flex-start;display:flex;flex-direction:row}.mat-radio-button .mat-radio-wrapper .mat-popover-predefined{display:flex;margin-left:5px}[dir=rtl] .mat-radio-button .mat-radio-wrapper .mat-popover-predefined{margin-left:0;margin-right:5px}.mat-radio-label{-webkit-user-select:none;user-select:none;cursor:pointer;align-items:center;white-space:nowrap;height:25px;display:flex;vertical-align:middle}.mat-radio-container{box-sizing:border-box;display:inline-block;position:relative;width:18px;height:18px;flex-shrink:0}.mat-radio-outer-circle{box-sizing:border-box;display:block;height:18px;left:0;position:absolute;top:0;transition:border-color ease .28s;width:18px;border-width:1px;border-style:solid;border-radius:50%}._mat-animation-noopable .mat-radio-outer-circle{transition:none}.mat-radio-inner-circle{border-radius:50%;box-sizing:border-box;display:block;height:18px;left:0;position:absolute;top:0;opacity:0;transition:transform ease .28s,background-color ease .28s,opacity linear 1ms .28s;width:18px;transform:scale(.001);-webkit-print-color-adjust:exact;color-adjust:exact}.mat-radio-checked .mat-radio-inner-circle{transform:scale(.65);opacity:1;transition:transform ease .28s,background-color ease .28s}.cdk-high-contrast-active .mat-radio-checked .mat-radio-inner-circle{border:solid 9px}._mat-animation-noopable .mat-radio-inner-circle{transition:none}.mat-radio-label-content{-webkit-user-select:auto;user-select:auto;display:inline-block;order:0;line-height:inherit;padding-left:8px;padding-right:0}[dir=rtl] .mat-radio-label-content{padding-right:8px;padding-left:0}.mat-radio-label-content.mat-radio-label-before{order:-1;padding-left:0;padding-right:8px}[dir=rtl] .mat-radio-label-content.mat-radio-label-before{padding-right:0;padding-left:8px}.mat-radio-disabled,.mat-radio-disabled .mat-radio-label{cursor:default}.mat-radio-button .mat-radio-ripple{position:absolute;left:calc(50% - 20px);top:calc(50% - 20px);height:40px;width:40px;z-index:1;pointer-events:none}.mat-radio-button .mat-radio-ripple .mat-ripple-element:not(.mat-radio-persistent-ripple){opacity:.16}.mat-radio-persistent-ripple{width:100%;height:100%;transform:none;top:0;left:0}.mat-radio-container:hover .mat-radio-persistent-ripple{opacity:.04}.mat-radio-button:not(.mat-radio-disabled).cdk-keyboard-focused .mat-radio-persistent-ripple,.mat-radio-button:not(.mat-radio-disabled).cdk-program-focused .mat-radio-persistent-ripple{opacity:.12}.mat-radio-persistent-ripple,.mat-radio-disabled .mat-radio-container:hover .mat-radio-persistent-ripple{opacity:0}@media (hover: none){.mat-radio-container:hover .mat-radio-persistent-ripple{display:none}}.mat-radio-input{opacity:0;position:absolute;top:0;left:0;margin:0;width:100%;height:100%;cursor:inherit;z-index:-1}.cdk-high-contrast-active .mat-radio-button:not(.mat-radio-disabled).cdk-keyboard-focused .mat-radio-ripple,.cdk-high-contrast-active .mat-radio-button:not(.mat-radio-disabled).cdk-program-focused .mat-radio-ripple{outline:solid 3px}.cdk-high-contrast-active .mat-radio-disabled{opacity:.5}\n"], directives: [{ type: i5.MatRipple, selector: "[mat-ripple], [matRipple]", inputs: ["matRippleColor", "matRippleUnbounded", "matRippleCentered", "matRippleRadius", "matRippleAnimation", "matRippleDisabled", "matRippleTrigger"], exportAs: ["matRipple"] }, { type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i2.MatHint, selector: "mat-hint", inputs: ["align", "id"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatRadioButton, decorators: [{
            type: Component,
            args: [{ selector: 'mat-radio-button', inputs: ['disableRipple', 'tabIndex'], encapsulation: ViewEncapsulation.None, exportAs: 'matRadioButton', host: {
                        class: 'mat-radio-button',
                        '[class.mat-radio-checked]': 'checked',
                        '[class.mat-radio-disabled]': 'disabled',
                        '[class._mat-animation-noopable]': '_noopAnimations',
                        '[class.mat-primary]': 'color === "primary"',
                        '[class.mat-accent]': 'color === "accent"',
                        '[class.mat-warn]': 'color === "warn"',
                        // Needs to be removed since it causes some a11y issues (see #21266).
                        '[attr.tabindex]': 'null',
                        '[attr.id]': 'id',
                        '[attr.aria-label]': 'null',
                        '[attr.aria-labelledby]': 'null',
                        '[attr.aria-describedby]': 'null',
                        // Note: under normal conditions focus shouldn't land on this element, however it may be
                        // programmatically set, for example inside of a focus trap, in this case we want to forward
                        // the focus to the native element.
                        '(focus)': '_inputElement.nativeElement.focus()'
                    }, changeDetection: ChangeDetectionStrategy.OnPush, template: "<!-- TODO(jelbourn): render the radio on either side of the content -->\n<!-- TODO(mtlin): Evaluate trade-offs of using native radio vs. cost of additional bindings. -->\n\n<span class=\"mat-radio-wrapper\">\n\n  <label [attr.for]=\"inputId\"\n         class=\"mat-radio-label\"\n         #label>\n    <!-- The actual 'radio' part of the control. -->\n    <span class=\"mat-radio-container\">\n      <span class=\"mat-radio-outer-circle\"></span>\n      <span class=\"mat-radio-inner-circle\"></span>\n      <input #input\n             class=\"mat-radio-input\"\n             type=\"radio\"\n             [id]=\"inputId\"\n             [checked]=\"checked\"\n             [disabled]=\"disabled\"\n             [attr.name]=\"name\"\n             [attr.value]=\"value\"\n             [required]=\"required\"\n             [attr.aria-label]=\"ariaLabel\"\n             [attr.aria-labelledby]=\"ariaLabelledby\"\n             [attr.aria-describedby]=\"ariaDescribedby\"\n             (change)=\"_onInputInteraction($event)\"\n             (click)=\"_onInputClick($event)\">\n\n      <!-- The ripple comes after the input so that we can target it with a CSS\n         sibling selector when the input is focused. -->\n      <span mat-ripple\n            class=\"mat-radio-ripple mat-focus-indicator\"\n            [matRippleTrigger]=\"label\"\n            [matRippleDisabled]=\"_isRippleDisabled()\"\n            [matRippleCentered]=\"true\"\n            [matRippleRadius]=\"20\"\n            [matRippleAnimation]=\"{enterDuration: _noopAnimations ? 0 : 150}\">\n\n        <span class=\"mat-ripple-element mat-radio-persistent-ripple\"></span>\n      </span>\n    </span>\n    <span class=\"mat-radio-label-content\"\n          [class.mat-radio-label-before]=\"labelPosition === 'before'\">\n      <!-- Add an invisible span so JAWS can read the label -->\n      <span style=\"display:none\">&nbsp;</span>\n      <ng-content></ng-content>\n    </span>\n\n  </label>\n  <ng-content select=\"mat-popover-predefined\"></ng-content>\n</span>\n\n<span #matHintContainer\n      class=\"mat-subscript-wrapper\">\n  <mat-hint *ngIf=\"hintText\"\n            #staticHint>{{hintText}}</mat-hint>\n  <ng-content select=\"mat-hint\"></ng-content>\n</span>", styles: [".mat-radio-button{display:inline-block;-webkit-tap-highlight-color:transparent;outline:0;padding-top:5px}.mat-radio-button .mat-radio-wrapper{align-self:flex-start;display:flex;flex-direction:row}.mat-radio-button .mat-radio-wrapper .mat-popover-predefined{display:flex;margin-left:5px}[dir=rtl] .mat-radio-button .mat-radio-wrapper .mat-popover-predefined{margin-left:0;margin-right:5px}.mat-radio-label{-webkit-user-select:none;user-select:none;cursor:pointer;align-items:center;white-space:nowrap;height:25px;display:flex;vertical-align:middle}.mat-radio-container{box-sizing:border-box;display:inline-block;position:relative;width:18px;height:18px;flex-shrink:0}.mat-radio-outer-circle{box-sizing:border-box;display:block;height:18px;left:0;position:absolute;top:0;transition:border-color ease .28s;width:18px;border-width:1px;border-style:solid;border-radius:50%}._mat-animation-noopable .mat-radio-outer-circle{transition:none}.mat-radio-inner-circle{border-radius:50%;box-sizing:border-box;display:block;height:18px;left:0;position:absolute;top:0;opacity:0;transition:transform ease .28s,background-color ease .28s,opacity linear 1ms .28s;width:18px;transform:scale(.001);-webkit-print-color-adjust:exact;color-adjust:exact}.mat-radio-checked .mat-radio-inner-circle{transform:scale(.65);opacity:1;transition:transform ease .28s,background-color ease .28s}.cdk-high-contrast-active .mat-radio-checked .mat-radio-inner-circle{border:solid 9px}._mat-animation-noopable .mat-radio-inner-circle{transition:none}.mat-radio-label-content{-webkit-user-select:auto;user-select:auto;display:inline-block;order:0;line-height:inherit;padding-left:8px;padding-right:0}[dir=rtl] .mat-radio-label-content{padding-right:8px;padding-left:0}.mat-radio-label-content.mat-radio-label-before{order:-1;padding-left:0;padding-right:8px}[dir=rtl] .mat-radio-label-content.mat-radio-label-before{padding-right:0;padding-left:8px}.mat-radio-disabled,.mat-radio-disabled .mat-radio-label{cursor:default}.mat-radio-button .mat-radio-ripple{position:absolute;left:calc(50% - 20px);top:calc(50% - 20px);height:40px;width:40px;z-index:1;pointer-events:none}.mat-radio-button .mat-radio-ripple .mat-ripple-element:not(.mat-radio-persistent-ripple){opacity:.16}.mat-radio-persistent-ripple{width:100%;height:100%;transform:none;top:0;left:0}.mat-radio-container:hover .mat-radio-persistent-ripple{opacity:.04}.mat-radio-button:not(.mat-radio-disabled).cdk-keyboard-focused .mat-radio-persistent-ripple,.mat-radio-button:not(.mat-radio-disabled).cdk-program-focused .mat-radio-persistent-ripple{opacity:.12}.mat-radio-persistent-ripple,.mat-radio-disabled .mat-radio-container:hover .mat-radio-persistent-ripple{opacity:0}@media (hover: none){.mat-radio-container:hover .mat-radio-persistent-ripple{display:none}}.mat-radio-input{opacity:0;position:absolute;top:0;left:0;margin:0;width:100%;height:100%;cursor:inherit;z-index:-1}.cdk-high-contrast-active .mat-radio-button:not(.mat-radio-disabled).cdk-keyboard-focused .mat-radio-ripple,.cdk-high-contrast-active .mat-radio-button:not(.mat-radio-disabled).cdk-program-focused .mat-radio-ripple{outline:solid 3px}.cdk-high-contrast-active .mat-radio-disabled{opacity:.5}\n"] }]
        }], ctorParameters: function () { return [{ type: MatRadioGroup, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [MAT_RADIO_GROUP]
                }] }, { type: i0.ElementRef }, { type: i0.ChangeDetectorRef }, { type: i3.FocusMonitor }, { type: i4.UniqueSelectionDispatcher }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [ANIMATION_MODULE_TYPE]
                }] }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [MAT_RADIO_DEFAULT_OPTIONS]
                }] }, { type: undefined, decorators: [{
                    type: Attribute,
                    args: ['tabindex']
                }] }]; } });

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
class MatRadioModule {
}
MatRadioModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatRadioModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
MatRadioModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatRadioModule, declarations: [MatRadioGroup, MatRadioButton, MatRadioGroupLabel], imports: [MatRippleModule, MatCommonModule, MatFormFieldModule, CommonModule], exports: [MatRadioGroup, MatRadioButton, MatCommonModule, MatRadioGroupLabel] });
MatRadioModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatRadioModule, imports: [[MatRippleModule, MatCommonModule, MatFormFieldModule, CommonModule], MatCommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatRadioModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [MatRippleModule, MatCommonModule, MatFormFieldModule, CommonModule],
                    exports: [MatRadioGroup, MatRadioButton, MatCommonModule, MatRadioGroupLabel],
                    declarations: [MatRadioGroup, MatRadioButton, MatRadioGroupLabel]
                }]
        }] });

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */

/**
 * Generated bundle index. Do not edit.
 */

export { MAT_RADIO_DEFAULT_OPTIONS, MAT_RADIO_DEFAULT_OPTIONS_FACTORY, MAT_RADIO_GROUP, MAT_RADIO_GROUP_CONTROL_VALUE_ACCESSOR, MatRadioButton, MatRadioChange, MatRadioGroup, MatRadioGroupLabel, MatRadioModule, _MatRadioButtonBase, _MatRadioGroupBase };
//# sourceMappingURL=vdlx-vdl-angular-mat-radio.mjs.map
