import { Directionality } from '@angular/cdk/bidi';
import { ChangeDetectorRef, DoCheck, ElementRef, EventEmitter, KeyValueDiffers, OnDestroy, OnInit } from '@angular/core';
import { MatIconRegistry } from '@vdlx/vdl-angular/mat/icon';
import { MatCell, MatColumnDef } from './cell';
import * as i0 from "@angular/core";
/** Adds wraps content within td cells so they can be animated when they are expanded or collapsed */
export declare class MatCellAnimated extends MatCell {
    constructor(columnDef: MatColumnDef, elementRef: ElementRef<HTMLElement>);
    static ɵfac: i0.ɵɵFactoryDeclaration<MatCellAnimated, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MatCellAnimated, "td[mat-cell-animated]", never, {}, {}, never, ["*"]>;
}
/** Expander for table tree */
export declare class MatTableTreeExpander {
    private changeDetectorRef;
    private _dir;
    /** Rotation in deg based on directionality context. Default is rotate(0deg) */
    closedRotation: string;
    /** Emits when the component is destroyed. */
    private readonly _destroyed;
    /** Aria label for expander icon */
    ariaLabel: string;
    /** Whether node is collapsed */
    isCollapsed: boolean;
    /** Whether node has child nodes */
    hasChildren: boolean;
    /** Emits event when expander is toggled */
    expanderToggleEvent: EventEmitter<MatTableRowExpanderToggleEvent>;
    constructor(matIconRegistry: MatIconRegistry, changeDetectorRef: ChangeDetectorRef, _dir: Directionality);
    static ɵfac: i0.ɵɵFactoryDeclaration<MatTableTreeExpander, [null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MatTableTreeExpander, "mat-table-tree-expander", never, { "ariaLabel": "aria-label"; "isCollapsed": "isCollapsed"; "hasChildren": "hasChildren"; }, { "expanderToggleEvent": "expanderToggleEvent"; }, never, never>;
}
export interface MatTableRowExpanderToggleEvent {
    isCollapsed: boolean;
}
/** Cell template container that adds the right classes and role. */
export declare class MatTreeCell extends MatCell implements OnInit, DoCheck, OnDestroy {
    private changeDetectorRef;
    private keyValueDiffers;
    private _dir;
    cellWrapper: ElementRef<HTMLElement>;
    treeExpander: MatTableTreeExpander;
    /** Emits event when expander is toggled */
    expanderToggleEvent: EventEmitter<MatTableRowExpanderToggleEvent>;
    /** Current padding value applied to the element. Used to avoid unnecessarily hitting the DOM. */
    private _currentPadding;
    /** Subject that emits when the component has been destroyed. */
    private _destroyed;
    /** Key Value differ for checking changes in node data */
    private keyValueDiffer;
    /** CSS units used for the indentation value. Default is 'px' */
    indentUnits: string;
    /**
     * Whether data is displayed indented or not. For Example when sorting, the
     * data is no longer in a hierarchical structure.
     */
    get disableIndentation(): boolean;
    set disableIndentation(value: boolean);
    _disableIndentation: boolean;
    /** Shows/Hides the expander. Default is true */
    isExpandable: boolean;
    /** Sets the aria-label for the table tree node expander */
    expanderAriaLabel: string;
    /** Row data for the Table Tree node */
    tableTreeNode: any;
    /** Property name for the node level key in the Row Data. Defaults to '_nodeTreeLevel' */
    nodeTreeLevelPropertyName: string;
    /** Property name for the node collapsed key in the Row Data. Defaults to '_nodeCollapsed' */
    nodeCollapsedPropertyName: string;
    /**
     * The max level of depth in the tree.
     */
    maxLevel: number;
    /** Whether the node has children */
    hasChildren: boolean;
    /** The indent for each level. Default is 35 from VDL design.
     * @docs-private
     */
    get indent(): number | string;
    set indent(indent: number | string);
    _indent: number;
    /** Emits an event when the node expander has been triggered */
    collapseNodeEvent: EventEmitter<MatTableTreeNodeCollapseEventType>;
    constructor(columnDef: MatColumnDef, elementRef: ElementRef<HTMLElement>, changeDetectorRef: ChangeDetectorRef, keyValueDiffers: KeyValueDiffers, _dir: Directionality);
    ngOnInit(): void;
    ngDoCheck(): void;
    ngOnDestroy(): void;
    /** Toggles the tree node collapsed property on expander toggle event */
    expanderToggledEvent(): void;
    /** Resets indentation after content has changed */
    onContentChange(): void;
    /** Returns if node is collapsed */
    isCollapsed(): boolean;
    /** Returns the hierarhy level for the node else returns 0 */
    getLevel(): number;
    /** Sets the indentation according to the hierarchy level for the node */
    _setPadding(forceChange?: boolean): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<MatTreeCell, [null, null, null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MatTreeCell, "mat-cell[mat-tree-cell], td[mat-tree-cell]", never, { "disableIndentation": "disableIndentation"; "isExpandable": "isExpandable"; "expanderAriaLabel": "matNodeExpanderAriaLabel"; "tableTreeNode": "matTableTreeNode"; "nodeTreeLevelPropertyName": "nodeTreeLevelPropertyName"; "nodeCollapsedPropertyName": "nodeCollapsedPropertyName"; "maxLevel": "matTableTreeCellMaxLevel"; "hasChildren": "hasChildren"; "indent": "matTableTreeCellIndent"; }, { "expanderToggleEvent": "expanderToggleEvent"; "collapseNodeEvent": "matTableTreeNodeCollapseEvent"; }, never, ["*"]>;
}
export interface MatTableTreeNodeCollapseEventType {
    node: any;
}
//# sourceMappingURL=cell-tree.d.ts.map