import * as i5$1 from '@angular/common';
import { DOCUMENT, CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { Injectable, Optional, SkipSelf, EventEmitter, Component, ChangeDetectionStrategy, ViewEncapsulation, Input, Output, Directive, Inject, ContentChildren, ContentChild, forwardRef, NgModule } from '@angular/core';
import * as i2 from '@vdlx/vdl-angular/mat/button';
import { MatButtonModule } from '@vdlx/vdl-angular/mat/button';
import { MatCardModule } from '@vdlx/vdl-angular/mat/card';
import * as i5 from '@vdlx/vdl-angular/mat/checkbox';
import { MatCheckboxModule } from '@vdlx/vdl-angular/mat/checkbox';
import { mixinColor, MatCommonModule } from '@vdlx/vdl-angular/mat/core';
import * as i3 from '@vdlx/vdl-angular/mat/icon';
import { MatIconModule } from '@vdlx/vdl-angular/mat/icon';
import * as i4 from '@vdlx/vdl-angular/mat/menu';
import { MatMenuModule } from '@vdlx/vdl-angular/mat/menu';
import * as i6 from '@vdlx/vdl-angular/mat/tooltip';
import { MatTooltipModule } from '@vdlx/vdl-angular/mat/tooltip';
import { Subject } from 'rxjs';
import * as i7 from '@angular/cdk/platform';
import { trigger, state, style, transition, animate } from '@angular/animations';

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
/**
 * To modify the labels and text displayed, create a new instance of MatGlobalHelpIntl and include it in a custom provider.
 */
class MatToolbarIntl {
    constructor() {
        /**
         * Stream that emits whenever the labels here are changed. Use this to notify
         * components if the labels have changed after initialization.
         */
        this.changes = new Subject();
        /** Values for mat-toolbar-overlay
         **************************************************/
        /** Aria label for the toolbar overlay close button. */
        this.toolbarOverlayCloseAriaLabel = 'Close toolbar overlay';
        /** Text for the toolbar overlay close button. */
        this.toolbarOverlayCloseTooltip = 'Close toolbar overlay';
        /** Template for rendering the toolbar overlay title */
        this.toolbarOverlaySelectedTemplate = '${selected} Selected';
        /** Values for mat-toolbar-filter
         **************************************************/
        /** Template for rendering the toolbar filter tooltip */
        this.toolbarFilterTooltip = 'Toggle table filter';
        /** Template for rendering the toolbar filter aria label */
        this.toolbarFilterAriaLabel = 'Toggle table filter panel';
        /** Values for mat-toolbar-selection-list
         **************************************************/
        /** Template for rendering the toolbar selection list tooltip */
        this.toolbarSelectionListTooltip = 'Toggle Selection List';
        /** Template for rendering the toolbar selection list aria label */
        this.toolbarSelectionListAriaLabel = 'Toggle Selection List';
    }
}
MatToolbarIntl.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatToolbarIntl, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
MatToolbarIntl.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatToolbarIntl, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatToolbarIntl, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }] });
/** @docs-private */
function MAT_TOOLBAR_INTL_PROVIDER_FACTORY(parentIntl) {
    return parentIntl || new MatToolbarIntl();
}
/** @docs-private */
const MAT_TOOLBAR_INTL_PROVIDER = {
    // If there is already an MatToolbarIntl available, use that. Otherwise, provide a new one.
    provide: MatToolbarIntl,
    deps: [[new Optional(), new SkipSelf(), MatToolbarIntl]],
    useFactory: MAT_TOOLBAR_INTL_PROVIDER_FACTORY
};

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
class MatToolbarSelectionList {
    constructor(_intl) {
        this._intl = _intl;
        /** Selected array changed event */
        this.selectedChange = new EventEmitter();
        /** Key within MenuItems Array for use as label in selection list. Default: 'name' */
        this.labelKey = 'name';
    }
    /** Array of selected values from the menuItems array */
    get selected() {
        return this._selected;
    }
    set selected(value) {
        this._selected = value;
        this.selectedChange.emit(this._selected);
    }
    /** Array of items to list in the menu for selection */
    get menuItems() {
        return this._menuItems;
    }
    set menuItems(value) {
        this._menuItems = value;
    }
    /** Returns true if the given menuItem is selected */
    menuItemIsSelected(menuItem) {
        return !!this.selected.find((item) => menuItem === item);
    }
    /**
     * toggles the selection of an item from the menuItem array
     * @param menuItem Menu item from the menuItem array
     * @param event Event from Click, Change or Keyboard
     */
    toggleMenuItem(event /* merge-12 added any */, menuItem) {
        event.stopPropagation(); // Keep the menu open until user dismisses it
        let selectedArray = this._selected;
        if (this.menuItemIsSelected(menuItem)) {
            selectedArray.forEach((item, index) => {
                if (item === menuItem) {
                    selectedArray.splice(index, 1);
                }
            });
        }
        else {
            selectedArray.push(menuItem);
        }
        if (this.maintainOrder) {
            const sortedSelectedArray = [];
            this.menuItems.forEach((item) => {
                if (selectedArray.find((selItem) => selItem === item)) {
                    sortedSelectedArray.push(item);
                }
            });
            selectedArray = sortedSelectedArray;
        }
        this.selected = selectedArray;
    }
}
MatToolbarSelectionList.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatToolbarSelectionList, deps: [{ token: MatToolbarIntl }], target: i0.ɵɵFactoryTarget.Component });
MatToolbarSelectionList.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.11", type: MatToolbarSelectionList, selector: "mat-toolbar-selection-list", inputs: { selected: "selected", menuItems: "menuItems", labelKey: "labelKey", maintainOrder: "maintainOrder" }, outputs: { selectedChange: "selectedChange" }, host: { properties: { "class.mat-toolbar-selection-list": "true" } }, ngImport: i0, template: "<button mat-button\n        [attr.aria-label]=\"_intl.toolbarSelectionListAriaLabel\"\n        [matMenuTriggerFor]=\"toggleMenu\"\n        class=\"trigger\"\n        overlapTrigger=\"true\"\n        matTooltip={{_intl.toolbarSelectionListTooltip}}\n        matTooltipPosition=\"below\"\n        matTooltipShowDelay=\"300\">\n  <mat-icon fontSet=\"material-symbols-outlined\">\n    view_column\n  </mat-icon>\n  <mat-icon fontSet=\"material-symbols-outlined\">\n    keyboard_arrow_down\n  </mat-icon>\n</button>\n<mat-menu [overlapTrigger]=\"true\"\n          xPosition=\"before\"\n          yPosition=\"below\"\n          #toggleMenu=\"matMenu\"\n          class=\"mat-toolbar-toggle-menu\">\n  <button mat-menu-item\n          *ngFor=\"let menuItem of menuItems\"\n          (click)=\"toggleMenuItem($event, menuItem)\"\n          (keypress.space)=\"toggleMenuItem($event, menuItem)\">\n    <mat-checkbox (change)=\"toggleMenuItem($event, menuItem)\"\n                  [checked]=\"menuItemIsSelected(menuItem)\">\n      {{ menuItem[labelKey] }}\n    </mat-checkbox>\n  </button>\n</mat-menu>", styles: [".mat-toolbar-selection-list .mat-button{height:45px;border-radius:0;padding:0}.mat-toolbar-selection-list .mat-button span.mat-button-wrapper{display:flex;justify-content:center}.mat-toolbar-selection-list .mat-button .mat-icon{display:flex;align-items:center;justify-content:center;font-size:24px;height:24px;width:24px}.mat-toolbar-selection-list .mat-button>.mat-button-wrapper>*:not(:first-child){padding-left:5px}.mat-toolbar-toggle-menu .mat-menu-item .mat-checkbox{pointer-events:none}[dir=rtl] .mat-toolbar-selection-list .mat-button>.mat-button-wrapper>*:not(:first-child){padding-right:5px;padding-left:0}\n"], components: [{ type: i2.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { type: i3.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { type: i4.MatMenu, selector: "mat-menu", exportAs: ["matMenu"] }, { type: i4.MatMenuItem, selector: "[mat-menu-item]", inputs: ["disabled", "disableRipple", "role"], exportAs: ["matMenuItem"] }, { type: i5.MatCheckbox, selector: "mat-checkbox", inputs: ["disableRipple", "color", "tabIndex", "aria-label", "aria-labelledby", "aria-describedby", "id", "required", "labelPosition", "name", "value", "checked", "disabled", "indeterminate", "errorText", "hintText"], outputs: ["change", "indeterminateChange"], exportAs: ["matCheckbox"] }], directives: [{ type: i4.MatMenuTrigger, selector: "[mat-menu-trigger-for], [matMenuTriggerFor]", exportAs: ["matMenuTrigger"] }, { type: i6.MatTooltip, selector: "[matTooltip]", exportAs: ["matTooltip"] }, { type: i5$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatToolbarSelectionList, decorators: [{
            type: Component,
            args: [{ selector: 'mat-toolbar-selection-list', host: {
                        '[class.mat-toolbar-selection-list]': 'true'
                    }, changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, template: "<button mat-button\n        [attr.aria-label]=\"_intl.toolbarSelectionListAriaLabel\"\n        [matMenuTriggerFor]=\"toggleMenu\"\n        class=\"trigger\"\n        overlapTrigger=\"true\"\n        matTooltip={{_intl.toolbarSelectionListTooltip}}\n        matTooltipPosition=\"below\"\n        matTooltipShowDelay=\"300\">\n  <mat-icon fontSet=\"material-symbols-outlined\">\n    view_column\n  </mat-icon>\n  <mat-icon fontSet=\"material-symbols-outlined\">\n    keyboard_arrow_down\n  </mat-icon>\n</button>\n<mat-menu [overlapTrigger]=\"true\"\n          xPosition=\"before\"\n          yPosition=\"below\"\n          #toggleMenu=\"matMenu\"\n          class=\"mat-toolbar-toggle-menu\">\n  <button mat-menu-item\n          *ngFor=\"let menuItem of menuItems\"\n          (click)=\"toggleMenuItem($event, menuItem)\"\n          (keypress.space)=\"toggleMenuItem($event, menuItem)\">\n    <mat-checkbox (change)=\"toggleMenuItem($event, menuItem)\"\n                  [checked]=\"menuItemIsSelected(menuItem)\">\n      {{ menuItem[labelKey] }}\n    </mat-checkbox>\n  </button>\n</mat-menu>", styles: [".mat-toolbar-selection-list .mat-button{height:45px;border-radius:0;padding:0}.mat-toolbar-selection-list .mat-button span.mat-button-wrapper{display:flex;justify-content:center}.mat-toolbar-selection-list .mat-button .mat-icon{display:flex;align-items:center;justify-content:center;font-size:24px;height:24px;width:24px}.mat-toolbar-selection-list .mat-button>.mat-button-wrapper>*:not(:first-child){padding-left:5px}.mat-toolbar-toggle-menu .mat-menu-item .mat-checkbox{pointer-events:none}[dir=rtl] .mat-toolbar-selection-list .mat-button>.mat-button-wrapper>*:not(:first-child){padding-right:5px;padding-left:0}\n"] }]
        }], ctorParameters: function () { return [{ type: MatToolbarIntl }]; }, propDecorators: { selected: [{
                type: Input
            }], selectedChange: [{
                type: Output
            }], menuItems: [{
                type: Input
            }], labelKey: [{
                type: Input
            }], maintainOrder: [{
                type: Input
            }] } });

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
/** Time and timing curve for toolbar animations. */
// Note: Keep this in sync with the Sass variable for the panel header animation.
const TOOLBAR_ANIMATION_TIMING = '225ms cubic-bezier(0.4,0.0,0.2,1)';
/**
 * Animations used by the Material toolbar.
 *
 * A bug in angular animation's `state` when ViewContainers are moved using ViewContainerRef.move()
 * causes the animation state of moved components to become `void` upon exit, and not update again
 * upon reentry into the DOM.  This can lead a to situation for the toolbar where the state
 * of the panel is `expanded` or `collapsed` but the animation state is `void`.
 *
 * To correctly handle animating to the next state, we animate between `void` and `collapsed` which
 * are defined to have the same styles. Since angular animates from the current styles to the
 * destination state's style definition, in situations where we are moving from `void`'s styles to
 * `collapsed` this acts a noop since no style values change.
 *
 * In the case where angular's animation state is out of sync with the toolbar's state, the
 * toolbar being `expanded` and angular animations being `void`, the animation from the
 * `expanded`'s effective styles (though in a `void` animation state) to the collapsed state will
 * occur as expected.
 *
 * Angular Bug: https://github.com/angular/angular/issues/18847
 *
 * @docs-private
 */
const matToolbarAnimations = {
    /** Animation that expands and collapses the toolbar overlay content. */
    overlayExpansion: trigger('overlayExpansion', [
        state('collapsed, void', style({ height: '0px', visibility: 'hidden' })),
        state('expanded', style({ height: '45px', visibility: 'visible' })),
        transition('expanded <=> collapsed, void => collapsed', animate(TOOLBAR_ANIMATION_TIMING))
    ])
};

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
class MatToolbarFilter {
    constructor(_intl, _changeDetectorRef) {
        this._intl = _intl;
        this._changeDetectorRef = _changeDetectorRef;
        /** Indicates the open state of the overlay. */
        this.open = false;
        this._intlChanges = _intl.changes.subscribe(() => {
            this._changeDetectorRef.markForCheck();
        });
    }
    /**
     * Tooltip for toolbar filter toggle button
     * @deprecated in merge-10, use toolbar-intl instead
     * @breaking-change merge-11
     */
    get toolbarFilterTooltip() {
        return this._toolbarFilterTooltip
            ? this._toolbarFilterTooltip
            : this._intl.toolbarFilterTooltip;
    }
    set toolbarFilterTooltip(value) {
        this._toolbarFilterTooltip = value;
    }
    /**
     * Aria label of the filter toggle button
     * @deprecated in merge-10, use toolbar-intl instead
     * @breaking-change merge-11
     */
    get ariaLabel() {
        return this._ariaLabel
            ? this._ariaLabel
            : this._intl.toolbarFilterAriaLabel;
    }
    set ariaLabel(value) {
        this._ariaLabel = value;
    }
    ngOnInit() {
        if (this.filtered === undefined) {
            throw new Error('Property "filtered" is required on mat-toolbar-filter.');
        }
    }
    ngOnDestroy() {
        this._intlChanges.unsubscribe();
    }
    toggleFilters() {
        setTimeout(() => {
            this.open = !this.open;
        }, 0);
    }
}
MatToolbarFilter.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatToolbarFilter, deps: [{ token: MatToolbarIntl }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component });
MatToolbarFilter.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.11", type: MatToolbarFilter, selector: "mat-toolbar-filter", inputs: { filtered: "filtered", open: "open", toolbarFilterTooltip: "toolbarFilterTooltip", ariaLabel: ["aria-label", "ariaLabel"] }, host: { properties: { "class.mat-toolbar-filter": "true", "class.mat-toolbar-filter-applied": "filtered", "class.mat-toolbar-filter-open": "open", "attr.aria-expanded": "open" } }, ngImport: i0, template: "<button mat-icon-button\n        (click)=\"toggleFilters()\"\n        [attr.aria-label]=\"ariaLabel\"\n        [attr.aria-pressed]=\"filtered\"\n        [matTooltip]=\"toolbarFilterTooltip\"\n        matTooltipPosition=\"below\"\n        matTooltipShowDelay=\"300\">\n  <span class=\"mat-toolbar-filter-stack\">\n    <mat-icon fontSet=\"material-symbols-outlined\"\n              class=\"mat-toolbar-filter-icon mat-icon-filled\">\n      filter_alt\n    </mat-icon>\n  </span>\n</button>", styles: ["mat-toolbar-filter.mat-toolbar-filter{display:flex;flex-direction:row;height:45px;align-content:center;align-items:center;min-width:45px}mat-toolbar-filter.mat-toolbar-filter button{display:flex;text-align:center;justify-content:center;align-items:center;height:100%;padding:0;min-width:45px}mat-toolbar-filter.mat-toolbar-filter button>.mat-button-wrapper{display:flex;align-items:center}mat-toolbar-filter.mat-toolbar-filter button .mat-toolbar-filter-stack{display:flex;flex:0 0 auto;align-items:center;font-size:32px}mat-toolbar-filter.mat-toolbar-filter button .mat-toolbar-filter-stack .mat-icon{display:flex;align-items:center;justify-content:center}mat-toolbar-filter.mat-toolbar-filter button .mat-toolbar-filter-stack .mat-toolbar-filter-icon{font-size:24px;width:24px;height:24px}mat-toolbar-filter.mat-toolbar-filter button:hover{border-radius:0}mat-toolbar-filter.mat-toolbar-filter.mat-toolbar-filter-applied button .mat-toolbar-filter-stack{border-radius:50%}\n"], components: [{ type: i2.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { type: i3.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }], directives: [{ type: i6.MatTooltip, selector: "[matTooltip]", exportAs: ["matTooltip"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatToolbarFilter, decorators: [{
            type: Component,
            args: [{ selector: 'mat-toolbar-filter', host: {
                        '[class.mat-toolbar-filter]': 'true',
                        '[class.mat-toolbar-filter-applied]': 'filtered',
                        '[class.mat-toolbar-filter-open]': 'open',
                        '[attr.aria-expanded]': 'open'
                    }, changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, template: "<button mat-icon-button\n        (click)=\"toggleFilters()\"\n        [attr.aria-label]=\"ariaLabel\"\n        [attr.aria-pressed]=\"filtered\"\n        [matTooltip]=\"toolbarFilterTooltip\"\n        matTooltipPosition=\"below\"\n        matTooltipShowDelay=\"300\">\n  <span class=\"mat-toolbar-filter-stack\">\n    <mat-icon fontSet=\"material-symbols-outlined\"\n              class=\"mat-toolbar-filter-icon mat-icon-filled\">\n      filter_alt\n    </mat-icon>\n  </span>\n</button>", styles: ["mat-toolbar-filter.mat-toolbar-filter{display:flex;flex-direction:row;height:45px;align-content:center;align-items:center;min-width:45px}mat-toolbar-filter.mat-toolbar-filter button{display:flex;text-align:center;justify-content:center;align-items:center;height:100%;padding:0;min-width:45px}mat-toolbar-filter.mat-toolbar-filter button>.mat-button-wrapper{display:flex;align-items:center}mat-toolbar-filter.mat-toolbar-filter button .mat-toolbar-filter-stack{display:flex;flex:0 0 auto;align-items:center;font-size:32px}mat-toolbar-filter.mat-toolbar-filter button .mat-toolbar-filter-stack .mat-icon{display:flex;align-items:center;justify-content:center}mat-toolbar-filter.mat-toolbar-filter button .mat-toolbar-filter-stack .mat-toolbar-filter-icon{font-size:24px;width:24px;height:24px}mat-toolbar-filter.mat-toolbar-filter button:hover{border-radius:0}mat-toolbar-filter.mat-toolbar-filter.mat-toolbar-filter-applied button .mat-toolbar-filter-stack{border-radius:50%}\n"] }]
        }], ctorParameters: function () { return [{ type: MatToolbarIntl }, { type: i0.ChangeDetectorRef }]; }, propDecorators: { filtered: [{
                type: Input
            }], open: [{
                type: Input
            }], toolbarFilterTooltip: [{
                type: Input,
                args: ['toolbarFilterTooltip']
            }], ariaLabel: [{
                type: Input,
                args: ['aria-label']
            }] } });

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
class MatToolbarRowExpansion {
    constructor(changeDetector) {
        this.changeDetector = changeDetector;
        /**
         * Sets row expansion to be hidden or visible. Default is false
         */
        this.opened = false;
    }
    /**
     * Set the open property for the row expansion to open
     * @param show Set to true if row expansion should be shown
     */
    setOpen(show) {
        this.opened = show;
        this.changeDetector.detectChanges();
    }
}
MatToolbarRowExpansion.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatToolbarRowExpansion, deps: [{ token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component });
MatToolbarRowExpansion.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.11", type: MatToolbarRowExpansion, selector: "mat-toolbar-row-expansion", host: { properties: { "class.mat-toolbar-row-expansion": "true", "class.mat-toolbar-row": "true" } }, ngImport: i0, template: '<ng-container><ng-content *ngIf="opened"></ng-content></ng-container>', isInline: true, directives: [{ type: i5$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatToolbarRowExpansion, decorators: [{
            type: Component,
            args: [{
                    selector: 'mat-toolbar-row-expansion',
                    template: '<ng-container><ng-content *ngIf="opened"></ng-content></ng-container>',
                    host: {
                        '[class.mat-toolbar-row-expansion]': 'true',
                        '[class.mat-toolbar-row]': 'true'
                    },
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None
                }]
        }], ctorParameters: function () { return [{ type: i0.ChangeDetectorRef }]; } });

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
/**
 * This directive is intended to be used in conjunction with an mat-toolbar-row-expansion tag.  It is
 * responsible for toggling the display of the provided content instance.
 */
class MatToolbarTrigger {
    constructor() {
        this.open = false;
    }
    get _matToolbarTriggerFor() {
        return this.matToolbarFilterContainer;
    }
    set _matToolbarTriggerFor(matToolbarFilterContainer) {
        this.matToolbarFilterContainer = matToolbarFilterContainer;
    }
    ngOnInit() {
        if (typeof this._matToolbarTriggerFor !== 'object') {
            throw new Error('Property "matToolbarTriggerFor" is required on mat-toolbar-trigger.');
        }
    }
    toggleContent() {
        this.open = !this.open;
        this.matToolbarFilterContainer.setOpen(this.open);
    }
}
MatToolbarTrigger.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatToolbarTrigger, deps: [], target: i0.ɵɵFactoryTarget.Directive });
MatToolbarTrigger.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.3.11", type: MatToolbarTrigger, selector: "[matToolbarTriggerFor]", inputs: { _matToolbarTriggerFor: ["matToolbarTriggerFor", "_matToolbarTriggerFor"], matToolbarFilterContainer: ["matToolbarTriggerFor", "matToolbarFilterContainer"] }, host: { listeners: { "click": "toggleContent()" } }, exportAs: ["matToolbarTrigger"], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatToolbarTrigger, decorators: [{
            type: Directive,
            args: [{
                    selector: `[matToolbarTriggerFor]`,
                    host: {
                        '(click)': 'toggleContent()'
                    },
                    exportAs: 'matToolbarTrigger'
                }]
        }], propDecorators: { _matToolbarTriggerFor: [{
                type: Input,
                args: ['matToolbarTriggerFor']
            }], matToolbarFilterContainer: [{
                type: Input,
                args: ['matToolbarTriggerFor']
            }] } });

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
// Boilerplate for applying mixins to MatToolbar.
/** @docs-private */
const _MatToolbarBase = mixinColor(class {
    constructor(_elementRef) {
        this._elementRef = _elementRef;
    }
});
class MatToolbarRow {
}
MatToolbarRow.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatToolbarRow, deps: [], target: i0.ɵɵFactoryTarget.Directive });
MatToolbarRow.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.3.11", type: MatToolbarRow, selector: "mat-toolbar-row", host: { classAttribute: "mat-toolbar-row" }, exportAs: ["matToolbarRow"], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatToolbarRow, decorators: [{
            type: Directive,
            args: [{
                    selector: 'mat-toolbar-row',
                    exportAs: 'matToolbarRow',
                    host: { class: 'mat-toolbar-row' }
                }]
        }] });
// VDL Change: toolbar overlay, spacer
// animate this over the mat-toolbar-row...
class MatToolbarOverlay {
    constructor(matToolBar, _intl, _changeDetectorRef) {
        this.matToolBar = matToolBar;
        this._intl = _intl;
        this._changeDetectorRef = _changeDetectorRef;
        /**
         * Sets the height of the toolbar overlay. Default to 45;
         */
        this.setHeight = 45;
        /**
         * Sets overlay to be hidden or visible.
         * Default is false
         */
        this.selected = 0;
        /**
         * Array of actions for buttons on the right side.
         * The array is of type ToolbarAction[]
         */
        this.actions = [];
        /** Event Emitter to close the overlay (e.g. set the selected input to 0) */
        this.closeOverlay = new EventEmitter();
        this._intlChanges = _intl.changes.subscribe(() => {
            this._changeDetectorRef.markForCheck();
        });
    }
    /**
     * Sets aria-label for close button on overlay
     * @deprecated in merge-10, use toolbar-intl instead
     * @breaking-change merge-11
     */
    get closeOverlayAriaLabel() {
        return this._closeOverlayAriaLabel
            ? this._closeOverlayAriaLabel
            : this._intl.toolbarOverlayCloseAriaLabel;
    }
    set closeOverlayAriaLabel(value) {
        this._closeOverlayAriaLabel = value;
    }
    get overlayString() {
        return this._intl.toolbarOverlaySelectedTemplate.replace('${selected}', this.selected.toString());
    }
    /** Gets the expanded state string. */
    _getOverlayState() {
        return this.selected ? 'expanded' : 'collapsed';
    }
    ngOnDestroy() {
        this._intlChanges.unsubscribe();
    }
    /** Callback, invoked when an animation on the host starts. */
    _onAnimationStart(event) {
        if (this.selected === 0) {
            this.matToolBar.hideToolbarRows(false);
        }
    }
    /** Callback, invoked whenever an animation on the host completes. */
    _onAnimationDone(event) {
        if (this.selected === 1) {
            this.matToolBar.hideToolbarRows(true);
        }
    }
}
MatToolbarOverlay.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatToolbarOverlay, deps: [{ token: MatToolbar }, { token: MatToolbarIntl }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component });
MatToolbarOverlay.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.11", type: MatToolbarOverlay, selector: "mat-toolbar-overlay", inputs: { selected: "selected", actions: "actions", closeOverlayAriaLabel: "closeOverlayAriaLabel" }, outputs: { closeOverlay: "closeOverlay" }, host: { properties: { "class.mat-toolbar-overlay": "true", "class._mat-animation-noopable": "_animationMode === \"NoopAnimations\"" } }, ngImport: i0, template: "<ng-container>\n  <div [@overlayExpansion]=\"_getOverlayState()\"\n       class=\"toolbar-overlay-container\"\n       *ngIf=\"selected > 0\">\n    <div class=\"toolbar-left-container\">\n      <button mat-icon-button\n              [attr.aria-label]=\"closeOverlayAriaLabel\"\n              (click)=\"this.closeOverlay.emit()\"\n              [matTooltip]=\"_intl.toolbarOverlayCloseTooltip\">\n        <mat-icon fontSet=\"material-symbols-outlined\"\n                  class=\"toolbar-close-button\">close\n        </mat-icon>\n      </button>\n      <p class=\"selected-text\"\n         aria-live=\"polite\"> {{ overlayString }}</p>\n    </div>\n\n    <div class=\"toolbar-right-container\">\n      <button *ngFor=\"let action of actions | slice:0:2\"\n              mat-button\n              (click)=\"action.action($event)\">\n        <mat-icon *ngIf=\"action.icon\"\n                  fontSet=\"material-symbols-outlined\"\n                  class=\"toolbar-action-icon\">{{ action.icon }}\n        </mat-icon>\n        <span>{{ action.name }}</span>\n      </button>\n\n      <div *ngIf=\"actions.length > 2\">\n        <div class=\"menu-section\">\n          <button mat-icon-button\n                  [matMenuTriggerFor]=\"menu\"\n                  aria-label=\"Open actions menu\">\n            <mat-icon fontSet=\"material-symbols-outlined\">more_vert</mat-icon>\n          </button>\n          <mat-menu #menu=\"matMenu\">\n            <button mat-menu-item\n                    *ngFor=\"let action of actions | slice:2\"\n                    (click)=\"action.action($event)\">\n              <mat-icon *ngIf=\"action.icon\"\n                        fontSet=\"material-symbols-outlined\"\n                        class=\"toolbar-action-icon\">{{ action.icon }}\n              </mat-icon>\n              <span>{{ action.name }}</span>\n            </button>\n          </mat-menu>\n        </div>\n      </div>\n    </div>\n  </div>\n</ng-container>", components: [{ type: i2.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { type: i3.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { type: i4.MatMenu, selector: "mat-menu", exportAs: ["matMenu"] }, { type: i4.MatMenuItem, selector: "[mat-menu-item]", inputs: ["disabled", "disableRipple", "role"], exportAs: ["matMenuItem"] }], directives: [{ type: i5$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i6.MatTooltip, selector: "[matTooltip]", exportAs: ["matTooltip"] }, { type: i5$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i4.MatMenuTrigger, selector: "[mat-menu-trigger-for], [matMenuTriggerFor]", exportAs: ["matMenuTrigger"] }], pipes: { "slice": i5$1.SlicePipe }, animations: [matToolbarAnimations.overlayExpansion], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatToolbarOverlay, decorators: [{
            type: Component,
            args: [{ selector: 'mat-toolbar-overlay', host: {
                        '[class.mat-toolbar-overlay]': 'true',
                        // VDL Change - toolbar animation
                        '[class._mat-animation-noopable]': '_animationMode === "NoopAnimations"'
                    }, changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, animations: [matToolbarAnimations.overlayExpansion], template: "<ng-container>\n  <div [@overlayExpansion]=\"_getOverlayState()\"\n       class=\"toolbar-overlay-container\"\n       *ngIf=\"selected > 0\">\n    <div class=\"toolbar-left-container\">\n      <button mat-icon-button\n              [attr.aria-label]=\"closeOverlayAriaLabel\"\n              (click)=\"this.closeOverlay.emit()\"\n              [matTooltip]=\"_intl.toolbarOverlayCloseTooltip\">\n        <mat-icon fontSet=\"material-symbols-outlined\"\n                  class=\"toolbar-close-button\">close\n        </mat-icon>\n      </button>\n      <p class=\"selected-text\"\n         aria-live=\"polite\"> {{ overlayString }}</p>\n    </div>\n\n    <div class=\"toolbar-right-container\">\n      <button *ngFor=\"let action of actions | slice:0:2\"\n              mat-button\n              (click)=\"action.action($event)\">\n        <mat-icon *ngIf=\"action.icon\"\n                  fontSet=\"material-symbols-outlined\"\n                  class=\"toolbar-action-icon\">{{ action.icon }}\n        </mat-icon>\n        <span>{{ action.name }}</span>\n      </button>\n\n      <div *ngIf=\"actions.length > 2\">\n        <div class=\"menu-section\">\n          <button mat-icon-button\n                  [matMenuTriggerFor]=\"menu\"\n                  aria-label=\"Open actions menu\">\n            <mat-icon fontSet=\"material-symbols-outlined\">more_vert</mat-icon>\n          </button>\n          <mat-menu #menu=\"matMenu\">\n            <button mat-menu-item\n                    *ngFor=\"let action of actions | slice:2\"\n                    (click)=\"action.action($event)\">\n              <mat-icon *ngIf=\"action.icon\"\n                        fontSet=\"material-symbols-outlined\"\n                        class=\"toolbar-action-icon\">{{ action.icon }}\n              </mat-icon>\n              <span>{{ action.name }}</span>\n            </button>\n          </mat-menu>\n        </div>\n      </div>\n    </div>\n  </div>\n</ng-container>" }]
        }], ctorParameters: function () { return [{ type: MatToolbar }, { type: MatToolbarIntl }, { type: i0.ChangeDetectorRef }]; }, propDecorators: { selected: [{
                type: Input
            }], actions: [{
                type: Input
            }], closeOverlayAriaLabel: [{
                type: Input,
                args: ['closeOverlayAriaLabel']
            }], closeOverlay: [{
                type: Output
            }] } });
/**
 * A spacer which you can add between elements to give space between them.
 */
class MatToolbarSpacer {
}
MatToolbarSpacer.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatToolbarSpacer, deps: [], target: i0.ɵɵFactoryTarget.Directive });
MatToolbarSpacer.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.3.11", type: MatToolbarSpacer, selector: "mat-toolbar-spacer", host: { properties: { "class.mat-toolbar-spacer": "true" } }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatToolbarSpacer, decorators: [{
            type: Directive,
            args: [{
                    selector: 'mat-toolbar-spacer',
                    host: {
                        '[class.mat-toolbar-spacer]': 'true'
                    }
                }]
        }] });
class MatToolbar extends _MatToolbarBase {
    constructor(elementRef, _platform, document) {
        super(elementRef);
        this._platform = _platform;
        // TODO: make the document a required param when doing breaking changes.
        this._document = document;
    }
    ngAfterContentChecked() {
        if (this._toolbarOverlay) {
            if (this._toolbarOverlay.selected > 0) {
                // this will close the expansionRow if it is opened
                if (this._toolbarExpansionRow && this._toolbarExpansionRow.opened) {
                    if (this._toolbarFilter && this._toolbarFilter.open) {
                        this._toolbarFilter.toggleFilters();
                    }
                    if (this._toolbarTrigger) {
                        this._toolbarTrigger.toggleContent();
                    }
                }
            }
        }
    }
    ngAfterViewInit() {
        if (this._platform.isBrowser) {
            this._checkToolbarMixedModes();
            this._toolbarRows.changes.subscribe(() => this._checkToolbarMixedModes());
        }
    }
    // VDL Change
    hideToolbarRows(hide) {
        this._hideToolbarRows = hide;
    }
    /**
     * Throws an exception when developers are attempting to combine the different toolbar row modes.
     */
    _checkToolbarMixedModes() {
        if (this._toolbarRows.length // &&
        // (typeof ngDevMode === 'undefined' || ngDevMode)
        ) {
            // Check if there are any other DOM nodes that can display content but aren't inside of
            // a <mat-toolbar-row> element.
            const isCombinedUsage = Array.from(this._elementRef.nativeElement.childNodes)
                .filter((node) => !(node.classList && node.classList.contains('mat-toolbar-row')))
                .filter((node) => node.nodeType !== (this._document ? this._document.COMMENT_NODE : 8))
                .some((node) => !!(node.textContent && node.textContent.trim()));
            if (isCombinedUsage) {
                throwToolbarMixedModesError();
            }
        }
    }
}
MatToolbar.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatToolbar, deps: [{ token: i0.ElementRef }, { token: i7.Platform }, { token: DOCUMENT }], target: i0.ɵɵFactoryTarget.Component });
MatToolbar.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.11", type: MatToolbar, selector: "mat-toolbar", inputs: { color: "color" }, host: { properties: { "class.mat-toolbar-multiple-rows": "_toolbarRows.length > 0", "class.mat-toolbar-single-row": "_toolbarRows.length === 0", "attr.role": "\"toolbar\"", "class.mat-toolbar-rows-hidden": "_hideToolbarRows" }, classAttribute: "mat-toolbar" }, queries: [{ propertyName: "_toolbarOverlay", first: true, predicate: MatToolbarOverlay, descendants: true }, { propertyName: "_toolbarExpansionRow", first: true, predicate: MatToolbarRowExpansion, descendants: true }, { propertyName: "_toolbarFilter", first: true, predicate: MatToolbarFilter, descendants: true }, { propertyName: "_toolbarTrigger", first: true, predicate: i0.forwardRef(function () { return MatToolbarTrigger; }), descendants: true }, { propertyName: "_toolbarRows", predicate: MatToolbarRow, descendants: true }], exportAs: ["matToolbar"], usesInheritance: true, ngImport: i0, template: "<ng-content></ng-content>\n<!-- VDL Change: tool bar overlay and row expansion -->\n<ng-content select=\"mat-toolbar-row, mat-toolbar-row-expansion\"></ng-content>\n<ng-content select=\"mat-toolbar-overlay\"></ng-content>", styles: [".cdk-high-contrast-active .mat-toolbar{outline:solid 1px}.toolbar-overlay-container{display:flex;justify-content:space-between;flex:1;height:45px}.toolbar-overlay-container .selected-text{height:45px;text-align:center}.toolbar-overlay-container .toolbar-left-container{display:flex}.toolbar-overlay-container .toolbar-left-container p{margin:auto}.toolbar-overlay-container .toolbar-action-icon{margin:5px 5px 0 0}.toolbar-overlay-container .toolbar-right-container{display:flex}.toolbar-overlay-container .toolbar-right-container button[mat-icon-button]{padding:0 15px;width:auto}.toolbar-overlay-container .toolbar-right-container button[mat-icon-button] .mat-icon{margin:auto}.toolbar-overlay-container .toolbar-right-container button[mat-icon-button] .toolbar-action-icon{margin:5px 5px 0 0}.toolbar-overlay-container button[mat-icon-button]{text-align:center;height:45px;width:45px;margin:auto}.toolbar-overlay-container button[mat-icon-button] .mat-button-wrapper{display:flex;justify-content:center;align-items:center}.toolbar-overlay-container button[mat-icon-button] .mat-icon{cursor:pointer}.mat-toolbar{padding:0;box-sizing:border-box;width:100%;position:relative;display:flex;flex-flow:column;flex:1;min-height:45px}.mat-toolbar .mat-form-field{margin:0}.mat-toolbar .mat-form-field .mat-form-field-infix{border-top:0}.mat-toolbar .mat-form-field .mat-form-field-wrapper{padding-bottom:4px}.mat-toolbar .mat-form-field .mat-form-field-underline{bottom:4px}.mat-toolbar .mat-form-field .mat-form-field-subscript-wrapper{display:none}.mat-toolbar .mat-form-field .mat-form-field-suffix-icons>[mat-icon-button]{padding:0}.mat-toolbar .mat-toolbar-row,.mat-toolbar.mat-toolbar-single-row{display:flex;box-sizing:border-box;padding:0 16px;width:100%;flex-direction:row;white-space:nowrap;justify-content:flex-start;align-items:center;height:45px}.mat-toolbar .mat-toolbar-row>.mat-form-field,.mat-toolbar.mat-toolbar-single-row>.mat-form-field{margin-top:2px;flex:1 1 auto}.mat-toolbar .mat-toolbar-row>button,.mat-toolbar.mat-toolbar-single-row>button{align-self:stretch;display:flex;align-items:center;padding-left:10px;padding-right:10px;border-radius:0}.mat-toolbar .mat-toolbar-row>button>.mat-button-wrapper,.mat-toolbar.mat-toolbar-single-row>button>.mat-button-wrapper{align-items:center}.mat-toolbar .mat-toolbar-row>.mat-toolbar-filter,.mat-toolbar.mat-toolbar-single-row>.mat-toolbar-filter{padding:0}.mat-toolbar .mat-toolbar-row .mat-form-field,.mat-toolbar.mat-toolbar-single-row .mat-form-field{padding-top:0}.mat-toolbar .mat-toolbar-row>button,.mat-toolbar.mat-toolbar-single-row>button{height:45px}.mat-toolbar .mat-toolbar-row>button .mat-button-wrapper,.mat-toolbar.mat-toolbar-single-row>button .mat-button-wrapper{display:flex}.mat-toolbar .mat-toolbar-row>button .mat-icon,.mat-toolbar.mat-toolbar-single-row>button .mat-icon{display:flex;align-items:center;justify-content:center;font-size:24px;height:24px;width:24px}.mat-toolbar .mat-toolbar-row>button>.mat-button-wrapper>*:not(:first-child),.mat-toolbar.mat-toolbar-single-row>button>.mat-button-wrapper>*:not(:first-child){padding-left:5px}.mat-toolbar .mat-toolbar-row>button:hover,.mat-toolbar.mat-toolbar-single-row>button:hover{border-radius:0}.mat-toolbar .mat-toolbar-row .mat-toolbar-action-button,.mat-toolbar.mat-toolbar-single-row .mat-toolbar-action-button{display:flex}.mat-toolbar.mat-toolbar-rows-hidden .mat-toolbar-row,.mat-toolbar.mat-toolbar-rows-hidden .mat-toolbar-single-row{display:none}.mat-toolbar:not(.action) .mat-toolbar-row:not(.toolbar-no-dividers)>*:first-child:not(mat-form-field),.mat-toolbar:not(.action).mat-toolbar-single-row:not(.toolbar-no-dividers)>*:first-child:not(mat-form-field){margin-left:-16px}.mat-toolbar:not(.action) .mat-toolbar-row:not(.toolbar-no-dividers)>*:last-child:not(mat-form-field),.mat-toolbar:not(.action).mat-toolbar-single-row:not(.toolbar-no-dividers)>*:last-child:not(mat-form-field){margin-right:-16px}.mat-toolbar:not(.action) .mat-toolbar-row:not(.toolbar-no-dividers)>span:first-child,.mat-toolbar:not(.action).mat-toolbar-single-row:not(.toolbar-no-dividers)>span:first-child{margin-right:16px;margin-left:0}.mat-toolbar:not(.action) .mat-toolbar-row:not(.toolbar-no-dividers)>*:not(:first-child):before,.mat-toolbar:not(.action).mat-toolbar-single-row:not(.toolbar-no-dividers)>*:not(:first-child):before{content:\"\";display:inline-block}.mat-toolbar .mat-toolbar-overlay{display:block;height:unset;width:100%;white-space:unset;align-content:unset;align-items:unset;justify-content:unset;align-self:flex-start;position:absolute;right:0;left:0}.mat-toolbar .mat-toolbar-overlay-extra{opacity:.5;position:absolute;right:0;left:0;top:45px}.mat-toolbar>.mat-toolbar-row-expansion{display:flex;flex:0 0 auto;flex-direction:column;width:100%;height:unset;white-space:unset;align-content:unset;align-items:unset;justify-content:unset}.mat-toolbar>.mat-toolbar-row-expansion .mat-button-bar{box-shadow:none}.mat-toolbar .mat-toolbar-multiple-rows{display:flex;box-sizing:border-box;flex-direction:column;width:100%}[dir=rtl] .toolbar-overlay-container .toolbar-action-icon{margin:5px 0 0 5px}[dir=rtl] .mat-toolbar{padding:0}[dir=rtl] .mat-toolbar .mat-toolbar-row>button>.mat-button-wrapper>*:not(:first-child),[dir=rtl] .mat-toolbar.mat-toolbar-single-row>button>.mat-button-wrapper>*:not(:first-child){padding-right:5px;padding-left:0}[dir=rtl]:not(.action) .mat-toolbar-row:not(.toolbar-no-dividers)>*:first-child:not(mat-form-field),[dir=rtl]:not(.action).mat-toolbar-single-row:not(.toolbar-no-dividers)>*:first-child:not(mat-form-field){margin-left:0}[dir=rtl]:not(.action) .mat-toolbar-row:not(.toolbar-no-dividers)>*:last-child:not(mat-form-field),[dir=rtl]:not(.action).mat-toolbar-single-row:not(.toolbar-no-dividers)>*:last-child:not(mat-form-field){margin-right:0}[dir=rtl]:not(.action) .mat-toolbar-row:not(.toolbar-no-dividers)>span:first-child,[dir=rtl]:not(.action).mat-toolbar-single-row:not(.toolbar-no-dividers)>span:first-child{margin-left:16px;margin-right:0}[dir=rtl]:not(.action) .mat-toolbar-row:not(.toolbar-no-dividers)>*:not(:first-child):before,[dir=rtl]:not(.action).mat-toolbar-single-row:not(.toolbar-no-dividers)>*:not(:first-child):before{content:\"\";display:inline-block;margin-right:16px}\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatToolbar, decorators: [{
            type: Component,
            args: [{ selector: 'mat-toolbar', exportAs: 'matToolbar', inputs: ['color'], host: {
                        class: 'mat-toolbar',
                        '[class.mat-toolbar-multiple-rows]': '_toolbarRows.length > 0',
                        '[class.mat-toolbar-single-row]': '_toolbarRows.length === 0',
                        // VDL Change
                        '[attr.role]': '"toolbar"',
                        '[class.mat-toolbar-rows-hidden]': '_hideToolbarRows'
                    }, changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, template: "<ng-content></ng-content>\n<!-- VDL Change: tool bar overlay and row expansion -->\n<ng-content select=\"mat-toolbar-row, mat-toolbar-row-expansion\"></ng-content>\n<ng-content select=\"mat-toolbar-overlay\"></ng-content>", styles: [".cdk-high-contrast-active .mat-toolbar{outline:solid 1px}.toolbar-overlay-container{display:flex;justify-content:space-between;flex:1;height:45px}.toolbar-overlay-container .selected-text{height:45px;text-align:center}.toolbar-overlay-container .toolbar-left-container{display:flex}.toolbar-overlay-container .toolbar-left-container p{margin:auto}.toolbar-overlay-container .toolbar-action-icon{margin:5px 5px 0 0}.toolbar-overlay-container .toolbar-right-container{display:flex}.toolbar-overlay-container .toolbar-right-container button[mat-icon-button]{padding:0 15px;width:auto}.toolbar-overlay-container .toolbar-right-container button[mat-icon-button] .mat-icon{margin:auto}.toolbar-overlay-container .toolbar-right-container button[mat-icon-button] .toolbar-action-icon{margin:5px 5px 0 0}.toolbar-overlay-container button[mat-icon-button]{text-align:center;height:45px;width:45px;margin:auto}.toolbar-overlay-container button[mat-icon-button] .mat-button-wrapper{display:flex;justify-content:center;align-items:center}.toolbar-overlay-container button[mat-icon-button] .mat-icon{cursor:pointer}.mat-toolbar{padding:0;box-sizing:border-box;width:100%;position:relative;display:flex;flex-flow:column;flex:1;min-height:45px}.mat-toolbar .mat-form-field{margin:0}.mat-toolbar .mat-form-field .mat-form-field-infix{border-top:0}.mat-toolbar .mat-form-field .mat-form-field-wrapper{padding-bottom:4px}.mat-toolbar .mat-form-field .mat-form-field-underline{bottom:4px}.mat-toolbar .mat-form-field .mat-form-field-subscript-wrapper{display:none}.mat-toolbar .mat-form-field .mat-form-field-suffix-icons>[mat-icon-button]{padding:0}.mat-toolbar .mat-toolbar-row,.mat-toolbar.mat-toolbar-single-row{display:flex;box-sizing:border-box;padding:0 16px;width:100%;flex-direction:row;white-space:nowrap;justify-content:flex-start;align-items:center;height:45px}.mat-toolbar .mat-toolbar-row>.mat-form-field,.mat-toolbar.mat-toolbar-single-row>.mat-form-field{margin-top:2px;flex:1 1 auto}.mat-toolbar .mat-toolbar-row>button,.mat-toolbar.mat-toolbar-single-row>button{align-self:stretch;display:flex;align-items:center;padding-left:10px;padding-right:10px;border-radius:0}.mat-toolbar .mat-toolbar-row>button>.mat-button-wrapper,.mat-toolbar.mat-toolbar-single-row>button>.mat-button-wrapper{align-items:center}.mat-toolbar .mat-toolbar-row>.mat-toolbar-filter,.mat-toolbar.mat-toolbar-single-row>.mat-toolbar-filter{padding:0}.mat-toolbar .mat-toolbar-row .mat-form-field,.mat-toolbar.mat-toolbar-single-row .mat-form-field{padding-top:0}.mat-toolbar .mat-toolbar-row>button,.mat-toolbar.mat-toolbar-single-row>button{height:45px}.mat-toolbar .mat-toolbar-row>button .mat-button-wrapper,.mat-toolbar.mat-toolbar-single-row>button .mat-button-wrapper{display:flex}.mat-toolbar .mat-toolbar-row>button .mat-icon,.mat-toolbar.mat-toolbar-single-row>button .mat-icon{display:flex;align-items:center;justify-content:center;font-size:24px;height:24px;width:24px}.mat-toolbar .mat-toolbar-row>button>.mat-button-wrapper>*:not(:first-child),.mat-toolbar.mat-toolbar-single-row>button>.mat-button-wrapper>*:not(:first-child){padding-left:5px}.mat-toolbar .mat-toolbar-row>button:hover,.mat-toolbar.mat-toolbar-single-row>button:hover{border-radius:0}.mat-toolbar .mat-toolbar-row .mat-toolbar-action-button,.mat-toolbar.mat-toolbar-single-row .mat-toolbar-action-button{display:flex}.mat-toolbar.mat-toolbar-rows-hidden .mat-toolbar-row,.mat-toolbar.mat-toolbar-rows-hidden .mat-toolbar-single-row{display:none}.mat-toolbar:not(.action) .mat-toolbar-row:not(.toolbar-no-dividers)>*:first-child:not(mat-form-field),.mat-toolbar:not(.action).mat-toolbar-single-row:not(.toolbar-no-dividers)>*:first-child:not(mat-form-field){margin-left:-16px}.mat-toolbar:not(.action) .mat-toolbar-row:not(.toolbar-no-dividers)>*:last-child:not(mat-form-field),.mat-toolbar:not(.action).mat-toolbar-single-row:not(.toolbar-no-dividers)>*:last-child:not(mat-form-field){margin-right:-16px}.mat-toolbar:not(.action) .mat-toolbar-row:not(.toolbar-no-dividers)>span:first-child,.mat-toolbar:not(.action).mat-toolbar-single-row:not(.toolbar-no-dividers)>span:first-child{margin-right:16px;margin-left:0}.mat-toolbar:not(.action) .mat-toolbar-row:not(.toolbar-no-dividers)>*:not(:first-child):before,.mat-toolbar:not(.action).mat-toolbar-single-row:not(.toolbar-no-dividers)>*:not(:first-child):before{content:\"\";display:inline-block}.mat-toolbar .mat-toolbar-overlay{display:block;height:unset;width:100%;white-space:unset;align-content:unset;align-items:unset;justify-content:unset;align-self:flex-start;position:absolute;right:0;left:0}.mat-toolbar .mat-toolbar-overlay-extra{opacity:.5;position:absolute;right:0;left:0;top:45px}.mat-toolbar>.mat-toolbar-row-expansion{display:flex;flex:0 0 auto;flex-direction:column;width:100%;height:unset;white-space:unset;align-content:unset;align-items:unset;justify-content:unset}.mat-toolbar>.mat-toolbar-row-expansion .mat-button-bar{box-shadow:none}.mat-toolbar .mat-toolbar-multiple-rows{display:flex;box-sizing:border-box;flex-direction:column;width:100%}[dir=rtl] .toolbar-overlay-container .toolbar-action-icon{margin:5px 0 0 5px}[dir=rtl] .mat-toolbar{padding:0}[dir=rtl] .mat-toolbar .mat-toolbar-row>button>.mat-button-wrapper>*:not(:first-child),[dir=rtl] .mat-toolbar.mat-toolbar-single-row>button>.mat-button-wrapper>*:not(:first-child){padding-right:5px;padding-left:0}[dir=rtl]:not(.action) .mat-toolbar-row:not(.toolbar-no-dividers)>*:first-child:not(mat-form-field),[dir=rtl]:not(.action).mat-toolbar-single-row:not(.toolbar-no-dividers)>*:first-child:not(mat-form-field){margin-left:0}[dir=rtl]:not(.action) .mat-toolbar-row:not(.toolbar-no-dividers)>*:last-child:not(mat-form-field),[dir=rtl]:not(.action).mat-toolbar-single-row:not(.toolbar-no-dividers)>*:last-child:not(mat-form-field){margin-right:0}[dir=rtl]:not(.action) .mat-toolbar-row:not(.toolbar-no-dividers)>span:first-child,[dir=rtl]:not(.action).mat-toolbar-single-row:not(.toolbar-no-dividers)>span:first-child{margin-left:16px;margin-right:0}[dir=rtl]:not(.action) .mat-toolbar-row:not(.toolbar-no-dividers)>*:not(:first-child):before,[dir=rtl]:not(.action).mat-toolbar-single-row:not(.toolbar-no-dividers)>*:not(:first-child):before{content:\"\";display:inline-block;margin-right:16px}\n"] }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i7.Platform }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }]; }, propDecorators: { _toolbarRows: [{
                type: ContentChildren,
                args: [MatToolbarRow, { descendants: true }]
            }], _toolbarOverlay: [{
                type: ContentChild,
                args: [MatToolbarOverlay]
            }], _toolbarExpansionRow: [{
                type: ContentChild,
                args: [MatToolbarRowExpansion]
            }], _toolbarFilter: [{
                type: ContentChild,
                args: [MatToolbarFilter]
            }], _toolbarTrigger: [{
                type: ContentChild,
                args: [forwardRef(() => MatToolbarTrigger)]
            }] } });
/**
 * Throws an exception when attempting to combine the different toolbar row modes.
 * @docs-private
 */
function throwToolbarMixedModesError() {
    throw Error('MatToolbar: Attempting to combine different toolbar modes. ' +
        'Either specify multiple `<mat-toolbar-row>` elements explicitly or just place content ' +
        'inside of a `<mat-toolbar>` for a single row.');
}

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
class MatToolbarModule {
}
MatToolbarModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatToolbarModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
MatToolbarModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatToolbarModule, declarations: [MatToolbar,
        MatToolbarFilter,
        MatToolbarOverlay,
        MatToolbarRow,
        MatToolbarRowExpansion,
        MatToolbarSelectionList,
        MatToolbarTrigger], imports: [CommonModule,
        MatCommonModule,
        MatButtonModule,
        MatCardModule,
        MatCheckboxModule,
        MatIconModule,
        MatMenuModule,
        MatTooltipModule], exports: [MatToolbar,
        MatToolbarFilter,
        MatToolbarOverlay,
        MatToolbarRow,
        MatToolbarRowExpansion,
        MatToolbarSelectionList,
        MatToolbarTrigger] });
MatToolbarModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatToolbarModule, providers: [MAT_TOOLBAR_INTL_PROVIDER], imports: [[
            CommonModule,
            MatCommonModule,
            MatButtonModule,
            MatCardModule,
            MatCheckboxModule,
            MatIconModule,
            MatMenuModule,
            MatTooltipModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: MatToolbarModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        MatCommonModule,
                        MatButtonModule,
                        MatCardModule,
                        MatCheckboxModule,
                        MatIconModule,
                        MatMenuModule,
                        MatTooltipModule
                    ],
                    exports: [
                        MatToolbar,
                        MatToolbarFilter,
                        MatToolbarOverlay,
                        MatToolbarRow,
                        MatToolbarRowExpansion,
                        MatToolbarSelectionList,
                        MatToolbarTrigger
                    ],
                    declarations: [
                        MatToolbar,
                        MatToolbarFilter,
                        MatToolbarOverlay,
                        MatToolbarRow,
                        MatToolbarRowExpansion,
                        MatToolbarSelectionList,
                        MatToolbarTrigger
                    ],
                    providers: [MAT_TOOLBAR_INTL_PROVIDER]
                }]
        }] });

/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */

/**
 * Generated bundle index. Do not edit.
 */

export { MAT_TOOLBAR_INTL_PROVIDER, MAT_TOOLBAR_INTL_PROVIDER_FACTORY, MatToolbar, MatToolbarFilter, MatToolbarIntl, MatToolbarModule, MatToolbarOverlay, MatToolbarRow, MatToolbarRowExpansion, MatToolbarSelectionList, MatToolbarSpacer, MatToolbarTrigger, throwToolbarMixedModesError };
//# sourceMappingURL=vdlx-vdl-angular-mat-toolbar.mjs.map
