/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
import { Platform } from '@angular/cdk/platform';
import { AfterContentChecked, AfterViewInit, ChangeDetectorRef, ElementRef, EventEmitter, OnDestroy, QueryList } from '@angular/core';
import { CanColor } from '@vdlx/vdl-angular/mat/core';
import { MatToolbarFilter } from './toolbar-filter';
import { MatToolbarIntl } from './toolbar-intl';
import { MatToolbarRowExpansion } from './toolbar-row-expansion';
import { MatToolbarTrigger } from './toolbar-trigger';
import * as i0 from "@angular/core";
/** @docs-private */
declare const _MatToolbarBase: import("@vdlx/vdl-angular/mat/core")._Constructor<CanColor> & import("@vdlx/vdl-angular/mat/core")._AbstractConstructor<CanColor> & {
    new (_elementRef: ElementRef): {
        _elementRef: ElementRef;
    };
};
export declare class MatToolbarRow {
    static ɵfac: i0.ɵɵFactoryDeclaration<MatToolbarRow, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<MatToolbarRow, "mat-toolbar-row", ["matToolbarRow"], {}, {}, never>;
}
export declare class MatToolbarOverlay implements OnDestroy {
    private matToolBar;
    _intl: MatToolbarIntl;
    private _changeDetectorRef;
    private _intlChanges;
    /**
     * Sets the height of the toolbar overlay. Default to 45;
     */
    setHeight: number;
    /**
     * Sets overlay to be hidden or visible.
     * Default is false
     */
    selected: number;
    /**
     * Array of actions for buttons on the right side.
     * The array is of type ToolbarAction[]
     */
    actions: ToolbarAction[];
    /**
     * Sets aria-label for close button on overlay
     * @deprecated in merge-10, use toolbar-intl instead
     * @breaking-change merge-11
     */
    get closeOverlayAriaLabel(): string;
    set closeOverlayAriaLabel(value: string);
    _closeOverlayAriaLabel: string;
    /** Event Emitter to close the overlay (e.g. set the selected input to 0) */
    readonly closeOverlay: EventEmitter<any>;
    get overlayString(): string;
    /** Gets the expanded state string. */
    _getOverlayState(): string;
    constructor(matToolBar: MatToolbar, _intl: MatToolbarIntl, _changeDetectorRef: ChangeDetectorRef);
    ngOnDestroy(): void;
    /** Callback, invoked when an animation on the host starts. */
    _onAnimationStart(event: AnimationEvent): void;
    /** Callback, invoked whenever an animation on the host completes. */
    _onAnimationDone(event: AnimationEvent): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<MatToolbarOverlay, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MatToolbarOverlay, "mat-toolbar-overlay", never, { "selected": "selected"; "actions": "actions"; "closeOverlayAriaLabel": "closeOverlayAriaLabel"; }, { "closeOverlay": "closeOverlay"; }, never, never>;
}
/**
 * A spacer which you can add between elements to give space between them.
 */
export declare class MatToolbarSpacer {
    static ɵfac: i0.ɵɵFactoryDeclaration<MatToolbarSpacer, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<MatToolbarSpacer, "mat-toolbar-spacer", never, {}, {}, never>;
}
export interface ToolbarAction {
    action: Function;
    name: string;
    icon?: string;
    svg?: string;
}
export declare class MatToolbar extends _MatToolbarBase implements CanColor, AfterViewInit, AfterContentChecked {
    private _platform;
    private _document;
    /** Reference to all toolbar row elements that have been projected. */
    _toolbarRows: QueryList<MatToolbarRow>;
    _hideToolbarRows: boolean;
    _toolbarOverlay: MatToolbarOverlay;
    _toolbarExpansionRow: MatToolbarRowExpansion;
    _toolbarFilter: MatToolbarFilter;
    _toolbarTrigger: MatToolbarTrigger;
    ngAfterContentChecked(): void;
    constructor(elementRef: ElementRef, _platform: Platform, document?: any);
    ngAfterViewInit(): void;
    hideToolbarRows(hide: boolean): void;
    /**
     * Throws an exception when developers are attempting to combine the different toolbar row modes.
     */
    private _checkToolbarMixedModes;
    static ɵfac: i0.ɵɵFactoryDeclaration<MatToolbar, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MatToolbar, "mat-toolbar", ["matToolbar"], { "color": "color"; }, {}, ["_toolbarOverlay", "_toolbarExpansionRow", "_toolbarFilter", "_toolbarTrigger", "_toolbarRows"], ["*", "mat-toolbar-row, mat-toolbar-row-expansion", "mat-toolbar-overlay"]>;
}
/**
 * Throws an exception when attempting to combine the different toolbar row modes.
 * @docs-private
 */
export declare function throwToolbarMixedModesError(): void;
export {};
